Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  tim.asm  Page 1



1                                 COMMENT *
2      
3                          This file is used to generate DSP code for the a Gen III = ARC22
4                                  timing board to operate a 256 x 256 pixel PICNIC IR FPA
5                          2005Jun06 JDM fixed bug in row skip
6                             *
7      
8                                    PAGE    132                               ; Printronix page width - 132 columns
9      
10                         ; Include the boot and header files so addressing is easy
11                                   INCLUDE "timhdr.asm"
12                                COMMENT *
13     
14                         This is a header file that is shared between the fiber optic timing board
15                         boot and application code files for Rev. 5 = 250 MHz timing boards
16                                 *
17     
18                                   PAGE    132                               ; Printronix page width - 132 columns
19     
20                         ; Various addressing control registers
21        FFFFFB           BCR       EQU     $FFFFFB                           ; Bus Control Register
22        FFFFF9           AAR0      EQU     $FFFFF9                           ; Address Attribute Register, channel 0
23        FFFFF8           AAR1      EQU     $FFFFF8                           ; Address Attribute Register, channel 1
24        FFFFF7           AAR2      EQU     $FFFFF7                           ; Address Attribute Register, channel 2
25        FFFFF6           AAR3      EQU     $FFFFF6                           ; Address Attribute Register, channel 3
26        FFFFFD           PCTL      EQU     $FFFFFD                           ; PLL control register
27        FFFFFE           IPRP      EQU     $FFFFFE                           ; Interrupt Priority register - Peripheral
28        FFFFFF           IPRC      EQU     $FFFFFF                           ; Interrupt Priority register - Core
29     
30                         ; Port E is the Synchronous Communications Interface (SCI) port
31        FFFF9F           PCRE      EQU     $FFFF9F                           ; Port Control Register
32        FFFF9E           PRRE      EQU     $FFFF9E                           ; Port Direction Register
33        FFFF9D           PDRE      EQU     $FFFF9D                           ; Port Data Register
34        FFFF9C           SCR       EQU     $FFFF9C                           ; SCI Control Register
35        FFFF9B           SCCR      EQU     $FFFF9B                           ; SCI Clock Control Register
36     
37        FFFF9A           SRXH      EQU     $FFFF9A                           ; SCI Receive Data Register, High byte
38        FFFF99           SRXM      EQU     $FFFF99                           ; SCI Receive Data Register, Middle byte
39        FFFF98           SRXL      EQU     $FFFF98                           ; SCI Receive Data Register, Low byte
40     
41        FFFF97           STXH      EQU     $FFFF97                           ; SCI Transmit Data register, High byte
42        FFFF96           STXM      EQU     $FFFF96                           ; SCI Transmit Data register, Middle byte
43        FFFF95           STXL      EQU     $FFFF95                           ; SCI Transmit Data register, Low byte
44     
45        FFFF94           STXA      EQU     $FFFF94                           ; SCI Transmit Address Register
46        FFFF93           SSR       EQU     $FFFF93                           ; SCI Status Register
47     
48        000009           SCITE     EQU     9                                 ; X:SCR bit set to enable the SCI transmitter
49        000008           SCIRE     EQU     8                                 ; X:SCR bit set to enable the SCI receiver
50        000000           TRNE      EQU     0                                 ; This is set in X:SSR when the transmitter
51                                                                             ;  shift and data registers are both empty
52        000001           TDRE      EQU     1                                 ; This is set in X:SSR when the transmitter
53                                                                             ;  data register is empty
54        000002           RDRF      EQU     2                                 ; X:SSR bit set when receiver register is full
55        00000F           SELSCI    EQU     15                                ; 1 for SCI to backplane, 0 to front connector
56     
57     
58                         ; ESSI Flags
59        000006           TDE       EQU     6                                 ; Set when transmitter data register is empty
60        000007           RDF       EQU     7                                 ; Set when receiver is full of data
61        000010           TE        EQU     16                                ; Transmitter enable
62     
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timhdr.asm  Page 2



63                         ; Phase Locked Loop initialization
64        050003           PLL_INIT  EQU     $050003                           ; PLL = 25 MHz x 2 = 100 MHz
65     
66                         ; Port B general purpose I/O
67        FFFFC4           HPCR      EQU     $FFFFC4                           ; Control register (bits 1-6 cleared for GPIO)
68        FFFFC9           HDR       EQU     $FFFFC9                           ; Data register
69        FFFFC8           HDDR      EQU     $FFFFC8                           ; Data Direction Register bits (=1 for output)
70     
71                         ; Port C is Enhanced Synchronous Serial Port 0 = ESSI0
72        FFFFBF           PCRC      EQU     $FFFFBF                           ; Port C Control Register
73        FFFFBE           PRRC      EQU     $FFFFBE                           ; Port C Data direction Register
74        FFFFBD           PDRC      EQU     $FFFFBD                           ; Port C GPIO Data Register
75        FFFFBC           TX00      EQU     $FFFFBC                           ; Transmit Data Register #0
76        FFFFB8           RX0       EQU     $FFFFB8                           ; Receive data register
77        FFFFB7           SSISR0    EQU     $FFFFB7                           ; Status Register
78        FFFFB6           CRB0      EQU     $FFFFB6                           ; Control Register B
79        FFFFB5           CRA0      EQU     $FFFFB5                           ; Control Register A
80     
81                         ; Port D is Enhanced Synchronous Serial Port 1 = ESSI1
82        FFFFAF           PCRD      EQU     $FFFFAF                           ; Port D Control Register
83        FFFFAE           PRRD      EQU     $FFFFAE                           ; Port D Data direction Register
84        FFFFAD           PDRD      EQU     $FFFFAD                           ; Port D GPIO Data Register
85        FFFFAC           TX10      EQU     $FFFFAC                           ; Transmit Data Register 0
86        FFFFA7           SSISR1    EQU     $FFFFA7                           ; Status Register
87        FFFFA6           CRB1      EQU     $FFFFA6                           ; Control Register B
88        FFFFA5           CRA1      EQU     $FFFFA5                           ; Control Register A
89     
90                         ; Timer module addresses
91        FFFF8F           TCSR0     EQU     $FFFF8F                           ; Timer control and status register
92        FFFF8E           TLR0      EQU     $FFFF8E                           ; Timer load register = 0
93        FFFF8D           TCPR0     EQU     $FFFF8D                           ; Timer compare register = exposure time
94        FFFF8C           TCR0      EQU     $FFFF8C                           ; Timer count register = elapsed time
95        FFFF83           TPLR      EQU     $FFFF83                           ; Timer prescaler load register => milliseconds
96        FFFF82           TPCR      EQU     $FFFF82                           ; Timer prescaler count register
97        000000           TIM_BIT   EQU     0                                 ; Set to enable the timer
98        000009           TRM       EQU     9                                 ; Set to enable the timer preloading
99        000015           TCF       EQU     21                                ; Set when timer counter = compare register
100    
101                        ; Board specific addresses and constants
102       FFFFF1           RDFO      EQU     $FFFFF1                           ; Read incoming fiber optic data byte
103       FFFFF2           WRFO      EQU     $FFFFF2                           ; Write fiber optic data replies
104       FFFFF3           WRSS      EQU     $FFFFF3                           ; Write switch state
105       FFFFF5           WRLATCH   EQU     $FFFFF5                           ; Write to a latch
106       010000           RDAD      EQU     $010000                           ; Read A/D values into the DSP
107       000009           EF        EQU     9                                 ; Serial receiver empty flag
108    
109                        ; DSP port A bit equates
110       000000           PWROK     EQU     0                                 ; Power control board says power is OK
111       000001           LED1      EQU     1                                 ; Control one of two LEDs
112       000002           LVEN      EQU     2                                 ; Low voltage power enable
113       000003           HVEN      EQU     3                                 ; High voltage power enable
114       00000E           SSFHF     EQU     14                                ; Switch state FIFO half full flag
115       00000A           EXT_IN0   EQU     10                                ; External digital I/O to the timing board
116       00000B           EXT_IN1   EQU     11
117       00000C           EXT_OUT0  EQU     12
118       00000D           EXT_OUT1  EQU     13
119    
120                        ; Port D equate
121       000001           SSFEF     EQU     1                                 ; Switch state FIFO empty flag
122    
123                        ; Other equates
124       000002           WRENA     EQU     2                                 ; Enable writing to the EEPROM
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timhdr.asm  Page 3



125    
126                        ; Latch U12 bit equates
127       000000           CDAC      EQU     0                                 ; Clear the analog board DACs
128       000002           ENCK      EQU     2                                 ; Enable the clock outputs
129       000004           SHUTTER   EQU     4                                 ; Control the shutter
130       000005           TIM_U_RST EQU     5                                 ; Reset the utility board
131    
132                        ; Software status bits, defined at X:<STATUS = X:0
133       000000           ST_RCV    EQU     0                                 ; Set to indicate word is from SCI = utility board
134       000002           IDLMODE   EQU     2                                 ; Set if need to idle after readout
135       000003           ST_SHUT   EQU     3                                 ; Set to indicate shutter is closed, clear for open
136       000004           ST_RDC    EQU     4                                 ; Set if executing 'RDC' command - reading out
137       000005           SPLIT_S   EQU     5                                 ; Set if split serial
138       000006           SPLIT_P   EQU     6                                 ; Set if split parallel
139       000007           MPP       EQU     7                                 ; Set if parallels are in MPP mode
140       000008           NOT_CLR   EQU     8                                 ; Set if not to clear CCD before exposure
141       00000A           TST_IMG   EQU     10                                ; Set if controller is to generate a test image
142       00000B           SHUT      EQU     11                                ; Set if opening shutter at beginning of exposure
143       00000C           ST_DITH   EQU     12                                ; Set if to dither during exposure
144       00000D           ST_SYNC   EQU     13                                ; Set if starting exposure on SYNC = high signal
145       00000E           ST_CNRD   EQU     14                                ; Set if in continous readout mode
146       00000F           ST_CDS    EQU     15                                ; Set if correlated double sample
147       000010           ST_RD     EQU     16                                ; Set if the signal 'READ' should be turned on and of
f
148    
149                        ; Address for the table containing the incoming SCI words
150       000400           SCI_TABLE EQU     $400
151    
152    
153                        ; Specify controller configuration bits of the X:STATUS word
154                        ;   to describe the software capabilities of this application file
155                        ; The bit is set (=1) if the capability is supported by the controller
156    
157    
158                                COMMENT *
159    
160                        BIT #'s         FUNCTION
161                        2,1,0           Video Processor
162                                                000     CCD Rev. 3
163                                                001     CCD Gen I
164                                                010     IR Rev. 4
165                                                011     IR Coadder
166                                                100     CCD Rev. 5, Differential input
167                                                101     8x IR
168    
169                        4,3             Timing Board
170                                                00      Rev. 4, Gen II
171                                                01      Gen I
172                                                10      Rev. 5, Gen III, 250 MHz
173    
174                        6,5             Utility Board
175                                                00      No utility board
176                                                01      Utility Rev. 3
177    
178                        7               Shutter
179                                                0       No shutter support
180                                                1       Yes shutter support
181    
182                        9,8             Temperature readout
183                                                00      No temperature readout
184                                                01      Polynomial Diode calibration
185                                                10      Linear temperature sensor calibration
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timhdr.asm  Page 4



186    
187                        10              Subarray readout
188                                                0       Not supported
189                                                1       Yes supported
190    
191                        11              Binning
192                                                0       Not supported
193                                                1       Yes supported
194    
195                        12              Split-Serial readout
196                                                0       Not supported
197                                                1       Yes supported
198    
199                        13              Split-Parallel readout
200                                                0       Not supported
201                                                1       Yes supported
202    
203                        14              MPP = Inverted parallel clocks
204                                                0       Not supported
205                                                1       Yes supported
206    
207                        16,15           Clock Driver Board
208                                                00      Rev. 3
209                                                11      No clock driver board (Gen I)
210    
211                        19,18,17                Special implementations
212                                                000     Somewhere else
213                                                001     Mount Laguna Observatory
214                                                010     NGST Aladdin
215                                                xxx     Other
216                                *
217    
218                        CCDVIDREV3B
219       000000                     EQU     $000000                           ; CCD Video Processor Rev. 3
220       000001           VIDGENI   EQU     $000001                           ; CCD Video Processor Gen I
221       000002           IRREV4    EQU     $000002                           ; IR Video Processor Rev. 4
222       000003           COADDER   EQU     $000003                           ; IR Coadder
223       000004           CCDVIDREV5 EQU    $000004                           ; Differential input CCD video Rev. 5
224       000000           TIMREV4   EQU     $000000                           ; Timing Revision 4 = 50 MHz
225       000008           TIMGENI   EQU     $000008                           ; Timing Gen I = 40 MHz
226       000010           TIMREV5   EQU     $000010                           ; Timing Revision 5 = 250 MHz
227       000020           UTILREV3  EQU     $000020                           ; Utility Rev. 3 supported
228       000080           SHUTTER_CC EQU    $000080                           ; Shutter supported
229       000100           TEMP_POLY EQU     $000100                           ; Polynomial calibration
230                        TEMP_LINEAR
231       000200                     EQU     $000200                           ; Linear calibration
232       000400           SUBARRAY  EQU     $000400                           ; Subarray readout supported
233       000800           BINNING   EQU     $000800                           ; Binning supported
234                        SPLIT_SERIAL
235       001000                     EQU     $001000                           ; Split serial supported
236                        SPLIT_PARALLEL
237       002000                     EQU     $002000                           ; Split parallel supported
238       004000           MPP_CC    EQU     $004000                           ; Inverted clocks supported
239       018000           CLKDRVGENI EQU    $018000                           ; No clock driver board - Gen I
240       020000           MLO       EQU     $020000                           ; Set if Mount Laguna Observatory
241       040000           NGST      EQU     $040000                           ; NGST Aladdin implementation
242       100000           CONT_RD   EQU     $100000                           ; Continuous readout implemented
243    
244                                  INCLUDE "timboot.asm"
245                               COMMENT *
246    
247                        This file is used to generate boot DSP code for the 250 MHz fiber optic
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 5



248                                timing board using a DSP56303 as its main processor.
249                        Added utility board support Dec. 2002
250                                *
251                                  PAGE    132                               ; Printronix page width - 132 columns
252    
253                        ; Special address for two words for the DSP to bootstrap code from the EEPROM
254                                  IF      @SCP("HOST","ROM")
261                                  ENDIF
262    
263                                  IF      @SCP("HOST","HOST")
264       P:000000 P:000000                   ORG     P:0,P:0
265       P:000000 P:000000 0C0190            JMP     <INIT
266       P:000001 P:000001 000000            NOP
267                                           ENDIF
268    
269                                 ;  This ISR receives serial words a byte at a time over the asynchronous
270                                 ;    serial link (SCI) and squashes them into a single 24-bit word
271       P:000002 P:000002 602400  SCI_RCV   MOVE              R0,X:<SAVE_R0           ; Save R0
272       P:000003 P:000003 052139            MOVEC             SR,X:<SAVE_SR           ; Save Status Register
273       P:000004 P:000004 60A700            MOVE              X:<SCI_R0,R0            ; Restore R0 = pointer to SCI receive regist
er
274       P:000005 P:000005 542300            MOVE              A1,X:<SAVE_A1           ; Save A1
275       P:000006 P:000006 452200            MOVE              X1,X:<SAVE_X1           ; Save X1
276       P:000007 P:000007 54A600            MOVE              X:<SCI_A1,A1            ; Get SRX value of accumulator contents
277       P:000008 P:000008 45E000            MOVE              X:(R0),X1               ; Get the SCI byte
278       P:000009 P:000009 0AD041            BCLR    #1,R0                             ; Test for the address being $FFF6 = last by
te
279       P:00000A P:00000A 000000            NOP
280       P:00000B P:00000B 000000            NOP
281       P:00000C P:00000C 000000            NOP
282       P:00000D P:00000D 205862            OR      X1,A      (R0)+                   ; Add the byte into the 24-bit word
283       P:00000E P:00000E 0E0013            JCC     <MID_BYT                          ; Not the last byte => only restore register
s
284       P:00000F P:00000F 545C00  END_BYT   MOVE              A1,X:(R4)+              ; Put the 24-bit word into the SCI buffer
285       P:000010 P:000010 60F400            MOVE              #SRXL,R0                ; Re-establish first address of SCI interfac
e
                            FFFF98
286       P:000012 P:000012 2C0000            MOVE              #0,A1                   ; For zeroing out SCI_A1
287       P:000013 P:000013 602700  MID_BYT   MOVE              R0,X:<SCI_R0            ; Save the SCI receiver address
288       P:000014 P:000014 542600            MOVE              A1,X:<SCI_A1            ; Save A1 for next interrupt
289       P:000015 P:000015 05A139            MOVEC             X:<SAVE_SR,SR           ; Restore Status Register
290       P:000016 P:000016 54A300            MOVE              X:<SAVE_A1,A1           ; Restore A1
291       P:000017 P:000017 45A200            MOVE              X:<SAVE_X1,X1           ; Restore X1
292       P:000018 P:000018 60A400            MOVE              X:<SAVE_R0,R0           ; Restore R0
293       P:000019 P:000019 000004            RTI                                       ; Return from interrupt service
294    
295                                 ; Clear error condition and interrupt on SCI receiver
296       P:00001A P:00001A 077013  CLR_ERR   MOVEP             X:SSR,X:RCV_ERR         ; Read SCI status register
                            000025
297       P:00001C P:00001C 077018            MOVEP             X:SRXL,X:RCV_ERR        ; This clears any error
                            000025
298       P:00001E P:00001E 000004            RTI
299    
300       P:00001F P:00001F                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
301       P:000030 P:000030                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
302       P:000040 P:000040                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
303    
304                                 ; Tune the table so the following instruction is at P:$50 exactly.
305       P:000050 P:000050 0D0002            JSR     SCI_RCV                           ; SCI receive data interrupt
306       P:000051 P:000051 000000            NOP
307       P:000052 P:000052 0D001A            JSR     CLR_ERR                           ; SCI receive error interrupt
308       P:000053 P:000053 000000            NOP
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 6



309    
310                                 ; *******************  Command Processing  ******************
311    
312                                 ; Read the header and check it for self-consistency
313       P:000054 P:000054 609F00  START     MOVE              X:<IDL_ADR,R0
314       P:000055 P:000055 018FA0            JSET    #TIM_BIT,X:TCSR0,EXPOSING         ; If exposing go check the timer
                            000317
315       P:000057 P:000057 0A00A4            JSET    #ST_RDC,X:<STATUS,CONTINUE_READING
                            00036F
316       P:000059 P:000059 0AE080            JMP     (R0)
317    
318       P:00005A P:00005A 330700  TST_RCV   MOVE              #<COM_BUF,R3
319       P:00005B P:00005B 0D00A5            JSR     <GET_RCV
320       P:00005C P:00005C 0E005B            JCC     *-1
321    
322                                 ; Check the header and read all the remaining words in the command
323       P:00005D P:00005D 0C00FF  PRC_RCV   JMP     <CHK_HDR                          ; Update HEADER and NWORDS
324       P:00005E P:00005E 578600  PR_RCV    MOVE              X:<NWORDS,B             ; Read this many words total in the command
325       P:00005F P:00005F 000000            NOP
326       P:000060 P:000060 01418C            SUB     #1,B                              ; We've already read the header
327       P:000061 P:000061 000000            NOP
328       P:000062 P:000062 06CF00            DO      B,RD_COM
                            00006A
329       P:000064 P:000064 205B00            MOVE              (R3)+                   ; Increment past what's been read already
330       P:000065 P:000065 0B0080  GET_WRD   JSCLR   #ST_RCV,X:STATUS,CHK_FO
                            0000A9
331       P:000067 P:000067 0B00A0            JSSET   #ST_RCV,X:STATUS,CHK_SCI
                            0000D5
332       P:000069 P:000069 0E0065            JCC     <GET_WRD
333       P:00006A P:00006A 000000            NOP
334       P:00006B P:00006B 330700  RD_COM    MOVE              #<COM_BUF,R3            ; Restore R3 = beginning of the command
335    
336                                 ; Is this command for the timing board?
337       P:00006C P:00006C 448500            MOVE              X:<HEADER,X0
338       P:00006D P:00006D 579B00            MOVE              X:<DMASK,B
339       P:00006E P:00006E 459A4E            AND     X0,B      X:<TIM_DRB,X1           ; Extract destination byte
340       P:00006F P:00006F 20006D            CMP     X1,B                              ; Does header = timing board number?
341       P:000070 P:000070 0EA080            JEQ     <COMMAND                          ; Yes, process it here
342       P:000071 P:000071 0E909D            JLT     <FO_XMT                           ; Send it to fiber optic transmitter
343    
344                                 ; Transmit the command to the utility board over the SCI port
345       P:000072 P:000072 060600            DO      X:<NWORDS,DON_XMT                 ; Transmit NWORDS
                            00007E
346       P:000074 P:000074 60F400            MOVE              #STXL,R0                ; SCI first byte address
                            FFFF95
347       P:000076 P:000076 44DB00            MOVE              X:(R3)+,X0              ; Get the 24-bit word to transmit
348       P:000077 P:000077 060380            DO      #3,SCI_SPT
                            00007D
349       P:000079 P:000079 019381            JCLR    #TDRE,X:SSR,*                     ; Continue ONLY if SCI XMT is empty
                            000079
350       P:00007B P:00007B 445800            MOVE              X0,X:(R0)+              ; Write to SCI, byte pointer + 1
351       P:00007C P:00007C 000000            NOP                                       ; Delay for the status flag to be set
352       P:00007D P:00007D 000000            NOP
353                                 SCI_SPT
354       P:00007E P:00007E 000000            NOP
355                                 DON_XMT
356       P:00007F P:00007F 0C0054            JMP     <START
357    
358                                 ; Process the receiver entry - is it in the command table ?
359       P:000080 P:000080 0203DF  COMMAND   MOVE              X:(R3+1),B              ; Get the command
360       P:000081 P:000081 205B00            MOVE              (R3)+
361       P:000082 P:000082 205B00            MOVE              (R3)+                   ; Point R3 to the first argument
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 7



362       P:000083 P:000083 302800            MOVE              #<COM_TBL,R0            ; Get the command table starting address
363       P:000084 P:000084 061B80            DO      #NUM_COM,END_COM                  ; Loop over the command table
                            00008B
364       P:000086 P:000086 47D800            MOVE              X:(R0)+,Y1              ; Get the command table entry
365       P:000087 P:000087 62E07D            CMP     Y1,B      X:(R0),R2               ; Does receiver = table entries address?
366       P:000088 P:000088 0E208B            JNE     <NOT_COM                          ; No, keep looping
367       P:000089 P:000089 00008C            ENDDO                                     ; Restore the DO loop system registers
368       P:00008A P:00008A 0AE280            JMP     (R2)                              ; Jump execution to the command
369       P:00008B P:00008B 205800  NOT_COM   MOVE              (R0)+                   ; Increment the register past the table addr
ess
370                                 END_COM
371       P:00008C P:00008C 0C008D            JMP     <ERROR                            ; The command is not in the table
372    
373                                 ; It's not in the command table - send an error message
374       P:00008D P:00008D 479D00  ERROR     MOVE              X:<ERR,Y1               ; Send the message - there was an error
375       P:00008E P:00008E 0C0090            JMP     <FINISH1                          ; This protects against unknown commands
376    
377                                 ; Send a reply packet - header and reply
378       P:00008F P:00008F 479800  FINISH    MOVE              X:<DONE,Y1              ; Send 'DON' as the reply
379       P:000090 P:000090 578500  FINISH1   MOVE              X:<HEADER,B             ; Get header of incoming command
380       P:000091 P:000091 469C00            MOVE              X:<SMASK,Y0             ; This was the source byte, and is to
381       P:000092 P:000092 330700            MOVE              #<COM_BUF,R3            ;     become the destination byte
382       P:000093 P:000093 46935E            AND     Y0,B      X:<TWO,Y0
383       P:000094 P:000094 0C1ED1            LSR     #8,B                              ; Shift right eight bytes, add it to the
384       P:000095 P:000095 460600            MOVE              Y0,X:<NWORDS            ;     header, and put 2 as the number
385       P:000096 P:000096 469958            ADD     Y0,B      X:<SBRD,Y0              ;     of words in the string
386       P:000097 P:000097 200058            ADD     Y0,B                              ; Add source board's header, set Y1 for abov
e
387       P:000098 P:000098 000000            NOP
388       P:000099 P:000099 575B00            MOVE              B,X:(R3)+               ; Put the new header on the transmitter stac
k
389       P:00009A P:00009A 475B00            MOVE              Y1,X:(R3)+              ; Put the argument on the transmitter stack
390       P:00009B P:00009B 570500            MOVE              B,X:<HEADER
391       P:00009C P:00009C 0C006B            JMP     <RD_COM                           ; Decide where to send the reply, and do it
392    
393                                 ; Transmit words to the host computer over the fiber optics link
394       P:00009D P:00009D 63F400  FO_XMT    MOVE              #COM_BUF,R3
                            000007
395       P:00009F P:00009F 060600            DO      X:<NWORDS,DON_FFO                 ; Transmit all the words in the command
                            0000A3
396       P:0000A1 P:0000A1 57DB00            MOVE              X:(R3)+,B
397       P:0000A2 P:0000A2 0D00EB            JSR     <XMT_WRD
398       P:0000A3 P:0000A3 000000            NOP
399       P:0000A4 P:0000A4 0C0054  DON_FFO   JMP     <START
400    
401                                 ; Check for commands from the fiber optic FIFO and the utility board (SCI)
402       P:0000A5 P:0000A5 0D00A9  GET_RCV   JSR     <CHK_FO                           ; Check for fiber optic command from FIFO
403       P:0000A6 P:0000A6 0E80A8            JCS     <RCV_RTS                          ; If there's a command, check the header
404       P:0000A7 P:0000A7 0D00D5            JSR     <CHK_SCI                          ; Check for an SCI command
405       P:0000A8 P:0000A8 00000C  RCV_RTS   RTS
406    
407                                 ; Because of FIFO metastability require that EF be stable for two tests
408       P:0000A9 P:0000A9 0A8989  CHK_FO    JCLR    #EF,X:HDR,TST2                    ; EF = Low,  Low  => CLR SR, return
                            0000AC
409       P:0000AB P:0000AB 0C00AF            JMP     <TST3                             ;      High, Low  => try again
410       P:0000AC P:0000AC 0A8989  TST2      JCLR    #EF,X:HDR,CLR_CC                  ;      Low,  High => try again
                            0000D1
411       P:0000AE P:0000AE 0C00A9            JMP     <CHK_FO                           ;      High, High => read FIFO
412       P:0000AF P:0000AF 0A8989  TST3      JCLR    #EF,X:HDR,CHK_FO
                            0000A9
413    
414       P:0000B1 P:0000B1 08F4BB            MOVEP             #$028FE2,X:BCR          ; Slow down RDFO access
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 8



                            028FE2
415       P:0000B3 P:0000B3 000000            NOP
416       P:0000B4 P:0000B4 000000            NOP
417       P:0000B5 P:0000B5 5FF000            MOVE                          Y:RDFO,B
                            FFFFF1
418       P:0000B7 P:0000B7 2B0000            MOVE              #0,B2
419       P:0000B8 P:0000B8 0140CE            AND     #$FF,B
                            0000FF
420       P:0000BA P:0000BA 0140CD            CMP     #>$AC,B                           ; It must be $AC to be a valid word
                            0000AC
421       P:0000BC P:0000BC 0E20D1            JNE     <CLR_CC
422       P:0000BD P:0000BD 4EF000            MOVE                          Y:RDFO,Y0   ; Read the MS byte
                            FFFFF1
423       P:0000BF P:0000BF 0C1951            INSERT  #$008010,Y0,B
                            008010
424       P:0000C1 P:0000C1 4EF000            MOVE                          Y:RDFO,Y0   ; Read the middle byte
                            FFFFF1
425       P:0000C3 P:0000C3 0C1951            INSERT  #$008008,Y0,B
                            008008
426       P:0000C5 P:0000C5 4EF000            MOVE                          Y:RDFO,Y0   ; Read the LS byte
                            FFFFF1
427       P:0000C7 P:0000C7 0C1951            INSERT  #$008000,Y0,B
                            008000
428       P:0000C9 P:0000C9 000000            NOP
429       P:0000CA P:0000CA 516300            MOVE              B0,X:(R3)               ; Put the word into COM_BUF
430       P:0000CB P:0000CB 0A0000            BCLR    #ST_RCV,X:<STATUS                 ; Its a command from the host computer
431       P:0000CC P:0000CC 000000  SET_CC    NOP
432       P:0000CD P:0000CD 0AF960            BSET    #0,SR                             ; Valid word => SR carry bit = 1
433       P:0000CE P:0000CE 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
434       P:0000D0 P:0000D0 00000C            RTS
435       P:0000D1 P:0000D1 0AF940  CLR_CC    BCLR    #0,SR                             ; Not valid word => SR carry bit = 0
436       P:0000D2 P:0000D2 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
437       P:0000D4 P:0000D4 00000C            RTS
438    
439                                 ; Test the SCI (= synchronous communications interface) for new words
440       P:0000D5 P:0000D5 44F000  CHK_SCI   MOVE              X:(SCI_TABLE+33),X0
                            000421
441       P:0000D7 P:0000D7 228E00            MOVE              R4,A
442       P:0000D8 P:0000D8 209000            MOVE              X0,R0
443       P:0000D9 P:0000D9 200045            CMP     X0,A
444       P:0000DA P:0000DA 0EA0D1            JEQ     <CLR_CC                           ; There is no new SCI word
445       P:0000DB P:0000DB 44D800            MOVE              X:(R0)+,X0
446       P:0000DC P:0000DC 446300            MOVE              X0,X:(R3)
447       P:0000DD P:0000DD 220E00            MOVE              R0,A
448       P:0000DE P:0000DE 0140C5            CMP     #(SCI_TABLE+32),A                 ; Wrap it around the circular
                            000420
449       P:0000E0 P:0000E0 0EA0E4            JEQ     <INIT_PROCESSED_SCI               ;   buffer boundary
450       P:0000E1 P:0000E1 547000            MOVE              A1,X:(SCI_TABLE+33)
                            000421
451       P:0000E3 P:0000E3 0C00E9            JMP     <SCI_END
452                                 INIT_PROCESSED_SCI
453       P:0000E4 P:0000E4 56F400            MOVE              #SCI_TABLE,A
                            000400
454       P:0000E6 P:0000E6 000000            NOP
455       P:0000E7 P:0000E7 567000            MOVE              A,X:(SCI_TABLE+33)
                            000421
456       P:0000E9 P:0000E9 0A0020  SCI_END   BSET    #ST_RCV,X:<STATUS                 ; Its a utility board (SCI) word
457       P:0000EA P:0000EA 0C00CC            JMP     <SET_CC
458    
459                                 ; Transmit the word in B1 to the host computer over the fiber optic data link
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 9



460                                 XMT_WRD
461       P:0000EB P:0000EB 08F4BB            MOVEP             #$028FE2,X:BCR          ; Slow down RDFO access
                            028FE2
462       P:0000ED P:0000ED 60F400            MOVE              #FO_HDR+1,R0
                            000002
463       P:0000EF P:0000EF 060380            DO      #3,XMT_WRD1
                            0000F3
464       P:0000F1 P:0000F1 0C1D91            ASL     #8,B,B
465       P:0000F2 P:0000F2 000000            NOP
466       P:0000F3 P:0000F3 535800            MOVE              B2,X:(R0)+
467                                 XMT_WRD1
468       P:0000F4 P:0000F4 60F400            MOVE              #FO_HDR,R0
                            000001
469       P:0000F6 P:0000F6 61F400            MOVE              #WRFO,R1
                            FFFFF2
470       P:0000F8 P:0000F8 060480            DO      #4,XMT_WRD2
                            0000FB
471       P:0000FA P:0000FA 46D800            MOVE              X:(R0)+,Y0              ; Should be MOVEP  X:(R0)+,Y:WRFO
472       P:0000FB P:0000FB 4E6100            MOVE                          Y0,Y:(R1)
473                                 XMT_WRD2
474       P:0000FC P:0000FC 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
475       P:0000FE P:0000FE 00000C            RTS
476    
477                                 ; Check the command or reply header in X:(R3) for self-consistency
478       P:0000FF P:0000FF 46E300  CHK_HDR   MOVE              X:(R3),Y0
479       P:000100 P:000100 579600            MOVE              X:<MASK1,B              ; Test for S.LE.3 and D.LE.3 and N.LE.7
480       P:000101 P:000101 20005E            AND     Y0,B
481       P:000102 P:000102 0E208D            JNE     <ERROR                            ; Test failed
482       P:000103 P:000103 579700            MOVE              X:<MASK2,B              ; Test for either S.NE.0 or D.NE.0
483       P:000104 P:000104 20005E            AND     Y0,B
484       P:000105 P:000105 0EA08D            JEQ     <ERROR                            ; Test failed
485       P:000106 P:000106 579500            MOVE              X:<SEVEN,B
486       P:000107 P:000107 20005E            AND     Y0,B                              ; Extract NWORDS, must be > 0
487       P:000108 P:000108 0EA08D            JEQ     <ERROR
488       P:000109 P:000109 44E300            MOVE              X:(R3),X0
489       P:00010A P:00010A 440500            MOVE              X0,X:<HEADER            ; Its a correct header
490       P:00010B P:00010B 550600            MOVE              B1,X:<NWORDS            ; Number of words in the command
491       P:00010C P:00010C 0C005E            JMP     <PR_RCV
492    
493                                 ;  *****************  Boot Commands  *******************
494    
495                                 ; Test Data Link - simply return value received after 'TDL'
496       P:00010D P:00010D 47DB00  TDL       MOVE              X:(R3)+,Y1              ; Get the data value
497       P:00010E P:00010E 0C0090            JMP     <FINISH1                          ; Return from executing TDL command
498    
499                                 ; Read DSP or EEPROM memory ('RDM' address): read memory, reply with value
500       P:00010F P:00010F 47DB00  RDMEM     MOVE              X:(R3)+,Y1
501       P:000110 P:000110 20EF00            MOVE              Y1,B
502       P:000111 P:000111 0140CE            AND     #$0FFFFF,B                        ; Bits 23-20 need to be zeroed
                            0FFFFF
503       P:000113 P:000113 21B000            MOVE              B1,R0                   ; Need the address in an address register
504       P:000114 P:000114 20EF00            MOVE              Y1,B
505       P:000115 P:000115 000000            NOP
506       P:000116 P:000116 0ACF14            JCLR    #20,B,RDX                         ; Test address bit for Program memory
                            00011A
507       P:000118 P:000118 07E087            MOVE              P:(R0),Y1               ; Read from Program Memory
508       P:000119 P:000119 0C0090            JMP     <FINISH1                          ; Send out a header with the value
509       P:00011A P:00011A 0ACF15  RDX       JCLR    #21,B,RDY                         ; Test address bit for X: memory
                            00011E
510       P:00011C P:00011C 47E000            MOVE              X:(R0),Y1               ; Write to X data memory
511       P:00011D P:00011D 0C0090            JMP     <FINISH1                          ; Send out a header with the value
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 10



512       P:00011E P:00011E 0ACF16  RDY       JCLR    #22,B,RDR                         ; Test address bit for Y: memory
                            000122
513       P:000120 P:000120 4FE000            MOVE                          Y:(R0),Y1   ; Read from Y data memory
514       P:000121 P:000121 0C0090            JMP     <FINISH1                          ; Send out a header with the value
515       P:000122 P:000122 0ACF17  RDR       JCLR    #23,B,ERROR                       ; Test address bit for read from EEPROM memo
ry
                            00008D
516       P:000124 P:000124 479400            MOVE              X:<THREE,Y1             ; Convert to word address to a byte address
517       P:000125 P:000125 220600            MOVE              R0,Y0                   ; Get 16-bit address in a data register
518       P:000126 P:000126 2000B8            MPY     Y0,Y1,B                           ; Multiply
519       P:000127 P:000127 20002A            ASR     B                                 ; Eliminate zero fill of fractional multiply
520       P:000128 P:000128 213000            MOVE              B0,R0                   ; Need to address memory
521       P:000129 P:000129 0AD06F            BSET    #15,R0                            ; Set bit so its in EEPROM space
522       P:00012A P:00012A 0D0178            JSR     <RD_WORD                          ; Read word from EEPROM
523       P:00012B P:00012B 21A700            MOVE              B1,Y1                   ; FINISH1 transmits Y1 as its reply
524       P:00012C P:00012C 0C0090            JMP     <FINISH1
525    
526                                 ; Program WRMEM ('WRM' address datum): write to memory, reply 'DON'.
527       P:00012D P:00012D 47DB00  WRMEM     MOVE              X:(R3)+,Y1              ; Get the address to be written to
528       P:00012E P:00012E 20EF00            MOVE              Y1,B
529       P:00012F P:00012F 0140CE            AND     #$0FFFFF,B                        ; Bits 23-20 need to be zeroed
                            0FFFFF
530       P:000131 P:000131 21B000            MOVE              B1,R0                   ; Need the address in an address register
531       P:000132 P:000132 20EF00            MOVE              Y1,B
532       P:000133 P:000133 46DB00            MOVE              X:(R3)+,Y0              ; Get datum into Y0 so MOVE works easily
533       P:000134 P:000134 0ACF14            JCLR    #20,B,WRX                         ; Test address bit for Program memory
                            000138
534       P:000136 P:000136 076086            MOVE              Y0,P:(R0)               ; Write to Program memory
535       P:000137 P:000137 0C008F            JMP     <FINISH
536       P:000138 P:000138 0ACF15  WRX       JCLR    #21,B,WRY                         ; Test address bit for X: memory
                            00013C
537       P:00013A P:00013A 466000            MOVE              Y0,X:(R0)               ; Write to X: memory
538       P:00013B P:00013B 0C008F            JMP     <FINISH
539       P:00013C P:00013C 0ACF16  WRY       JCLR    #22,B,WRR                         ; Test address bit for Y: memory
                            000140
540       P:00013E P:00013E 4E6000            MOVE                          Y0,Y:(R0)   ; Write to Y: memory
541       P:00013F P:00013F 0C008F            JMP     <FINISH
542       P:000140 P:000140 0ACF17  WRR       JCLR    #23,B,ERROR                       ; Test address bit for write to EEPROM
                            00008D
543       P:000142 P:000142 013D02            BCLR    #WRENA,X:PDRC                     ; WR_ENA* = 0 to enable EEPROM writing
544       P:000143 P:000143 460E00            MOVE              Y0,X:<SV_A1             ; Save the datum to be written
545       P:000144 P:000144 479400            MOVE              X:<THREE,Y1             ; Convert word address to a byte address
546       P:000145 P:000145 220600            MOVE              R0,Y0                   ; Get 16-bit address in a data register
547       P:000146 P:000146 2000B8            MPY     Y1,Y0,B                           ; Multiply
548       P:000147 P:000147 20002A            ASR     B                                 ; Eliminate zero fill of fractional multiply
549       P:000148 P:000148 213000            MOVE              B0,R0                   ; Need to address memory
550       P:000149 P:000149 0AD06F            BSET    #15,R0                            ; Set bit so its in EEPROM space
551       P:00014A P:00014A 558E00            MOVE              X:<SV_A1,B1             ; Get the datum to be written
552       P:00014B P:00014B 060380            DO      #3,L1WRR                          ; Loop over three bytes of the word
                            000154
553       P:00014D P:00014D 07588D            MOVE              B1,P:(R0)+              ; Write each EEPROM byte
554       P:00014E P:00014E 0C1C91            ASR     #8,B,B
555       P:00014F P:00014F 469E00            MOVE              X:<C100K,Y0             ; Move right one byte, enter delay = 1 msec
556       P:000150 P:000150 06C600            DO      Y0,L2WRR                          ; Delay by 12 milliseconds for EEPROM write
                            000153
557       P:000152 P:000152 060CA0            REP     #12                               ; Assume 100 MHz DSP56303
558       P:000153 P:000153 000000            NOP
559                                 L2WRR
560       P:000154 P:000154 000000            NOP                                       ; DO loop nesting restriction
561                                 L1WRR
562       P:000155 P:000155 013D22            BSET    #WRENA,X:PDRC                     ; WR_ENA* = 1 to disable EEPROM writing
563       P:000156 P:000156 0C008F            JMP     <FINISH
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 11



564    
565                                 ; Load application code from P: memory into its proper locations
566       P:000157 P:000157 47DB00  LDAPPL    MOVE              X:(R3)+,Y1              ; Application number, not used yet
567       P:000158 P:000158 0D015A            JSR     <LOAD_APPLICATION
568       P:000159 P:000159 0C008F            JMP     <FINISH
569    
570                                 LOAD_APPLICATION
571       P:00015A P:00015A 60F400            MOVE              #$8000,R0               ; Starting EEPROM address
                            008000
572       P:00015C P:00015C 0D0178            JSR     <RD_WORD                          ; Number of words in boot code
573       P:00015D P:00015D 21A600            MOVE              B1,Y0
574       P:00015E P:00015E 479400            MOVE              X:<THREE,Y1
575       P:00015F P:00015F 2000B8            MPY     Y0,Y1,B
576       P:000160 P:000160 20002A            ASR     B
577       P:000161 P:000161 213000            MOVE              B0,R0                   ; EEPROM address of start of P: application
578       P:000162 P:000162 0AD06F            BSET    #15,R0                            ; To access EEPROM
579       P:000163 P:000163 0D0178            JSR     <RD_WORD                          ; Read number of words in application P:
580       P:000164 P:000164 61F400            MOVE              #(X_BOOT_START+1),R1    ; End of boot P: code that needs keeping
                            000228
581       P:000166 P:000166 06CD00            DO      B1,RD_APPL_P
                            000169
582       P:000168 P:000168 0D0178            JSR     <RD_WORD
583       P:000169 P:000169 07598D            MOVE              B1,P:(R1)+
584                                 RD_APPL_P
585       P:00016A P:00016A 0D0178            JSR     <RD_WORD                          ; Read number of words in application X:
586       P:00016B P:00016B 61F400            MOVE              #END_COMMAND_TABLE,R1
                            000036
587       P:00016D P:00016D 06CD00            DO      B1,RD_APPL_X
                            000170
588       P:00016F P:00016F 0D0178            JSR     <RD_WORD
589       P:000170 P:000170 555900            MOVE              B1,X:(R1)+
590                                 RD_APPL_X
591       P:000171 P:000171 0D0178            JSR     <RD_WORD                          ; Read number of words in application Y:
592       P:000172 P:000172 310100            MOVE              #1,R1                   ; There is no Y: memory in the boot code
593       P:000173 P:000173 06CD00            DO      B1,RD_APPL_Y
                            000176
594       P:000175 P:000175 0D0178            JSR     <RD_WORD
595       P:000176 P:000176 5D5900            MOVE                          B1,Y:(R1)+
596                                 RD_APPL_Y
597       P:000177 P:000177 00000C            RTS
598    
599                                 ; Read one word from EEPROM location R0 into accumulator B1
600       P:000178 P:000178 060380  RD_WORD   DO      #3,L_RDBYTE
                            00017B
601       P:00017A P:00017A 07D88B            MOVE              P:(R0)+,B2
602       P:00017B P:00017B 0C1C91            ASR     #8,B,B
603                                 L_RDBYTE
604       P:00017C P:00017C 00000C            RTS
605    
606                                 ; Come to here on a 'STP' command so 'DON' can be sent
607                                 STOP_IDLE_CLOCKING
608       P:00017D P:00017D 305A00            MOVE              #<TST_RCV,R0            ; Execution address when idle => when not
609       P:00017E P:00017E 601F00            MOVE              R0,X:<IDL_ADR           ;   processing commands or reading out
610       P:00017F P:00017F 0A0002            BCLR    #IDLMODE,X:<STATUS                ; Don't idle after readout
611       P:000180 P:000180 0C008F            JMP     <FINISH
612    
613                                 ; Routines executed after the DSP boots and initializes
614       P:000181 P:000181 305A00  STARTUP   MOVE              #<TST_RCV,R0            ; Execution address when idle => when not
615       P:000182 P:000182 601F00            MOVE              R0,X:<IDL_ADR           ;   processing commands or reading out
616       P:000183 P:000183 44F400            MOVE              #50000,X0               ; Delay by 500 milliseconds
                            00C350
617       P:000185 P:000185 06C400            DO      X0,L_DELAY
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 12



                            000188
618       P:000187 P:000187 06E8A3            REP     #1000
619       P:000188 P:000188 000000            NOP
620                                 L_DELAY
621       P:000189 P:000189 57F400            MOVE              #$020002,B              ; Normal reply after booting is 'SYR'
                            020002
622       P:00018B P:00018B 0D00EB            JSR     <XMT_WRD
623       P:00018C P:00018C 57F400            MOVE              #'SYR',B
                            535952
624       P:00018E P:00018E 0D00EB            JSR     <XMT_WRD
625    
626       P:00018F P:00018F 0C0054            JMP     <START                            ; Start normal command processing
627    
628                                 ; *******************  DSP  INITIALIZATION  CODE  **********************
629                                 ; This code initializes the DSP right after booting, and is overwritten
630                                 ;   by application code
631       P:000190 P:000190 08F4BD  INIT      MOVEP             #PLL_INIT,X:PCTL        ; Initialize PLL to 100 MHz
                            050003
632       P:000192 P:000192 000000            NOP
633    
634                                 ; Set operation mode register OMR to normal expanded
635       P:000193 P:000193 0500BA            MOVEC             #$0000,OMR              ; Operating Mode Register = Normal Expanded
636       P:000194 P:000194 0500BB            MOVEC             #0,SP                   ; Reset the Stack Pointer SP
637    
638                                 ; Program the AA = address attribute pins
639       P:000195 P:000195 08F4B9            MOVEP             #$FFFC21,X:AAR0         ; Y = $FFF000 to $FFFFFF asserts commands
                            FFFC21
640       P:000197 P:000197 08F4B8            MOVEP             #$008909,X:AAR1         ; P = $008000 to $00FFFF accesses the EEPROM
                            008909
641       P:000199 P:000199 08F4B7            MOVEP             #$010C11,X:AAR2         ; X = $010000 to $010FFF reads A/D values
                            010C11
642       P:00019B P:00019B 08F4B6            MOVEP             #$080621,X:AAR3         ; Y = $080000 to $0BFFFF R/W from SRAM
                            080621
643    
644                                 ; Program the DRAM memory access and addressing
645       P:00019D P:00019D 08F4BB            MOVEP             #$028FE1,X:BCR          ; Bus Control Register
                            028FE1
646    
647                                 ; Program the Host port B for parallel I/O
648       P:00019F P:00019F 08F484            MOVEP             #>1,X:HPCR              ; All pins enabled as GPIO
                            000001
649       P:0001A1 P:0001A1 08F489            MOVEP             #$810C,X:HDR
                            00810C
650       P:0001A3 P:0001A3 08F488            MOVEP             #$B10E,X:HDDR           ; Data Direction Register
                            00B10E
651                                                                                     ;  (1 for Output, 0 for Input)
652    
653                                 ; Port B conversion from software bits to schematic labels
654                                 ;       PB0 = PWROK             PB08 = PRSFIFO*
655                                 ;       PB1 = LED1              PB09 = EF*
656                                 ;       PB2 = LVEN              PB10 = EXT-IN0
657                                 ;       PB3 = HVEN              PB11 = EXT-IN1
658                                 ;       PB4 = STATUS0           PB12 = EXT-OUT0
659                                 ;       PB5 = STATUS1           PB13 = EXT-OUT1
660                                 ;       PB6 = STATUS2           PB14 = SSFHF*
661                                 ;       PB7 = STATUS3           PB15 = SELSCI
662    
663                                 ; Program the serial port ESSI0 = Port C for serial communication with
664                                 ;   the utility board
665       P:0001A5 P:0001A5 07F43F            MOVEP             #>0,X:PCRC              ; Software reset of ESSI0
                            000000
666       P:0001A7 P:0001A7 07F435            MOVEP             #$180809,X:CRA0         ; Divide 100 MHz by 20 to get 5.0 MHz
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 13



                            180809
667                                                                                     ; DC[4:0] = 0 for non-network operation
668                                                                                     ; WL0-WL2 = 3 for 24-bit data words
669                                                                                     ; SSC1 = 0 for SC1 not used
670       P:0001A9 P:0001A9 07F436            MOVEP             #$020020,X:CRB0         ; SCKD = 1 for internally generated clock
                            020020
671                                                                                     ; SCD2 = 0 so frame sync SC2 is an output
672                                                                                     ; SHFD = 0 for MSB shifted first
673                                                                                     ; FSL = 0, frame sync length not used
674                                                                                     ; CKP = 0 for rising clock edge transitions
675                                                                                     ; SYN = 0 for asynchronous
676                                                                                     ; TE0 = 1 to enable transmitter #0
677                                                                                     ; MOD = 0 for normal, non-networked mode
678                                                                                     ; TE0 = 0 to NOT enable transmitter #0 yet
679                                                                                     ; RE = 1 to enable receiver
680       P:0001AB P:0001AB 07F43F            MOVEP             #%111001,X:PCRC         ; Control Register (0 for GPIO, 1 for ESSI)
                            000039
681       P:0001AD P:0001AD 07F43E            MOVEP             #%000110,X:PRRC         ; Data Direction Register (0 for In, 1 for O
ut)
                            000006
682       P:0001AF P:0001AF 07F43D            MOVEP             #%000100,X:PDRC         ; Data Register - WR_ENA* = 1
                            000004
683    
684                                 ; Port C version = Analog boards
685                                 ;       MOVEP   #$000809,X:CRA0 ; Divide 100 MHz by 20 to get 5.0 MHz
686                                 ;       MOVEP   #$000030,X:CRB0 ; SCKD = 1 for internally generated clock
687                                 ;       MOVEP   #%100000,X:PCRC ; Control Register (0 for GPIO, 1 for ESSI)
688                                 ;       MOVEP   #%000100,X:PRRC ; Data Direction Register (0 for In, 1 for Out)
689                                 ;       MOVEP   #%000000,X:PDRC ; Data Register: 'not used' = 0 outputs
690    
691       P:0001B1 P:0001B1 07F43C            MOVEP             #0,X:TX00               ; Initialize the transmitter to zero
                            000000
692       P:0001B3 P:0001B3 000000            NOP
693       P:0001B4 P:0001B4 000000            NOP
694       P:0001B5 P:0001B5 013630            BSET    #TE,X:CRB0                        ; Enable the SSI transmitter
695    
696                                 ; Conversion from software bits to schematic labels for Port C
697                                 ;       PC0 = SC00 = UTL-T-SCK
698                                 ;       PC1 = SC01 = 2_XMT = SYNC on prototype
699                                 ;       PC2 = SC02 = WR_ENA*
700                                 ;       PC3 = SCK0 = TIM-U-SCK
701                                 ;       PC4 = SRD0 = UTL-T-STD
702                                 ;       PC5 = STD0 = TIM-U-STD
703    
704                                 ; Program the serial port ESSI1 = Port D for serial transmission to
705                                 ;   the analog boards and two parallel I/O input pins
706       P:0001B6 P:0001B6 07F42F            MOVEP             #>0,X:PCRD              ; Software reset of ESSI0
                            000000
707       P:0001B8 P:0001B8 07F425            MOVEP             #$000809,X:CRA1         ; Divide 100 MHz by 20 to get 5.0 MHz
                            000809
708                                                                                     ; DC[4:0] = 0
709                                                                                     ; WL[2:0] = ALC = 0 for 8-bit data words
710                                                                                     ; SSC1 = 0 for SC1 not used
711       P:0001BA P:0001BA 07F426            MOVEP             #$000030,X:CRB1         ; SCKD = 1 for internally generated clock
                            000030
712                                                                                     ; SCD2 = 1 so frame sync SC2 is an output
713                                                                                     ; SHFD = 0 for MSB shifted first
714                                                                                     ; CKP = 0 for rising clock edge transitions
715                                                                                     ; TE0 = 0 to NOT enable transmitter #0 yet
716                                                                                     ; MOD = 0 so its not networked mode
717       P:0001BC P:0001BC 07F42F            MOVEP             #%100000,X:PCRD         ; Control Register (0 for GPIO, 1 for ESSI)
                            000020
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 14



718                                                                                     ; PD3 = SCK1, PD5 = STD1 for ESSI
719       P:0001BE P:0001BE 07F42E            MOVEP             #%000100,X:PRRD         ; Data Direction Register (0 for In, 1 for O
ut)
                            000004
720       P:0001C0 P:0001C0 07F42D            MOVEP             #%000100,X:PDRD         ; Data Register: 'not used' = 0 outputs
                            000004
721       P:0001C2 P:0001C2 07F42C            MOVEP             #0,X:TX10               ; Initialize the transmitter to zero
                            000000
722       P:0001C4 P:0001C4 000000            NOP
723       P:0001C5 P:0001C5 000000            NOP
724       P:0001C6 P:0001C6 012630            BSET    #TE,X:CRB1                        ; Enable the SSI transmitter
725    
726                                 ; Conversion from software bits to schematic labels for Port D
727                                 ; PD0 = SC10 = 2_XMT_? input
728                                 ; PD1 = SC11 = SSFEF* input
729                                 ; PD2 = SC12 = PWR_EN
730                                 ; PD3 = SCK1 = TIM-A-SCK
731                                 ; PD4 = SRD1 = PWRRST
732                                 ; PD5 = STD1 = TIM-A-STD
733    
734                                 ; Program the SCI port to communicate with the utility board
735       P:0001C7 P:0001C7 07F41C            MOVEP             #$0B04,X:SCR            ; SCI programming: 11-bit asynchronous
                            000B04
736                                                                                     ;   protocol (1 start, 8 data, 1 even parity
,
737                                                                                     ;   1 stop); LSB before MSB; enable receiver
738                                                                                     ;   and its interrupts; transmitter interrup
ts
739                                                                                     ;   disabled.
740       P:0001C9 P:0001C9 07F41B            MOVEP             #$0003,X:SCCR           ; SCI clock: utility board data rate =
                            000003
741                                                                                     ;   (390,625 kbits/sec); internal clock.
742       P:0001CB P:0001CB 07F41F            MOVEP             #%011,X:PCRE            ; Port Control Register = RXD, TXD enabled
                            000003
743       P:0001CD P:0001CD 07F41E            MOVEP             #%000,X:PRRE            ; Port Direction Register (0 = Input)
                            000000
744    
745                                 ;       PE0 = RXD
746                                 ;       PE1 = TXD
747                                 ;       PE2 = SCLK
748    
749                                 ; Program one of the three timers as an exposure timer
750       P:0001CF P:0001CF 07F403            MOVEP             #$C34F,X:TPLR           ; Prescaler to generate millisecond timer,
                            00C34F
751                                                                                     ;  counting from the system clock / 2 = 50 M
Hz
752       P:0001D1 P:0001D1 07F40F            MOVEP             #$208200,X:TCSR0        ; Clear timer complete bit and enable presca
ler
                            208200
753       P:0001D3 P:0001D3 07F40E            MOVEP             #0,X:TLR0               ; Timer load register
                            000000
754    
755                                 ; Enable interrupts for the SCI port only
756       P:0001D5 P:0001D5 08F4BF            MOVEP             #$000000,X:IPRC         ; No interrupts allowed
                            000000
757       P:0001D7 P:0001D7 08F4BE            MOVEP             #>$80,X:IPRP            ; Enable SCI interrupt only, IPR = 1
                            000080
758       P:0001D9 P:0001D9 00FCB8            ANDI    #$FC,MR                           ; Unmask all interrupt levels
759    
760                                 ; Initialize the fiber optic serial receiver circuitry
761       P:0001DA P:0001DA 061480            DO      #20,L_FO_INIT
                            0001DF
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 15



762       P:0001DC P:0001DC 5FF000            MOVE                          Y:RDFO,B
                            FFFFF1
763       P:0001DE P:0001DE 0605A0            REP     #5
764       P:0001DF P:0001DF 000000            NOP
765                                 L_FO_INIT
766    
767                                 ; Pulse PRSFIFO* low to revive the CMDRST* instruction and reset the FIFO
768       P:0001E0 P:0001E0 44F400            MOVE              #1000000,X0             ; Delay by 10 milliseconds
                            0F4240
769       P:0001E2 P:0001E2 06C400            DO      X0,*+3
                            0001E4
770       P:0001E4 P:0001E4 000000            NOP
771       P:0001E5 P:0001E5 0A8908            BCLR    #8,X:HDR
772       P:0001E6 P:0001E6 0614A0            REP     #20
773       P:0001E7 P:0001E7 000000            NOP
774       P:0001E8 P:0001E8 0A8928            BSET    #8,X:HDR
775    
776                                 ; Reset the utility board
777       P:0001E9 P:0001E9 0A0F05            BCLR    #5,X:<LATCH
778       P:0001EA P:0001EA 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Clear reset utility board bit
                            00000F
779       P:0001EC P:0001EC 06C8A0            REP     #200                              ; Delay by RESET* low time
780       P:0001ED P:0001ED 000000            NOP
781       P:0001EE P:0001EE 0A0F25            BSET    #5,X:<LATCH
782       P:0001EF P:0001EF 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Clear reset utility board bit
                            00000F
783       P:0001F1 P:0001F1 56F400            MOVE              #200000,A               ; Delay 2 msec for utility boot
                            030D40
784       P:0001F3 P:0001F3 06CE00            DO      A,*+3
                            0001F5
785       P:0001F5 P:0001F5 000000            NOP
786    
787                                 ; Put all the analog switch inputs to low so they draw minimum current
788       P:0001F6 P:0001F6 012F23            BSET    #3,X:PCRD                         ; Turn the serial clock on
789       P:0001F7 P:0001F7 56F400            MOVE              #$0C3000,A              ; Value of integrate speed and gain switches
                            0C3000
790       P:0001F9 P:0001F9 20001B            CLR     B
791       P:0001FA P:0001FA 241000            MOVE              #$100000,X0             ; Increment over board numbers for DAC write
s
792       P:0001FB P:0001FB 45F400            MOVE              #$001000,X1             ; Increment over board numbers for WRSS writ
es
                            001000
793       P:0001FD P:0001FD 060F80            DO      #15,L_ANALOG                      ; Fifteen video processor boards maximum
                            000205
794       P:0001FF P:0001FF 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
795       P:000200 P:000200 200040            ADD     X0,A
796       P:000201 P:000201 5F7000            MOVE                          B,Y:WRSS    ; This is for the fast analog switches
                            FFFFF3
797       P:000203 P:000203 0620A3            REP     #800                              ; Delay for the serial data transmission
798       P:000204 P:000204 000000            NOP
799       P:000205 P:000205 200068            ADD     X1,B                              ; Increment the video and clock driver numbe
rs
800                                 L_ANALOG
801       P:000206 P:000206 0A0F00            BCLR    #CDAC,X:<LATCH                    ; Enable clearing of DACs
802       P:000207 P:000207 0A0F02            BCLR    #ENCK,X:<LATCH                    ; Disable clock and DAC output switches
803       P:000208 P:000208 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Execute these two operations
                            00000F
804       P:00020A P:00020A 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
805       P:00020B P:00020B 0C0220            JMP     <SKIP
806    
807                                 ; Transmit contents of accumulator A1 over the synchronous serial transmitter
808                                 XMIT_A_WORD
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 16



809       P:00020C P:00020C 547000            MOVE              A1,X:SV_A1
                            00000E
810       P:00020E P:00020E 01A786            JCLR    #TDE,X:SSISR1,*                   ; Start bit
                            00020E
811       P:000210 P:000210 07F42C            MOVEP             #$010000,X:TX10
                            010000
812       P:000212 P:000212 060380            DO      #3,L_XMIT
                            000218
813       P:000214 P:000214 01A786            JCLR    #TDE,X:SSISR1,*                   ; Three data bytes
                            000214
814       P:000216 P:000216 04CCCC            MOVEP             A1,X:TX10
815       P:000217 P:000217 0C1E90            LSL     #8,A
816       P:000218 P:000218 000000            NOP
817                                 L_XMIT
818       P:000219 P:000219 01A786            JCLR    #TDE,X:SSISR1,*                   ; Zeroes to bring transmitter low
                            000219
819       P:00021B P:00021B 07F42C            MOVEP             #0,X:TX10
                            000000
820       P:00021D P:00021D 54F000            MOVE              X:SV_A1,A1
                            00000E
821       P:00021F P:00021F 00000C            RTS
822    
823                                 SKIP
824    
825                                 ; Set up the circular SCI buffer, 32 words in size
826       P:000220 P:000220 64F400            MOVE              #SCI_TABLE,R4
                            000400
827       P:000222 P:000222 051FA4            MOVE              #31,M4
828       P:000223 P:000223 647000            MOVE              R4,X:(SCI_TABLE+33)
                            000421
829    
830                                           IF      @SCP("HOST","ROM")
838                                           ENDIF
839    
840       P:000225 P:000225 44F400            MOVE              #>$AC,X0
                            0000AC
841       P:000227 P:000227 440100            MOVE              X0,X:<FO_HDR
842    
843       P:000228 P:000228 0C0181            JMP     <STARTUP
844    
845                                 ;  ****************  X: Memory tables  ********************
846    
847                                 ; Define the address in P: space where the table of constants begins
848    
849                                  X_BOOT_START
850       000227                              EQU     @LCV(L)-2
851    
852                                           IF      @SCP("HOST","ROM")
854                                           ENDIF
855                                           IF      @SCP("HOST","HOST")
856       X:000000 X:000000                   ORG     X:0,X:0
857                                           ENDIF
858    
859                                 ; Special storage area - initialization constants and scratch space
860       X:000000 X:000000         STATUS    DC      $18000                            ; Controller status bits
861                                                                                     ; Correlated double sample (#15)
862                                                                                     ; Turn READ on and off (#16)
863    
864       000001                    FO_HDR    EQU     STATUS+1                          ; Fiber optic write bytes
865       000005                    HEADER    EQU     FO_HDR+4                          ; Command header
866       000006                    NWORDS    EQU     HEADER+1                          ; Number of words in the command
867       000007                    COM_BUF   EQU     NWORDS+1                          ; Command buffer
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 17



868       00000E                    SV_A1     EQU     COM_BUF+7                         ; Save accumulator A1
869    
870                                           IF      @SCP("HOST","ROM")
875                                           ENDIF
876    
877                                           IF      @SCP("HOST","HOST")
878       X:00000F X:00000F                   ORG     X:$F,X:$F
879                                           ENDIF
880    
881                                 ; Parameter table in P: space to be copied into X: space during
882                                 ;   initialization, and is copied from ROM by the DSP boot
883       X:00000F X:00000F         LATCH     DC      $7A                               ; Starting value in latch chip U25
884                                  EXPOSURE_TIME
885       X:000010 X:000010                   DC      0                                 ; Exposure time in milliseconds
886                                  ELAPSED_TIME
887       X:000011 X:000011                   DC      0                                 ; Time elapsed so far in the exposure
888       X:000012 X:000012         ONE       DC      1                                 ; One
889       X:000013 X:000013         TWO       DC      2                                 ; Two
890       X:000014 X:000014         THREE     DC      3                                 ; Three
891       X:000015 X:000015         SEVEN     DC      7                                 ; Seven
892       X:000016 X:000016         MASK1     DC      $FCFCF8                           ; Mask for checking header
893       X:000017 X:000017         MASK2     DC      $030300                           ; Mask for checking header
894       X:000018 X:000018         DONE      DC      'DON'                             ; Standard reply
895       X:000019 X:000019         SBRD      DC      $020000                           ; Source Identification number
896       X:00001A X:00001A         TIM_DRB   DC      $000200                           ; Destination = timing board number
897       X:00001B X:00001B         DMASK     DC      $00FF00                           ; Mask to get destination board number
898       X:00001C X:00001C         SMASK     DC      $FF0000                           ; Mask to get source board number
899       X:00001D X:00001D         ERR       DC      'ERR'                             ; An error occurred
900       X:00001E X:00001E         C100K     DC      100000                            ; Delay for WRROM = 1 millisec
901       X:00001F X:00001F         IDL_ADR   DC      TST_RCV                           ; Address of idling routine
902       X:000020 X:000020         EXP_ADR   DC      0                                 ; Jump to this address during exposures
903    
904                                 ; Places for saving register values
905       X:000021 X:000021         SAVE_SR   DC      0                                 ; Status Register
906       X:000022 X:000022         SAVE_X1   DC      0
907       X:000023 X:000023         SAVE_A1   DC      0
908       X:000024 X:000024         SAVE_R0   DC      0
909       X:000025 X:000025         RCV_ERR   DC      0
910       X:000026 X:000026         SCI_A1    DC      0                                 ; Contents of accumulator A1 in RCV ISR
911       X:000027 X:000027         SCI_R0    DC      SRXL
912    
913                                 ; Command table
914       000028                    COM_TBL_R EQU     @LCV(R)
915       X:000028 X:000028         COM_TBL   DC      'TDL',TDL                         ; Test Data Link
916       X:00002A X:00002A                   DC      'RDM',RDMEM                       ; Read from DSP or EEPROM memory
917       X:00002C X:00002C                   DC      'WRM',WRMEM                       ; Write to DSP memory
918       X:00002E X:00002E                   DC      'LDA',LDAPPL                      ; Load application from EEPROM to DSP
919       X:000030 X:000030                   DC      'STP',STOP_IDLE_CLOCKING
920       X:000032 X:000032                   DC      'DON',START                       ; Nothing special
921       X:000034 X:000034                   DC      'ERR',START                       ; Nothing special
922    
923                                  END_COMMAND_TABLE
924       000036                              EQU     @LCV(R)
925    
926                                 ; The table at SCI_TABLE is for words received from the utility board, written by
927                                 ;   the interrupt service routine SCI_RCV. Note that it is 32 words long,
928                                 ;   hard coded, and the 33rd location contains the pointer to words that have
929                                 ;   been processed by moving them from the SCI_TABLE to the COM_BUF.
930    
931                                           IF      @SCP("HOST","ROM")
933                                           ENDIF
934    
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timboot.asm  Page 18



935       000036                    END_ADR   EQU     @LCV(L)                           ; End address of P: code written to ROM
936    
937       P:000229 P:000229                   ORG     P:,P:
938    
939       100012                    CC        EQU     IRREV4+TIMREV5+CONT_RD
940    
941    
942                                 ; Put number of words of application in P: for loading application from EEPROM
943       P:000229 P:000229                   DC      TIMBOOT_X_MEMORY-@LCV(L)-1
944    
945                                 ;  Reset entire array and don't transmit any pixel data
946                                 RESET_ARRAY
947       P:00022A P:00022A 303B00            MOVE              #<READ_ON,R0            ; Turn Read ON
948       P:00022B P:00022B 0D03D5            JSR     <CLOCK
949       P:00022C P:00022C 304100            MOVE              #<INIT_FRAME,R0
950       P:00022D P:00022D 0D03D5            JSR     <CLOCK
951    
952       P:00022E P:00022E 064080            DO      #64,END_FRAME
                            000238
953       P:000230 P:000230 304600            MOVE              #<SHIFT_RESET_ODD_ROW,R0
954       P:000231 P:000231 0D03D5            JSR     <CLOCK
955                                 ;JDM dont reset each pixel
956                                 ;       DO      #64,L_ODD
957                                 ;       MOVE    #<SHIFT_PIXELS,R0
958                                 ;       JSR     <CLOCK
959                                 ;       NOP
960                                 L_ODD
961       P:000232 P:000232 304D00            MOVE              #<SHIFT_RESET_EVEN_ROW,R0
962       P:000233 P:000233 0D03D5            JSR     <CLOCK
963                                 ;JDM dont reset each pixel
964                                 ;       DO      #64,L_EVEN
965                                 ;       MOVE    #<SHIFT_PIXELS,R0
966                                 ;       JSR     <CLOCK
967                                 ;       NOP
968                                 L_EVEN
969       P:000234 P:000234 0BE580            JSR     (R5)                              ; Check for incoming command if in
970       P:000235 P:000235 0E0238            JCC     <NOT_COMMAND                      ;  continuous reset mode
971       P:000236 P:000236 00008C            ENDDO                                     ; If there is an incoming command then
972       P:000237 P:000237 0C023D            JMP     <RST_END                          ;  exit continuous mode and return
973                                 NOT_COMMAND
974       P:000238 P:000238 000000            NOP
975       P:000239 P:000239 000000  END_FRAME NOP
976       P:00023A P:00023A 303B00            MOVE              #<READ_ON,R0            ; Turn Read OFF
977       P:00023B P:00023B 0D03D5            JSR     <CLOCK
978       P:00023C P:00023C 00000C            RTS                                       ; Return from subroutine call
979    
980       P:00023D P:00023D 303B00  RST_END   MOVE              #<READ_ON,R0            ; Turn Read OFF
981       P:00023E P:00023E 0D03D5            JSR     <CLOCK
982       P:00023F P:00023F 0AF960            BSET    #0,SR                             ; Set carry bit to indicate command was rece
ived
983       P:000240 P:000240 000000            NOP
984       P:000241 P:000241 00000C            RTS
985    
986                                 ; Dummy subroutine to not call receiver checking routine
987       P:000242 P:000242 0AF940  NO_CHK    BCLR    #0,SR                             ; Clear status register clear bit
988       P:000243 P:000243 000000            NOP
989       P:000244 P:000244 00000C            RTS
990    
991                                 ; Continuously reset array, checking for host commands every line
992                                 CONT_RST
993       P:000245 P:000245 330700            MOVE              #<COM_BUF,R3
994       P:000246 P:000246 35A500            MOVE              #<GET_RCV,R5
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  tim.asm  Page 19



995       P:000247 P:000247 0D022A            JSR     <RESET_ARRAY
996       P:000248 P:000248 0E805D            JCS     <PRC_RCV                          ; Process the command if its there
997       P:000249 P:000249 0C0245            JMP     <CONT_RST
998    
999                                 ;  ***********************   ARRAY READOUT   ********************
1000                                RD_ARRAY
1001      P:00024A P:00024A 0D03C4            JSR     <PCI_READ_IMAGE                   ; Wake up the PCI interface board
1002      P:00024B P:00024B 0A00AA            JSET    #TST_IMG,X:STATUS,SYNTHETIC_IMAGE
                            0003AC
1003   
1004      P:00024D P:00024D 0A0090            JCLR    #ST_RD,X:<STATUS,C_RD
                            000255
1005      P:00024F P:00024F 303B00            MOVE              #<READ_ON,R0            ; Turn the PICNIC 'READ' line ON
1006      P:000250 P:000250 0D03D5            JSR     <CLOCK
1007      P:000251 P:000251 065882            DO      #600,DLY_ON                       ; Wait 5 msec for the signal to settle
                            000254
1008      P:000253 P:000253 0D03E0            JSR     <PAL_DLY
1009      P:000254 P:000254 000000            NOP
1010                                DLY_ON
1011   
1012                                ; Compute NXLOOP and NYLOOP including the number of readout channels
1013      P:000255 P:000255 5E8F00  C_RD      MOVE                          Y:<OS,A
1014      P:000256 P:000256 0140C5            CMP     #'ALL',A
                            414C4C
1015      P:000258 P:000258 0E2265            JNE     <ONE_RD
1016      P:000259 P:000259 5E8200            MOVE                          Y:<NROWS,A  ; Read from all four corners
1017      P:00025A P:00025A 200023            LSR     A
1018      P:00025B P:00025B 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS1
                            00025F
1019      P:00025D P:00025D 200023            LSR     A                                 ; If CDS read only half of NROWS at a time
1020      P:00025E P:00025E 000000            NOP
1021      P:00025F P:00025F 5C1100  NO_CDS1   MOVE                          A1,Y:<NYLOOP
1022      P:000260 P:000260 5E8100            MOVE                          Y:<NCOLS,A
1023      P:000261 P:000261 200023            LSR     A
1024      P:000262 P:000262 000000            NOP
1025      P:000263 P:000263 5C1000            MOVE                          A1,Y:<NXLOOP
1026      P:000264 P:000264 0C026D            JMP     <RDFRAME
1027   
1028                                ; Dimensions for reading from just one quadrant
1029      P:000265 P:000265 5E8200  ONE_RD    MOVE                          Y:<NROWS,A
1030      P:000266 P:000266 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS2
                            00026A
1031      P:000268 P:000268 200023            LSR     A                                 ; If CDS read only half of NROWS at a time
1032      P:000269 P:000269 000000            NOP
1033      P:00026A P:00026A 5C1100  NO_CDS2   MOVE                          A1,Y:<NYLOOP
1034      P:00026B P:00026B 4C8100            MOVE                          Y:<NCOLS,X0
1035      P:00026C P:00026C 4C1000            MOVE                          X0,Y:<NXLOOP
1036   
1037                                ; Initialize the reading of the frame
1038      P:00026D P:00026D 304100  RDFRAME   MOVE              #<INIT_FRAME,R0
1039      P:00026E P:00026E 0D03D5            JSR     <CLOCK
1040   
1041                                ; Skip over Y:ROW_OFFSET rows, keeping track of even/odd effects
1042      P:00026F P:00026F 0A0D60            BSET    #0,Y:<ODD_ROW
1043      P:000270 P:000270 5E8400            MOVE                          Y:<ROW_OFFSET,A
1044      P:000271 P:000271 200003            TST     A
1045      P:000272 P:000272 0EF280            JLE     <WHOLE_FRAME
1046      P:000273 P:000273 305A00  ROWSKIP   MOVE              #<SHIFT_ODD_ROW,R0
1047      P:000274 P:000274 0D03D5            JSR     <CLOCK
1048      P:000275 P:000275 0B0D40            BCHG    #0,Y:<ODD_ROW
1049      P:000276 P:000276 014184            SUB     #1,A
1050      P:000277 P:000277 200003            TST     A
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  tim.asm  Page 20



1051      P:000278 P:000278 0EA282            JEQ     <READOUT
1052      P:000279 P:000279 305400            MOVE              #<SHIFT_EVEN_ROW,R0
1053      P:00027A P:00027A 0D03D5            JSR     <CLOCK
1054      P:00027B P:00027B 0B0D40            BCHG    #0,Y:<ODD_ROW
1055      P:00027C P:00027C 014184            SUB     #1,A
1056      P:00027D P:00027D 200003            TST     A
1057      P:00027E P:00027E 0EA282            JEQ     <READOUT
1058      P:00027F P:00027F 0C0273            JMP     <ROWSKIP
1059   
1060                                WHOLE_FRAME
1061      P:000280 P:000280 305A00            MOVE              #<SHIFT_ODD_ROW,R0
1062      P:000281 P:000281 0D03D5            JSR     <CLOCK
1063   
1064      P:000282 P:000282 5E9100  READOUT   MOVE                          Y:<NYLOOP,A
1065                                NXT_ROW                                             ;   REMOVE JDMFIX?        BCHG  #0,Y:<ODD_RO
W
1066   
1067      P:000283 P:000283 0A0E40            BCLR    #0,Y:<ODD_COL
1068      P:000284 P:000284 5F8300            MOVE                          Y:<COL_OFFSET,B
1069      P:000285 P:000285 20000B            TST     B
1070      P:000286 P:000286 0EF2AA            JLE     <WHOLE_ROW
1071      P:000287 P:000287 0A898E  COLSKIP   JCLR    #SSFHF,X:HDR,*                    ; Only write to FIFO if < half full
                            000287
1072      P:000289 P:000289 09F4B3            MOVEP             #(CLK3+DELAY+H_PIXEL),Y:WRSS
                            083001
1073      P:00028B P:00028B 0B0E40            BCHG    #0,Y:<ODD_COL
1074      P:00028C P:00028C 01418C            SUB     #1,B
1075      P:00028D P:00028D 20000B            TST     B
1076      P:00028E P:00028E 0EF296            JLE     <RD_PXLS
1077      P:00028F P:00028F 09F4B3            MOVEP             #(CLK3+DELAY+L_PIXEL),Y:WRSS
                            083000
1078      P:000291 P:000291 0B0E40            BCHG    #0,Y:<ODD_COL
1079      P:000292 P:000292 01418C            SUB     #1,B
1080      P:000293 P:000293 20000B            TST     B
1081      P:000294 P:000294 0EF296            JLE     <RD_PXLS
1082      P:000295 P:000295 0C0287            JMP     <COLSKIP
1083   
1084      P:000296 P:000296 5F9000  RD_PXLS   MOVE                          Y:<NXLOOP,B
1085      P:000297 P:000297 0A0EE0  RD_LINE   JSET    #0,Y:<ODD_COL,O_COL
                            00029E
1086      P:000299 P:000299 0A898E            JCLR    #SSFHF,X:HDR,*
                            000299
1087      P:00029B P:00029B 09F4B3            MOVEP             #(CLK3+DELAY+H_PIXEL),Y:WRSS
                            083001
1088      P:00029D P:00029D 0C02A0            JMP     <RD_PXL
1089      P:00029E P:00029E 09F4B3  O_COL     MOVEP             #(CLK3+DELAY+L_PIXEL),Y:WRSS
                            083000
1090   
1091      P:0002A0 P:0002A0 0B0E40  RD_PXL    BCHG    #0,Y:<ODD_COL
1092      P:0002A1 P:0002A1 060540            DO      Y:<NUM_RDS,RD_PXL0
                            0002A5
1093      P:0002A3 P:0002A3 306E00            MOVE              #<READ_PIXEL,R0
1094      P:0002A4 P:0002A4 0D03D5            JSR     <CLOCK
1095      P:0002A5 P:0002A5 01418C            SUB     #1,B
1096      P:0002A6 P:0002A6 000000  RD_PXL0   NOP
1097      P:0002A7 P:0002A7 20000B            TST     B
1098      P:0002A8 P:0002A8 0E7297            JGT     <RD_LINE
1099      P:0002A9 P:0002A9 0C02B2            JMP     <END_LINE
1100   
1101                                ; Read out the entire row
1102                                WHOLE_ROW
1103      P:0002AA P:0002AA 5F9000            MOVE                          Y:<NXLOOP,B
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  tim.asm  Page 21



1104      P:0002AB P:0002AB 20002B            LSR     B
1105      P:0002AC P:0002AC 000000            NOP                                       ; SHIFT_READ_PIXELS processes two pixels
1106      P:0002AD P:0002AD 06CD00            DO      B1,RD_PIX0                        ;   each time it is called
                            0002B1
1107      P:0002AF P:0002AF 306000            MOVE              #<SHIFT_READ_PIXELS,R0
1108      P:0002B0 P:0002B0 0D03D5            JSR     <CLOCK
1109      P:0002B1 P:0002B1 000000            NOP
1110                                RD_PIX0
1111   
1112                                END_LINE
1113      P:0002B2 P:0002B2 014184            SUB     #1,A                              ; A = ROW number down counter
1114      P:0002B3 P:0002B3 200003            TST     A
1115      P:0002B4 P:0002B4 0EA2BF            JEQ     <READ_END
1116      P:0002B5 P:0002B5 0A0DE0            JSET    #0,Y:<ODD_ROW,ODD
                            0002BB
1117   
1118                                ; Shift either and odd or an even row number depending on where we are
1119      P:0002B7 P:0002B7 305400  EVEN      MOVE              #<SHIFT_EVEN_ROW,R0
1120      P:0002B8 P:0002B8 0D03D5            JSR     <CLOCK
1121      P:0002B9 P:0002B9 0B0D40            BCHG    #0,Y:<ODD_ROW                     ; flip odd_row back to cancel next line JDMF
IX?
1122      P:0002BA P:0002BA 0C0283            JMP     <NXT_ROW
1123      P:0002BB P:0002BB 305A00  ODD       MOVE              #<SHIFT_ODD_ROW,R0
1124      P:0002BC P:0002BC 0D03D5            JSR     <CLOCK
1125      P:0002BD P:0002BD 0B0D40            BCHG    #0,Y:<ODD_ROW                     ; flip odd_row back to cancel next line JDMF
IX?
1126      P:0002BE P:0002BE 0C0283            JMP     <NXT_ROW
1127   
1128                                READ_END
1129                                ; JDM 2005Sep14  Fix from Leach to elinminate the mysteroous 10ms frametime delay
1130                                ;  Here we comment out the next 3 lines
1131                                ;       MOVE    #<SXMIT_EIGHT_PIXELS,R0
1132                                ;       JSR     <CLOCK
1133                                ;       NOP
1134   
1135      P:0002BF P:0002BF 0A0090            JCLR    #ST_RD,X:<STATUS,NO_RD
                            0002C3
1136      P:0002C1 P:0002C1 303B00            MOVE              #<READ_ON,R0            ; Turn the PICNIC Read line OFF
1137      P:0002C2 P:0002C2 0D03D5            JSR     <CLOCK
1138                                NO_RD
1139   
1140                                ; We're all done with the readout, so return
1141      P:0002C3 P:0002C3 00000C            RTS
1142   
1143                                ; ******  Minclude many routines not directly needed for readout  *******
1144                                          INCLUDE "timIRmisc.asm"
1145                                ; Miscellaneous IR array control routines, customized for John Monnier
1146   
1147                                POWER_OFF
1148      P:0002C4 P:0002C4 0D02F6            JSR     <CLEAR_SWITCHES                   ; Clear switches and DACs
1149      P:0002C5 P:0002C5 0A8922            BSET    #LVEN,X:HDR
1150      P:0002C6 P:0002C6 0A8923            BSET    #HVEN,X:HDR
1151      P:0002C7 P:0002C7 0C008F            JMP     <FINISH
1152   
1153                                ; Start power-on cycle
1154                                POWER_ON
1155      P:0002C8 P:0002C8 0D02F6            JSR     <CLEAR_SWITCHES                   ; Clear all analog switches
1156      P:0002C9 P:0002C9 0D02D5            JSR     <PON                              ; Turn on the power control board
1157      P:0002CA P:0002CA 0A8980            JCLR    #PWROK,X:HDR,PWR_ERR              ; Test if the power turned on properly
                            0002D2
1158      P:0002CC P:0002CC 305A00            MOVE              #TST_RCV,R0             ; For testing only, don't reset array
1159      P:0002CD P:0002CD 601F00            MOVE              R0,X:<IDL_ADR
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 22



1160      P:0002CE P:0002CE 60F400            MOVE              #CONT_RST,R0            ; Put controller in continuous readout
                            000245
1161      P:0002D0 P:0002D0 601F00            MOVE              R0,X:<IDL_ADR           ;   state
1162      P:0002D1 P:0002D1 0C008F            JMP     <FINISH
1163   
1164                                ; The power failed to turn on because of an error on the power control board
1165      P:0002D2 P:0002D2 0A8922  PWR_ERR   BSET    #LVEN,X:HDR                       ; Turn off the low voltage emable line
1166      P:0002D3 P:0002D3 0A8923            BSET    #HVEN,X:HDR                       ; Turn off the high voltage emable line
1167      P:0002D4 P:0002D4 0C008D            JMP     <ERROR
1168   
1169                                ; Now ramp up the low voltages (+/- 6.5V, 16.5V) and delay them to turn on
1170      P:0002D5 P:0002D5 0A0F20  PON       BSET    #CDAC,X:<LATCH                    ; Disable clearing of DACs
1171      P:0002D6 P:0002D6 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Write it to the hardware
                            00000F
1172      P:0002D8 P:0002D8 0A8902            BCLR    #LVEN,X:HDR                       ; LVEN = Low => Turn on +/- 6.5V,
1173      P:0002D9 P:0002D9 5E8900            MOVE                          Y:<PWR_DLY,A ;   +/- 16.5V
1174      P:0002DA P:0002DA 0D0469            JSR     <MILLISEC_DELAY
1175   
1176                                ; Write all the bias voltages to the DACs
1177                                SET_BIASES
1178      P:0002DB P:0002DB 012F23            BSET    #3,X:PCRD                         ; Turn on the serial clock
1179      P:0002DC P:0002DC 0A0F01            BCLR    #1,X:<LATCH                       ; Separate updates of clock driver
1180      P:0002DD P:0002DD 302100            MOVE              #<ZERO_BIASES,R0        ; Get starting address of DAC values
1181      P:0002DE P:0002DE 0D0463            JSR     <SET_DAC                          ; Write it to the hardware
1182      P:0002DF P:0002DF 569400            MOVE              X:<THREE,A
1183      P:0002E0 P:0002E0 0D0469            JSR     <MILLISEC_DELAY
1184      P:0002E1 P:0002E1 0A0F22            BSET    #ENCK,X:<LATCH                    ; Enable clock and DAC output switches
1185      P:0002E2 P:0002E2 09F0B5            MOVEP             X:LATCH,Y:WRLATCH
                            00000F
1186   
1187                                ; Turn on Vdd = digital power unit cell to the IR array
1188      P:0002E4 P:0002E4 5EF000            MOVE                          Y:VDD,A     ; pin #5 = Vdd = array digital power
                            00001F
1189      P:0002E6 P:0002E6 0D020C            JSR     XMIT_A_WORD
1190      P:0002E7 P:0002E7 5E8A00            MOVE                          Y:<VDD_DLY,A ; Delay for the IR array to settle
1191      P:0002E8 P:0002E8 0D0469            JSR     <MILLISEC_DELAY
1192   
1193      P:0002E9 P:0002E9 301600            MOVE              #<DC_BIASES,R0          ; Get starting address of DAC values
1194      P:0002EA P:0002EA 0D0463            JSR     <SET_DAC
1195      P:0002EB P:0002EB 569400            MOVE              X:<THREE,A              ; Delay three millisec to settle
1196      P:0002EC P:0002EC 0D0469            JSR     <MILLISEC_DELAY
1197   
1198                                ; Set clock driver DACs
1199      P:0002ED P:0002ED 302E00            MOVE              #<DACS,R0               ; Get starting address of DAC values
1200      P:0002EE P:0002EE 0D0463            JSR     <SET_DAC
1201      P:0002EF P:0002EF 0D03E0            JSR     <PAL_DLY
1202   
1203                                ; Turn continuous reset mode on, disable the SSI, and return
1204      P:0002F0 P:0002F0 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1205      P:0002F1 P:0002F1 00000C            RTS
1206   
1207                                SET_BIAS_VOLTAGES
1208      P:0002F2 P:0002F2 0D02DB            JSR     <SET_BIASES
1209      P:0002F3 P:0002F3 0C008F            JMP     <FINISH
1210   
1211      P:0002F4 P:0002F4 0D02F6  CLR_SWS   JSR     <CLEAR_SWITCHES
1212      P:0002F5 P:0002F5 0C008F            JMP     <FINISH
1213   
1214                                CLEAR_SWITCHES
1215      P:0002F6 P:0002F6 012F23            BSET    #3,X:PCRD                         ; Turn the serial clock on
1216      P:0002F7 P:0002F7 56F400            MOVE              #$0C3000,A              ; Value of integrate speed and gain switches
                            0C3000
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 23



1217      P:0002F9 P:0002F9 20001B            CLR     B
1218      P:0002FA P:0002FA 241000            MOVE              #$100000,X0             ; Increment over board numbers for DAC write
s
1219      P:0002FB P:0002FB 45F400            MOVE              #$001000,X1             ; Increment over board numbers for WRSS writ
es
                            001000
1220      P:0002FD P:0002FD 060F80            DO      #15,L_VIDEO                       ; Fifteen video processor boards maximum
                            000304
1221      P:0002FF P:0002FF 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1222      P:000300 P:000300 200040            ADD     X0,A
1223      P:000301 P:000301 5F7000            MOVE                          B,Y:WRSS
                            FFFFF3
1224      P:000303 P:000303 0D03E0            JSR     <PAL_DLY                          ; Delay for the serial data transmission
1225      P:000304 P:000304 200068            ADD     X1,B
1226                                L_VIDEO
1227      P:000305 P:000305 0A0F00            BCLR    #CDAC,X:<LATCH                    ; Clear the DACs
1228      P:000306 P:000306 0A0F02            BCLR    #ENCK,X:<LATCH                    ; Disable clock and DAC output switches
1229      P:000307 P:000307 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Execute these two operations
                            00000F
1230      P:000309 P:000309 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1231      P:00030A P:00030A 00000C            RTS
1232   
1233                                ; Start the exposure timer and monitor its progress
1234      P:00030B P:00030B 579000  EXPOSE    MOVE              X:<EXPOSURE_TIME,B
1235      P:00030C P:00030C 20000B            TST     B                                 ; Special test for zero exposure time
1236      P:00030D P:00030D 0EA319            JEQ     <END_EXP                          ; Don't even start an exposure
1237      P:00030E P:00030E 01418C            SUB     #1,B                              ; Timer counts from X:TCPR0+1 to zero
1238      P:00030F P:00030F 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Enable the timer #0
1239      P:000310 P:000310 577000            MOVE              B,X:TCPR0
                            FFFF8D
1240      P:000312 P:000312 330700  CHK_RCV   MOVE              #COM_BUF,R3             ; The beginning of the command buffer
1241      P:000313 P:000313 0A8989            JCLR    #EF,X:HDR,CHK_TIM                 ; Simple test for fast execution
                            000317
1242      P:000315 P:000315 0D00A5            JSR     <GET_RCV                          ; Check for an incoming command
1243      P:000316 P:000316 0E805D            JCS     <PRC_RCV                          ; If command is received, go check it
1244      P:000317 P:000317 018F95  CHK_TIM   JCLR    #TCF,X:TCSR0,CHK_RCV              ; Wait for timer to equal compare value
                            000312
1245      P:000319 P:000319 010F00  END_EXP   BCLR    #TIM_BIT,X:TCSR0                  ; Disable the timer
1246      P:00031A P:00031A 0AE780            JMP     (R7)                              ; This contains the return address
1247   
1248                                ; Start the exposure, expose, and initiate the IR array readout
1249                                START_EXPOSURE                                      ; Test for continuous readout
1250      P:00031B P:00031B 5E9200            MOVE                          Y:<NCOADDS,A
1251      P:00031C P:00031C 014185            CMP     #1,A
1252      P:00031D P:00031D 0E7322            JGT     <SETUP_CONT_RD
1253      P:00031E P:00031E 0A008E            JCLR    #ST_CNRD,X:STATUS,INIT_PCI_BOARD  ; We are in single mode
                            00033C
1254      P:000320 P:000320 0A000E            BCLR    #ST_CNRD,X:<STATUS
1255      P:000321 P:000321 0C0325            JMP     <INIT_FRAME_COUNT                 ; Must send IFC if exiting cont. mode
1256   
1257                                ; Initialize the coaddition sequence
1258                                SETUP_CONT_RD
1259      P:000322 P:000322 0A002E            BSET    #ST_CNRD,X:<STATUS                ; We are in continous readout mode
1260      P:000323 P:000323 303B00            MOVE              #<READ_ON,R0            ; Turn PICNIC Read line ON
1261      P:000324 P:000324 0D03D5            JSR     <CLOCK
1262   
1263                                INIT_FRAME_COUNT
1264      P:000325 P:000325 0D03D2            JSR     <WAIT_TO_FINISH_CLOCKING
1265      P:000326 P:000326 57F400            MOVE              #$020102,B              ; Initialize the PCI frame counter
                            020102
1266      P:000328 P:000328 0D00EB            JSR     <XMT_WRD
1267      P:000329 P:000329 57F400            MOVE              #'IFC',B
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 24



                            494643
1268      P:00032B P:00032B 0D00EB            JSR     <XMT_WRD
1269      P:00032C P:00032C 240000            MOVE              #0,X0
1270      P:00032D P:00032D 4C1300            MOVE                          X0,Y:<ICOADD ; Initialize the coaddition counter
1271      P:00032E P:00032E 4C0700            MOVE                          X0,Y:<I_FPR ; Initialize the reads per reset counter
1272      P:00032F P:00032F 0C033C            JMP     <INIT_PCI_BOARD
1273   
1274                                ; Start up the next frame of the coaddition series
1275                                NEXT_COADD
1276      P:000330 P:000330 5E9300            MOVE                          Y:<ICOADD,A ; Get the # of frames coadded so far
1277      P:000331 P:000331 014180            ADD     #1,A
1278      P:000332 P:000332 4C9200            MOVE                          Y:<NCOADDS,X0 ; See if we've coadded enough frames
1279      P:000333 P:000333 5C1300            MOVE                          A1,Y:<ICOADD ; Increment the coaddition frame counter
1280      P:000334 P:000334 200045            CMP     X0,A
1281      P:000335 P:000335 0E136F            JGE     <CONTINUE_READ                    ; End of coaddition sequence
1282   
1283      P:000336 P:000336 5E9400            MOVE                          Y:<IBUFFER,A ; Get the position in the buffer
1284      P:000337 P:000337 014180            ADD     #1,A
1285      P:000338 P:000338 4C9500            MOVE                          Y:<N_FPB,X0
1286      P:000339 P:000339 5C1400            MOVE                          A1,Y:<IBUFFER
1287      P:00033A P:00033A 200045            CMP     X0,A
1288      P:00033B P:00033B 0E9344            JLT     <TST_RST                          ; Test if the frame buffer is full
1289   
1290                                INIT_PCI_BOARD                                      ; Initialize PCI pointer if full
1291      P:00033C P:00033C 240000            MOVE              #0,X0
1292      P:00033D P:00033D 4C1400            MOVE                          X0,Y:<IBUFFER ; IBUFFER counts from 0 to N_FPB
1293      P:00033E P:00033E 57F400            MOVE              #$020102,B
                            020102
1294      P:000340 P:000340 0D00EB            JSR     <XMT_WRD
1295      P:000341 P:000341 57F400            MOVE              #'IIA',B
                            494941
1296      P:000343 P:000343 0D00EB            JSR     <XMT_WRD
1297   
1298                                ; Test if a reset of the IR array is needed
1299      P:000344 P:000344 5E8700  TST_RST   MOVE                          Y:<I_FPR,A  ; Get the "frames per reset" counter
1300      P:000345 P:000345 014180            ADD     #1,A
1301      P:000346 P:000346 4C8600            MOVE                          Y:<N_FPR,X0
1302      P:000347 P:000347 5C0700            MOVE                          A1,Y:<I_FPR
1303      P:000348 P:000348 200045            CMP     X0,A
1304      P:000349 P:000349 0E934D            JLT     <TRIGGER                          ; Test if need to reset the array
1305      P:00034A P:00034A 240000            MOVE              #0,X0
1306      P:00034B P:00034B 4C0700            MOVE                          X0,Y:<I_FPR ; Initialize the reads per reset counter
1307      P:00034C P:00034C 0D0370            JSR     <RST_FPA                          ; Reset the array
1308   
1309                                ; Sample the EXT_IN0 bit, waiting for a trigger, which is high true.
1310      P:00034D P:00034D 0A008D  TRIGGER   JCLR    #ST_SYNC,X:<STATUS,AGAIN
                            000355
1311      P:00034F P:00034F 0A898A  WAIT_RD   JCLR    #EXT_IN0,X:HDR,WAIT_RD            ; Wait for the trigger to go high
                            00034F
1312      P:000351 P:000351 0606A0            REP     #6                                ; Wait 150 nsec, as a noise filter
1313      P:000352 P:000352 000000            NOP
1314      P:000353 P:000353 0A898A            JCLR    #EXT_IN0,X:HDR,WAIT_RD            ; If trigger is low start over
                            00034F
1315   
1316                                ; Begin the exposure and one or two readouts depending on the CDS setting
1317      P:000355 P:000355 0A008F  AGAIN     JCLR    #ST_CDS,X:<STATUS,EX_STRT
                            00035D
1318      P:000357 P:000357 0D024A            JSR     <RD_ARRAY                         ; Read before expose
1319      P:000358 P:000358 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1320      P:000359 P:000359 0A0090            JCLR    #ST_RD,X:<STATUS,EX_STRT
                            00035D
1321      P:00035B P:00035B 303E00            MOVE              #<READ_OFF,R0           ; Turn PICNIC Read line OFF
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 25



1322      P:00035C P:00035C 0D03D5            JSR     <CLOCK
1323      P:00035D P:00035D 67F400  EX_STRT   MOVE              #EXP_END,R7
                            000360
1324      P:00035F P:00035F 0C030B            JMP     <EXPOSE
1325      P:000360 P:000360 0D024A  EXP_END   JSR     <RD_ARRAY                         ; Read after expose
1326      P:000361 P:000361 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1327      P:000362 P:000362 0A0090            JCLR    #ST_RD,X:<STATUS,RDA_END
                            000366
1328      P:000364 P:000364 303E00            MOVE              #<READ_OFF,R0           ; Turn PICNIC Read line OFF
1329      P:000365 P:000365 0D03D5            JSR     <CLOCK
1330   
1331                                ; Check for a command at the end of readout. Only ABORT should be issued.
1332      P:000366 P:000366 330700  RDA_END   MOVE              #<COM_BUF,R3
1333      P:000367 P:000367 0D00A5            JSR     <GET_RCV                          ; Was a command received?
1334      P:000368 P:000368 0E8387            JCS     <CHK_ABORT_COMMAND                ; If yes, see if its an abort command
1335   
1336                                ; Check for coaddition mode
1337      P:000369 P:000369 5E9200  CHK_ADD   MOVE                          Y:<NCOADDS,A
1338      P:00036A P:00036A 014185            CMP     #1,A
1339      P:00036B P:00036B 0EF36F            JLE     <CONTINUE_READ
1340      P:00036C P:00036C 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1341      P:00036D P:00036D 0D03D2            JSR     <WAIT_TO_FINISH_CLOCKING
1342   
1343                                ; JDM 2005Sep 14   commented out to L_RDDLY to speed up data taking
1344                                ; Delay a minimum of 70 microsec for the pixel data to be written to the PCI bus
1345                                ;       MOVE    #1000000,X0             ; = 100 microsec, #100 per microsec
1346                                ;       DO      X0,L_RDDLY
1347                                ;       NOP
1348                                ;L_RDDLY
1349      P:00036E P:00036E 0C0330            JMP     <NEXT_COADD
1350   
1351                                CONTINUE_READ
1352      P:00036F P:00036F 0C0054            JMP     <START
1353   
1354                                ; Reset array, as a subroutine
1355      P:000370 P:000370 65F400  RST_FPA   MOVE              #NO_CHK,R5              ; Don't check for incoming commands
                            000242
1356      P:000372 P:000372 0D022A            JSR     <RESET_ARRAY                      ; Reset the array
1357      P:000373 P:000373 5E8800            MOVE                          Y:<RST_DLY,A ; Enter reset delay into timer
1358      P:000374 P:000374 0D0469            JSR     <MILLISEC_DELAY                   ; Let the reset signal settle down
1359      P:000375 P:000375 00000C            RTS
1360   
1361                                ; ****************  End of START_EXPOSURE routine  **********************
1362   
1363                                ; Set the desired exposure time
1364                                SET_EXPOSURE_TIME
1365      P:000376 P:000376 46DB00            MOVE              X:(R3)+,Y0
1366      P:000377 P:000377 461000            MOVE              Y0,X:EXPOSURE_TIME
1367      P:000378 P:000378 07F00D            MOVEP             X:EXPOSURE_TIME,X:TCPR0
                            000010
1368      P:00037A P:00037A 0C008F            JMP     <FINISH
1369   
1370                                ; Read the time remaining until the exposure ends
1371                                READ_EXPOSURE_TIME
1372      P:00037B P:00037B 47F000            MOVE              X:TCR0,Y1               ; Read elapsed exposure time
                            FFFF8C
1373      P:00037D P:00037D 0C0090            JMP     <FINISH1
1374   
1375                                ; Pause the exposure - close the shutter, and stop the timer
1376                                PAUSE_EXPOSURE
1377      P:00037E P:00037E 07700C            MOVEP             X:TCR0,X:ELAPSED_TIME   ; Save the elapsed exposure time
                            000011
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 26



1378      P:000380 P:000380 010F00            BCLR    #TIM_BIT,X:TCSR0                  ; Disable the DSP exposure timer
1379      P:000381 P:000381 0C008F            JMP     <FINISH
1380   
1381                                ; Resume the exposure - open the shutter if needed and restart the timer
1382                                RESUME_EXPOSURE
1383      P:000382 P:000382 010F29            BSET    #TRM,X:TCSR0                      ; To be sure it will load TLR0
1384      P:000383 P:000383 07700C            MOVEP             X:TCR0,X:TLR0           ; Restore elapsed exposure time
                            FFFF8E
1385      P:000385 P:000385 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Re-enable the DSP exposure timer
1386      P:000386 P:000386 0C008F            JMP     <FINISH
1387   
1388                                ; See if the command issued during readout is a 'ABR'. If not continue readout
1389                                CHK_ABORT_COMMAND
1390      P:000387 P:000387 44DB00            MOVE              X:(R3)+,X0              ; Get candidate header
1391      P:000388 P:000388 56F400            MOVE              #$000202,A
                            000202
1392      P:00038A P:00038A 200045            CMP     X0,A
1393      P:00038B P:00038B 0E2393            JNE     <RD_CONT
1394      P:00038C P:00038C 0D00A5  WT_COM    JSR     <GET_RCV                          ; Get the command
1395      P:00038D P:00038D 0E038C            JCC     <WT_COM
1396      P:00038E P:00038E 44DB00            MOVE              X:(R3)+,X0              ; Get candidate header
1397      P:00038F P:00038F 56F400            MOVE              #'ABR',A
                            414252
1398      P:000391 P:000391 200045            CMP     X0,A
1399      P:000392 P:000392 0EA396            JEQ     <RDCCD_END_ABORT
1400      P:000393 P:000393 330700  RD_CONT   MOVE              #<COM_BUF,R3            ; Continue reading out the CCD
1401      P:000394 P:000394 227400            MOVE              R3,R4
1402      P:000395 P:000395 0C0369            JMP     <CHK_ADD
1403   
1404                                ; Special ending after abort command to send a 'DON' to the host computer
1405                                RDCCD_END_ABORT
1406      P:000396 P:000396 0A0084            JCLR    #ST_RDC,X:<STATUS,ABORT_EXPOSURE
                            0003AA
1407      P:000398 P:000398 569200            MOVE              X:<ONE,A
1408      P:000399 P:000399 0D0469            JSR     <MILLISEC_DELAY                   ; Wait one millisec
1409      P:00039A P:00039A 0A0082            JCLR    #IDLMODE,X:<STATUS,NO_IDL2        ; Don't idle after readout
                            0003A0
1410      P:00039C P:00039C 60F400            MOVE              #CONT_RST,R0
                            000245
1411      P:00039E P:00039E 601F00            MOVE              R0,X:<IDL_ADR
1412      P:00039F P:00039F 0C03A2            JMP     <RDC_E2
1413      P:0003A0 P:0003A0 305A00  NO_IDL2   MOVE              #TST_RCV,R0
1414      P:0003A1 P:0003A1 601F00            MOVE              R0,X:<IDL_ADR
1415      P:0003A2 P:0003A2 0D03D2  RDC_E2    JSR     <WAIT_TO_FINISH_CLOCKING
1416      P:0003A3 P:0003A3 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1417      P:0003A4 P:0003A4 240000            MOVE              #0,X0
1418      P:0003A5 P:0003A5 4C1200            MOVE                          X0,Y:<NCOADDS ; Terminate coaddition
1419      P:0003A6 P:0003A6 44F400            MOVE              #$000202,X0             ; Send 'DON' to the host computer
                            000202
1420      P:0003A8 P:0003A8 440500            MOVE              X0,X:<HEADER
1421      P:0003A9 P:0003A9 0C008F            JMP     <FINISH
1422   
1423                                ; Abort exposure - close the shutter, stop the timer and resume idle mode
1424                                ABORT_EXPOSURE
1425      P:0003AA P:0003AA 010F00            BCLR    #TIM_BIT,X:TCSR0                  ; Disable the DSP exposure timer
1426      P:0003AB P:0003AB 0C0366            JMP     <RDA_END
1427   
1428                                ; Generate a synthetic image by simply incrementing the pixel counts
1429                                SYNTHETIC_IMAGE
1430      P:0003AC P:0003AC 200013            CLR     A
1431      P:0003AD P:0003AD 060240            DO      Y:<NROWS,LPR_TST                  ; Loop over each line readout
                            0003B8
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 27



1432      P:0003AF P:0003AF 060140            DO      Y:<NCOLS,LSR_TST                  ; Loop over number of pixels per line
                            0003B7
1433      P:0003B1 P:0003B1 0614A0            REP     #20                               ; #20 => 1.0 microsec per pixel
1434      P:0003B2 P:0003B2 000000            NOP
1435      P:0003B3 P:0003B3 014180            ADD     #1,A                              ; Pixel data = Pixel data + 1
1436      P:0003B4 P:0003B4 000000            NOP
1437      P:0003B5 P:0003B5 21CF00            MOVE              A,B
1438      P:0003B6 P:0003B6 0D03BA            JSR     <XMT_PIX                          ;  transmit them
1439      P:0003B7 P:0003B7 000000            NOP
1440                                LSR_TST
1441      P:0003B8 P:0003B8 000000            NOP
1442                                LPR_TST
1443      P:0003B9 P:0003B9 0C0366            JMP     <RDA_END                          ; Normal exit
1444   
1445                                ; Transmit the 16-bit pixel datum in B1 to the host computer
1446      P:0003BA P:0003BA 0C1DA1  XMT_PIX   ASL     #16,B,B
1447      P:0003BB P:0003BB 000000            NOP
1448      P:0003BC P:0003BC 216500            MOVE              B2,X1
1449      P:0003BD P:0003BD 0C1D91            ASL     #8,B,B
1450      P:0003BE P:0003BE 000000            NOP
1451      P:0003BF P:0003BF 216400            MOVE              B2,X0
1452      P:0003C0 P:0003C0 000000            NOP
1453      P:0003C1 P:0003C1 09C532            MOVEP             X1,Y:WRFO
1454      P:0003C2 P:0003C2 09C432            MOVEP             X0,Y:WRFO
1455      P:0003C3 P:0003C3 00000C            RTS
1456   
1457                                ; Alert the PCI interface board that images are coming soon
1458                                PCI_READ_IMAGE
1459      P:0003C4 P:0003C4 57F400            MOVE              #$020104,B              ; Send header word to the FO transmitter
                            020104
1460      P:0003C6 P:0003C6 0D00EB            JSR     <XMT_WRD
1461      P:0003C7 P:0003C7 57F400            MOVE              #'RDA',B
                            524441
1462      P:0003C9 P:0003C9 0D00EB            JSR     <XMT_WRD
1463      P:0003CA P:0003CA 5F8100            MOVE                          Y:<NCOLS,B  ; Number of columns to read
1464      P:0003CB P:0003CB 0D00EB            JSR     <XMT_WRD
1465      P:0003CC P:0003CC 5F8200            MOVE                          Y:<NROWS,B  ; Number of rows to read
1466      P:0003CD P:0003CD 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS3
                            0003D0
1467      P:0003CF P:0003CF 20002B            LSR     B
1468      P:0003D0 P:0003D0 0D00EB  NO_CDS3   JSR     <XMT_WRD
1469      P:0003D1 P:0003D1 00000C            RTS
1470   
1471                                ; Wait for the clocking to be complete before proceeding
1472                                WAIT_TO_FINISH_CLOCKING
1473      P:0003D2 P:0003D2 01ADA1            JSET    #SSFEF,X:PDRD,*                   ; Wait for the SS FIFO to be empty
                            0003D2
1474      P:0003D4 P:0003D4 00000C            RTS
1475   
1476                                ; This MOVEP instruction executes in 30 nanosec, 20 nanosec for the MOVEP,
1477                                ;   and 10 nanosec for the wait state that is required for SRAM writes and
1478                                ;   FIFO setup times. It looks reliable, so will be used for now.
1479   
1480                                ; Core subroutine for clocking
1481                                CLOCK
1482      P:0003D5 P:0003D5 0A898E            JCLR    #SSFHF,X:HDR,*                    ; Only write to FIFO if < half full
                            0003D5
1483      P:0003D7 P:0003D7 000000            NOP
1484      P:0003D8 P:0003D8 0A898E            JCLR    #SSFHF,X:HDR,CLOCK                ; Guard against metastability
                            0003D5
1485      P:0003DA P:0003DA 4CD800            MOVE                          Y:(R0)+,X0  ; # of waveform entries
1486      P:0003DB P:0003DB 06C400            DO      X0,CLK1                           ; Repeat X0 times
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 28



                            0003DD
1487      P:0003DD P:0003DD 09D8F3            MOVEP             Y:(R0)+,Y:WRSS          ; 30 nsec Write the waveform to the SS
1488                                CLK1
1489      P:0003DE P:0003DE 000000            NOP
1490      P:0003DF P:0003DF 00000C            RTS                                       ; Return from subroutine
1491   
1492                                ; Delay for serial writes to the PALs and DACs by 8 microsec
1493      P:0003E0 P:0003E0 062083  PAL_DLY   DO      #800,DLY                          ; Wait 8 usec for serial data transmission
                            0003E2
1494      P:0003E2 P:0003E2 000000            NOP
1495      P:0003E3 P:0003E3 000000  DLY       NOP
1496      P:0003E4 P:0003E4 00000C            RTS
1497   
1498                                ; Let the host computer read the controller configuration
1499                                READ_CONTROLLER_CONFIGURATION
1500      P:0003E5 P:0003E5 4F8B00            MOVE                          Y:<CONFIG,Y1 ; Just transmit the configuration
1501      P:0003E6 P:0003E6 0C0090            JMP     <FINISH1
1502   
1503                                ; Set a particular DAC numbers, for setting DC bias voltages, clock driver
1504                                ;   voltages and video processor offset
1505                                ;
1506                                ; SBN  #BOARD  #DAC  ['CLK' or 'VID']  voltage
1507                                ;
1508                                ;                               #BOARD is from 0 to 15
1509                                ;                               #DAC number
1510                                ;                               #voltage is from 0 to 4095
1511   
1512                                SET_BIAS_NUMBER                                     ; Set bias number
1513      P:0003E7 P:0003E7 012F23            BSET    #3,X:PCRD                         ; Turn on the serial clock
1514      P:0003E8 P:0003E8 56DB00            MOVE              X:(R3)+,A               ; First argument is board number, 0 to 15
1515      P:0003E9 P:0003E9 0614A0            REP     #20
1516      P:0003EA P:0003EA 200033            LSL     A
1517      P:0003EB P:0003EB 000000            NOP
1518      P:0003EC P:0003EC 21C400            MOVE              A,X0
1519      P:0003ED P:0003ED 56DB00            MOVE              X:(R3)+,A               ; Second argument is DAC number
1520      P:0003EE P:0003EE 060EA0            REP     #14
1521      P:0003EF P:0003EF 200033            LSL     A
1522      P:0003F0 P:0003F0 200042            OR      X0,A
1523      P:0003F1 P:0003F1 57DB00            MOVE              X:(R3)+,B               ; Third argument is 'VID' or 'CLK' string
1524      P:0003F2 P:0003F2 44F400            MOVE              #'VID',X0
                            564944
1525      P:0003F4 P:0003F4 20004D            CMP     X0,B
1526      P:0003F5 P:0003F5 0E23FA            JNE     <CLK_DRV
1527      P:0003F6 P:0003F6 0ACC73            BSET    #19,A1                            ; Set bits to mean video processor DAC
1528      P:0003F7 P:0003F7 000000            NOP
1529      P:0003F8 P:0003F8 0ACC72            BSET    #18,A1
1530      P:0003F9 P:0003F9 0C03FE            JMP     <VID_BRD
1531      P:0003FA P:0003FA 44F400  CLK_DRV   MOVE              #'CLK',X0
                            434C4B
1532      P:0003FC P:0003FC 20004D            CMP     X0,B
1533      P:0003FD P:0003FD 0E2408            JNE     <ERR_SBN
1534      P:0003FE P:0003FE 21C400  VID_BRD   MOVE              A,X0
1535      P:0003FF P:0003FF 56DB00            MOVE              X:(R3)+,A               ; Fourth argument is voltage value, 0 to $ff
f
1536      P:000400 P:000400 46F400            MOVE              #$000FFF,Y0             ; Mask off just 12 bits to be sure
                            000FFF
1537      P:000402 P:000402 200056            AND     Y0,A
1538      P:000403 P:000403 200042            OR      X0,A
1539      P:000404 P:000404 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1540      P:000405 P:000405 0D03E0            JSR     <PAL_DLY                          ; Wait for the number to be sent
1541      P:000406 P:000406 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1542      P:000407 P:000407 0C008F            JMP     <FINISH
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 29



1543      P:000408 P:000408 56DB00  ERR_SBN   MOVE              X:(R3)+,A               ; Read and discard the fourth argument
1544      P:000409 P:000409 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1545      P:00040A P:00040A 0C008D            JMP     <ERROR
1546   
1547                                ; Specify the MUX value to be output on the clock driver board
1548                                ; Command syntax is  SMX  #clock_driver_board #MUX1 #MUX2
1549                                ;                               #clock_driver_board from 0 to 15
1550                                ;                               #MUX1, #MUX2 from 0 to 23
1551   
1552      P:00040B P:00040B 012F23  SET_MUX   BSET    #3,X:PCRD                         ; Turn on the serial clock
1553      P:00040C P:00040C 56DB00            MOVE              X:(R3)+,A               ; Clock driver board number
1554      P:00040D P:00040D 0614A0            REP     #20
1555      P:00040E P:00040E 200033            LSL     A
1556      P:00040F P:00040F 44F400            MOVE              #$003000,X0
                            003000
1557      P:000411 P:000411 200042            OR      X0,A
1558      P:000412 P:000412 000000            NOP
1559      P:000413 P:000413 21C500            MOVE              A,X1                    ; Move here for storage
1560   
1561                                ; Get the first MUX number
1562      P:000414 P:000414 56DB00            MOVE              X:(R3)+,A               ; Get the first MUX number
1563      P:000415 P:000415 0AF0A9            JLT     ERR_SM1
                            000459
1564      P:000417 P:000417 44F400            MOVE              #>24,X0                 ; Check for argument less than 32
                            000018
1565      P:000419 P:000419 200045            CMP     X0,A
1566      P:00041A P:00041A 0AF0A1            JGE     ERR_SM1
                            000459
1567      P:00041C P:00041C 21CF00            MOVE              A,B
1568      P:00041D P:00041D 44F400            MOVE              #>7,X0
                            000007
1569      P:00041F P:00041F 20004E            AND     X0,B
1570      P:000420 P:000420 44F400            MOVE              #>$18,X0
                            000018
1571      P:000422 P:000422 200046            AND     X0,A
1572      P:000423 P:000423 0E2426            JNE     <SMX_1                            ; Test for 0 <= MUX number <= 7
1573      P:000424 P:000424 0ACD63            BSET    #3,B1
1574      P:000425 P:000425 0C0431            JMP     <SMX_A
1575      P:000426 P:000426 44F400  SMX_1     MOVE              #>$08,X0
                            000008
1576      P:000428 P:000428 200045            CMP     X0,A                              ; Test for 8 <= MUX number <= 15
1577      P:000429 P:000429 0E242C            JNE     <SMX_2
1578      P:00042A P:00042A 0ACD64            BSET    #4,B1
1579      P:00042B P:00042B 0C0431            JMP     <SMX_A
1580      P:00042C P:00042C 44F400  SMX_2     MOVE              #>$10,X0
                            000010
1581      P:00042E P:00042E 200045            CMP     X0,A                              ; Test for 16 <= MUX number <= 23
1582      P:00042F P:00042F 0E2459            JNE     <ERR_SM1
1583      P:000430 P:000430 0ACD65            BSET    #5,B1
1584      P:000431 P:000431 20006A  SMX_A     OR      X1,B1                             ; Add prefix to MUX numbers
1585      P:000432 P:000432 000000            NOP
1586      P:000433 P:000433 21A700            MOVE              B1,Y1
1587   
1588                                ; Add on the second MUX number
1589      P:000434 P:000434 56DB00            MOVE              X:(R3)+,A               ; Get the next MUX number
1590      P:000435 P:000435 0E908D            JLT     <ERROR
1591      P:000436 P:000436 44F400            MOVE              #>24,X0                 ; Check for argument less than 32
                            000018
1592      P:000438 P:000438 200045            CMP     X0,A
1593      P:000439 P:000439 0E108D            JGE     <ERROR
1594      P:00043A P:00043A 0606A0            REP     #6
1595      P:00043B P:00043B 200033            LSL     A
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 30



1596      P:00043C P:00043C 000000            NOP
1597      P:00043D P:00043D 21CF00            MOVE              A,B
1598      P:00043E P:00043E 44F400            MOVE              #$1C0,X0
                            0001C0
1599      P:000440 P:000440 20004E            AND     X0,B
1600      P:000441 P:000441 44F400            MOVE              #>$600,X0
                            000600
1601      P:000443 P:000443 200046            AND     X0,A
1602      P:000444 P:000444 0E2447            JNE     <SMX_3                            ; Test for 0 <= MUX number <= 7
1603      P:000445 P:000445 0ACD69            BSET    #9,B1
1604      P:000446 P:000446 0C0452            JMP     <SMX_B
1605      P:000447 P:000447 44F400  SMX_3     MOVE              #>$200,X0
                            000200
1606      P:000449 P:000449 200045            CMP     X0,A                              ; Test for 8 <= MUX number <= 15
1607      P:00044A P:00044A 0E244D            JNE     <SMX_4
1608      P:00044B P:00044B 0ACD6A            BSET    #10,B1
1609      P:00044C P:00044C 0C0452            JMP     <SMX_B
1610      P:00044D P:00044D 44F400  SMX_4     MOVE              #>$400,X0
                            000400
1611      P:00044F P:00044F 200045            CMP     X0,A                              ; Test for 16 <= MUX number <= 23
1612      P:000450 P:000450 0E208D            JNE     <ERROR
1613      P:000451 P:000451 0ACD6B            BSET    #11,B1
1614      P:000452 P:000452 200078  SMX_B     ADD     Y1,B                              ; Add prefix to MUX numbers
1615      P:000453 P:000453 000000            NOP
1616      P:000454 P:000454 21AE00            MOVE              B1,A
1617      P:000455 P:000455 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1618      P:000456 P:000456 0D03E0            JSR     <PAL_DLY                          ; Delay for all this to happen
1619      P:000457 P:000457 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1620      P:000458 P:000458 0C008F            JMP     <FINISH
1621      P:000459 P:000459 56DB00  ERR_SM1   MOVE              X:(R3)+,A
1622      P:00045A P:00045A 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1623      P:00045B P:00045B 0C008D            JMP     <ERROR
1624   
1625                                ; Write a number to an analog board over the serial link
1626      P:00045C P:00045C 012F23  WR_BIAS   BSET    #3,X:PCRD                         ; Turn on the serial clock
1627      P:00045D P:00045D 0D03E0            JSR     <PAL_DLY
1628      P:00045E P:00045E 0D020C            JSR     <XMIT_A_WORD                      ; Transmit it to TIM-A-STD
1629      P:00045F P:00045F 0D03E0            JSR     <PAL_DLY
1630      P:000460 P:000460 012F03            BCLR    #3,X:PCRD                         ; Turn off the serial clock
1631      P:000461 P:000461 0D03E0            JSR     <PAL_DLY
1632      P:000462 P:000462 00000C            RTS
1633   
1634                                ; Read DAC values from a table, and write them to the DACs
1635      P:000463 P:000463 065840  SET_DAC   DO      Y:(R0)+,L_DAC                     ; Repeat Y:(R0)+ times
                            000467
1636      P:000465 P:000465 5ED800            MOVE                          Y:(R0)+,A   ; Read the table entry
1637      P:000466 P:000466 0D020C            JSR     <XMIT_A_WORD                      ; Transmit it to TIM-A-STD
1638      P:000467 P:000467 000000            NOP
1639      P:000468 P:000468 00000C  L_DAC     RTS
1640   
1641                                ; Short delay for the array to settle down after a global reset
1642                                MILLISEC_DELAY
1643      P:000469 P:000469 200003            TST     A
1644      P:00046A P:00046A 0E246C            JNE     <DLY_IT
1645      P:00046B P:00046B 00000C            RTS
1646      P:00046C P:00046C 014184  DLY_IT    SUB     #1,A
1647      P:00046D P:00046D 07F40E            MOVEP             #0,X:TLR0               ; Load 0 into counter timer
                            000000
1648      P:00046F P:00046F 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Enable the timer #0
1649      P:000470 P:000470 567000            MOVE              A,X:TCPR0               ; Desired elapsed time
                            FFFF8D
1650      P:000472 P:000472 018F95  CNT_DWN   JCLR    #TCF,X:TCSR0,CNT_DWN              ; Wait here for timer to count down
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 31



                            000472
1651      P:000474 P:000474 010F00            BCLR    #TIM_BIT,X:TCSR0
1652      P:000475 P:000475 00000C            RTS
1653   
1654                                ; Put PCI board in reading image out mode to block commands to the timing board
1655                                READING_IMAGE_ON
1656      P:000476 P:000476 57F400            MOVE              #$020102,B              ; Send header word to the FO transmitter
                            020102
1657      P:000478 P:000478 0D00EB            JSR     <XMT_WRD
1658      P:000479 P:000479 57F400            MOVE              #'RDI',B
                            524449
1659      P:00047B P:00047B 0D00EB            JSR     <XMT_WRD
1660      P:00047C P:00047C 00000C            RTS
1661   
1662                                ; Select which readouts to readout - 'SOS'  Amplifier_name
1663                                ;       Amplifier_name = 0, 1, 2, 3 or 'ALL'
1664   
1665                                SELECT_OUTPUT_SOURCE
1666      P:00047D P:00047D 44DB00            MOVE              X:(R3)+,X0              ; Get amplifier(s) name or number
1667      P:00047E P:00047E 4C0F00            MOVE                          X0,Y:<OS
1668      P:00047F P:00047F 56F400            MOVE              #'ALL',A                ; All amplifiers = readouts #0 to #3
                            414C4C
1669      P:000481 P:000481 200045            CMP     X0,A
1670      P:000482 P:000482 0E2486            JNE     <CHK_0
1671      P:000483 P:000483 44F400            MOVE              #$00F0C0,X0
                            00F0C0
1672      P:000485 P:000485 0C04A1            JMP     <SOS
1673      P:000486 P:000486 56F400  CHK_0     MOVE              #>0,A                   ; Amplifier 0 = Upper Left
                            000000
1674      P:000488 P:000488 200045            CMP     X0,A
1675      P:000489 P:000489 0E248D            JNE     <CHK_1
1676      P:00048A P:00048A 44F400            MOVE              #$00F000,X0
                            00F000
1677      P:00048C P:00048C 0C04A1            JMP     <SOS
1678      P:00048D P:00048D 56F400  CHK_1     MOVE              #>1,A                   ; Amplifier 1 = Upper Right
                            000001
1679      P:00048F P:00048F 200045            CMP     X0,A
1680      P:000490 P:000490 0E2494            JNE     <CHK_2
1681      P:000491 P:000491 44F400            MOVE              #$00F041,X0
                            00F041
1682      P:000493 P:000493 0C04A1            JMP     <SOS
1683      P:000494 P:000494 56F400  CHK_2     MOVE              #>2,A                   ; Amplifier 2 = Lower Right
                            000002
1684      P:000496 P:000496 200045            CMP     X0,A
1685      P:000497 P:000497 0E249B            JNE     <CHK_3
1686      P:000498 P:000498 44F400            MOVE              #$00F082,X0
                            00F082
1687      P:00049A P:00049A 0C04A1            JMP     <SOS
1688      P:00049B P:00049B 56F400  CHK_3     MOVE              #>3,A                   ; Amplifier 3 = Lower Left
                            000003
1689      P:00049D P:00049D 200045            CMP     X0,A
1690      P:00049E P:00049E 0E208D            JNE     <ERROR
1691      P:00049F P:00049F 44F400            MOVE              #$00F0C3,X0
                            00F0C3
1692   
1693      P:0004A1 P:0004A1 4C7000  SOS       MOVE                          X0,Y:SXMIT0
                            000064
1694      P:0004A3 P:0004A3 4C7000            MOVE                          X0,Y:SXMIT1
                            000069
1695      P:0004A5 P:0004A5 4C7000            MOVE                          X0,Y:SXMIT2
                            000077
1696      P:0004A7 P:0004A7 4C7000            MOVE                          X0,Y:SXMIT3
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 32



                            00007B
1697      P:0004A9 P:0004A9 4C7000            MOVE                          X0,Y:SXMIT00
                            000071
1698      P:0004AB P:0004AB 0C008F            JMP     <FINISH
1699   
1700                                ; Special continuous readout commands
1701                                SET_NUMBER_OF_COADDS
1702      P:0004AC P:0004AC 44DB00            MOVE              X:(R3)+,X0
1703      P:0004AD P:0004AD 4C1200            MOVE                          X0,Y:<NCOADDS
1704      P:0004AE P:0004AE 0C008F            JMP     <FINISH
1705   
1706                                SET_NUMBER_OF_FRAMES_PER_BUFFER
1707      P:0004AF P:0004AF 44DB00            MOVE              X:(R3)+,X0
1708      P:0004B0 P:0004B0 4C1500            MOVE                          X0,Y:<N_FPB
1709      P:0004B1 P:0004B1 0C008F            JMP     <FINISH
1710   
1711                                ; Set number of readout times per pixel
1712                                SET_NUM_READS
1713      P:0004B2 P:0004B2 44DB00            MOVE              X:(R3)+,X0
1714      P:0004B3 P:0004B3 4C0500            MOVE                          X0,Y:<NUM_RDS
1715      P:0004B4 P:0004B4 0C008F            JMP     <FINISH
1716   
1717                                SET_NUMBER_OF_FRAMES_PER_RESET
1718      P:0004B5 P:0004B5 44DB00            MOVE              X:(R3)+,X0
1719      P:0004B6 P:0004B6 4C0600            MOVE                          X0,Y:<N_FPR
1720      P:0004B7 P:0004B7 0C008F            JMP     <FINISH
1721   
1722                                ; Subarray readout - specify region to read
1723                                SPECIFY_SUB_ARRAY
1724      P:0004B8 P:0004B8 44DB00            MOVE              X:(R3)+,X0
1725      P:0004B9 P:0004B9 4C0300            MOVE                          X0,Y:<COL_OFFSET
1726      P:0004BA P:0004BA 44DB00            MOVE              X:(R3)+,X0
1727      P:0004BB P:0004BB 4C0400            MOVE                          X0,Y:<ROW_OFFSET
1728      P:0004BC P:0004BC 0C008F            JMP     <FINISH
1729   
1730                                ; Set trigger mode, to start readout on trigger true.
1731                                SET_TRIGGER_MODE
1732      P:0004BD P:0004BD 0A5B80            JCLR    #0,X:(R3)+,NO_TRIGGER             ; 1 for external triggering 0 for not
                            0004C1
1733      P:0004BF P:0004BF 0A002D            BSET    #ST_SYNC,X:<STATUS
1734      P:0004C0 P:0004C0 0C008F            JMP     <FINISH
1735                                NO_TRIGGER
1736      P:0004C1 P:0004C1 0A000D            BCLR    #ST_SYNC,X:<STATUS
1737      P:0004C2 P:0004C2 0C008F            JMP     <FINISH
1738   
1739                                ; Set correlated double sample (CDS) mode, to readout before and after exposure
1740                                SET_CDS_MODE
1741      P:0004C3 P:0004C3 0A5B80            JCLR    #0,X:(R3)+,NO_CDS4                ; 1 for CDS, 0 for not
                            0004C7
1742      P:0004C5 P:0004C5 0A002F            BSET    #ST_CDS,X:<STATUS
1743      P:0004C6 P:0004C6 0C008F            JMP     <FINISH
1744                                NO_CDS4
1745      P:0004C7 P:0004C7 0A000F            BCLR    #ST_CDS,X:<STATUS
1746      P:0004C8 P:0004C8 0C008F            JMP     <FINISH
1747   
1748                                ; Turn the PICNIC signal READ on before an exposure and off after it?
1749                                SET_READ_MODE
1750      P:0004C9 P:0004C9 0A5B80            JCLR    #0,X:(R3)+,NO_READ_ON_AND_OFF     ; 1 for turning it on and off
                            0004CD
1751      P:0004CB P:0004CB 0A0030            BSET    #ST_RD,X:<STATUS
1752      P:0004CC P:0004CC 0C008F            JMP     <FINISH
1753                                NO_READ_ON_AND_OFF
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  timIRmisc.asm  Page 33



1754      P:0004CD P:0004CD 0A0010            BCLR    #ST_RD,X:<STATUS
1755      P:0004CE P:0004CE 0C008F            JMP     <FINISH
1756   
1757   
1758                                 TIMBOOT_X_MEMORY
1759      0004CF                              EQU     @LCV(L)
1760   
1761                                ; Define the address in P: space where the table of constants begins
1762   
1763                                          IF      @SCP("HOST","HOST")
1764      X:000036 X:000036                   ORG     X:END_COMMAND_TABLE,X:END_COMMAND_TABLE
1765                                          ENDIF
1766   
1767                                          IF      @SCP("HOST","ROM")
1769                                          ENDIF
1770   
1771      X:000036 X:000036                   DC      'SEX',START_EXPOSURE
1772      X:000038 X:000038                   DC      'AEX',ABORT_EXPOSURE
1773      X:00003A X:00003A                   DC      'PON',POWER_ON
1774      X:00003C X:00003C                   DC      'POF',POWER_OFF
1775      X:00003E X:00003E                   DC      'SET',SET_EXPOSURE_TIME
1776      X:000040 X:000040                   DC      'RET',READ_EXPOSURE_TIME
1777      X:000042 X:000042                   DC      'SBN',SET_BIAS_NUMBER
1778      X:000044 X:000044                   DC      'SMX',SET_MUX
1779      X:000046 X:000046                   DC      'SBV',SET_BIASES
1780      X:000048 X:000048                   DC      'RCC',READ_CONTROLLER_CONFIGURATION
1781      X:00004A X:00004A                   DC      'DON',START
1782   
1783                                ; Continuous readout commands
1784      X:00004C X:00004C                   DC      'SNC',SET_NUMBER_OF_COADDS
1785      X:00004E X:00004E                   DC      'FPB',SET_NUMBER_OF_FRAMES_PER_BUFFER
1786   
1787                                ; Custom commands
1788      X:000050 X:000050                   DC      'STM',SET_TRIGGER_MODE
1789      X:000052 X:000052                   DC      'SOS',SELECT_OUTPUT_SOURCE
1790      X:000054 X:000054                   DC      'SNR',SET_NUM_READS
1791      X:000056 X:000056                   DC      'SFR',SET_NUMBER_OF_FRAMES_PER_RESET
1792      X:000058 X:000058                   DC      'SSA',SPECIFY_SUB_ARRAY
1793      X:00005A X:00005A                   DC      'CDS',SET_CDS_MODE
1794      X:00005C X:00005C                   DC      'SRD',SET_READ_MODE               ; READ signal on PICNIC on and off?
1795   
1796                                 END_APPLICATON_COMMAND_TABLE
1797      00005E                              EQU     @LCV(L)
1798   
1799                                          IF      @SCP("HOST","HOST")
1800      00001B                    NUM_COM   EQU     (@LCV(R)-COM_TBL_R)/2             ; Number of boot +
1801                                                                                    ;  application commands
1802      000317                    EXPOSING  EQU     CHK_TIM                           ; Address if exposing
1803                                 CONTINUE_READING
1804      00036F                              EQU     CONTINUE_READ                     ; Address if reading out
1805                                          ENDIF
1806   
1807                                          IF      @SCP("HOST","ROM")
1809                                          ENDIF
1810   
1811                                ; Now let's go for the timing waveform tables
1812                                          IF      @SCP("HOST","HOST")
1813      Y:000000 Y:000000                   ORG     Y:0,Y:0
1814                                          ENDIF
1815   
1816      Y:000000 Y:000000         GAIN      DC      END_APPLICATON_Y_MEMORY-@LCV(L)-1
1817   
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  tim.asm  Page 34



1818      Y:000001 Y:000001         NCOLS     DC      256                               ; Number of columns
1819      Y:000002 Y:000002         NROWS     DC      256                               ; Number of rows
1820      Y:000003 Y:000003         COL_OFFSET DC     0                                 ; Number of columns to skip in subarray mode
1821      Y:000004 Y:000004         ROW_OFFSET DC     0                                 ; Number of rows to skip in subarray mode
1822      Y:000005 Y:000005         NUM_RDS   DC      1                                 ; Number of reads per reset
1823      Y:000006 Y:000006         N_FPR     DC      1                                 ; Number of frames per reset
1824      Y:000007 Y:000007         I_FPR     DC      1                                 ; Counter for frames per reset
1825      Y:000008 Y:000008         RST_DLY   DC      5                                 ; Delay after array reset for settling
1826      Y:000009 Y:000009         PWR_DLY   DC      100                               ; Delay in millisec for power to turn on
1827      Y:00000A Y:00000A         VDD_DLY   DC      300                               ; Delay in millise for VDD to settle
1828      Y:00000B Y:00000B         CONFIG    DC      CC                                ; Controller configuration
1829      Y:00000C Y:00000C         TST_DAT   DC      0                                 ; Synthetic image test datum
1830      Y:00000D Y:00000D         ODD_ROW   DC      0                                 ; Odd or even row number
1831      Y:00000E Y:00000E         ODD_COL   DC      0                                 ; Odd or even column number
1832      Y:00000F Y:00000F         OS        DC      'ALL'                             ; Number of readouts
1833      Y:000010 Y:000010         NXLOOP    DC      0                                 ; Loop index for the columns
1834      Y:000011 Y:000011         NYLOOP    DC      0                                 ; Loop index for the rows
1835   
1836                                ; Continuous readout mode constants
1837      Y:000012 Y:000012         NCOADDS   DC      1                                 ; Number of coadditions per exposure
1838      Y:000013 Y:000013         ICOADD    DC      0                                 ; Counter of number of coadds done so far
1839      Y:000014 Y:000014         IBUFFER   DC      0                                 ; Buffer pointer - counts from 0 to N_FPB
1840      Y:000015 Y:000015         N_FPB     DC      1                                 ; Number of frames in each image buffer
1841   
1842                                ; Include the waveform table for the PICNIC focal plane array
1843                                          INCLUDE "PICNIC.waveforms"                ; Readout and clocking waveform file
1844   
1845                                ; Miscellaneous definitions
1846      000000                    VIDEO     EQU     $000000                           ; Video board select = 0 for first A/D board
 with biases
1847      002000                    CLK2      EQU     $002000                           ; Clock board select = 2
1848      003000                    CLK3      EQU     $003000                           ; Clock board select = 3
1849      080000                    DELAY     EQU     $080000                           ; Delay for clocking operations  ; 080 = 500
 musec
1850                                                                                    ;    (20 ns unit, 160 if MSB set)
1851      100000                    VP_DLY    EQU     $100000                           ; Video delay time 100=500 musec
1852      00F0C0                    SXMIT     EQU     $00F0C0                           ; Series transmit A/D channels #0 to 3
1853   
1854                                ;  Clock voltage definitions
1855      000CC0                    CLK_HIGH  EQU     $CC0                              ; ~+4V, assuming +VREF = +2.5
1856      0000F4                    CLK_LOW   EQU     $0F4                              ; ~+.30V, assuming -VREF =  0.0
1857   
1858                                ; Logic analyzer values
1859                                ;CLK_HIGH       EQU     $a00
1860                                ;CLK_LOW        EQU     $7E0
1861   
1862                                ; Table of offset values begins at Y:$10
1863   
1864                                ; DAC settings for the video offsets
1865      Y:000016 Y:000016         DC_BIASES DC      END_DC_BIASES-DC_BIASES-1
1866      Y:000017 Y:000017         OFF_0     DC      $0c0000                           ; Input offset board #0, channel A
1867      Y:000018 Y:000018         OFF_1     DC      $0c4000                           ; Input offset board #0, channel B
1868      Y:000019 Y:000019         OFF_2     DC      $1c0000                           ; Input offset board #1, channel A
1869      Y:00001A Y:00001A         OFF_3     DC      $1c4000                           ; Input offset board #1, channel B
1870   
1871                                ; DAC settings to generate DC bias voltages for the PICNIC array
1872      Y:00001B Y:00001B         VOFFSET   DC      $0c8bd4                           ; pin #1 = preamp offset = +3.7 volts
1873                                ;VRESET      DC    $0cc195     ; pin #2 = reset = +0.5 volts
1874      Y:00001C Y:00001C         VRESET    DC      $0cc28f                           ; pin #2 = reset = +0.8 volts
1875      Y:00001D Y:00001D         VD        DC      $0d0fff                           ; pin #3 = analog power = +5.0 volts
1876                                ;ICTL        DC    $0d4bd4     ; pin #4 = current control = +3.7 volts
1877      Y:00001E Y:00001E         ICTL      DC      $0d4a8c                           ; pin #4 = current control = +3.3 volts
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  PICNIC.waveforms  Page 35



1878      Y:00001F Y:00001F         VDD       DC      $0d8ccb                           ; pin #5 = digital power = +4.0 volts
1879      Y:000020 Y:000020         VUNUSED   DC      $0dc000                           ; pin #6 = unused to 0V
1880                                END_DC_BIASES
1881   
1882                                ;  Zero out the DC biases during the power-on sequence
1883                                ZERO_BIASES
1884      Y:000021 Y:000021                   DC      END_ZERO_BIASES-ZERO_BIASES-1
1885      Y:000022 Y:000022                   DC      $0c8000                           ; Pin #1, board #0
1886      Y:000023 Y:000023                   DC      $0cc000                           ; Pin #2
1887      Y:000024 Y:000024                   DC      $0d0000                           ; Pin #3
1888      Y:000025 Y:000025                   DC      $0d4000                           ; Pin #4
1889      Y:000026 Y:000026                   DC      $0d8000                           ; Pin #5
1890      Y:000027 Y:000027                   DC      $0dc000                           ; Pin #6
1891   
1892      Y:000028 Y:000028                   DC      $1c8000                           ; Pin #1, board #1
1893      Y:000029 Y:000029                   DC      $1cc000                           ; Pin #2
1894      Y:00002A Y:00002A                   DC      $1d0000                           ; Pin #3
1895      Y:00002B Y:00002B                   DC      $1d4000                           ; Pin #4
1896      Y:00002C Y:00002C                   DC      $1d8000                           ; Pin #5
1897      Y:00002D Y:00002D                   DC      $1dc000                           ; Pin #6
1898                                END_ZERO_BIASES
1899   
1900                                ; Initialize all DACs, starting with the clock driver ones
1901      Y:00002E Y:00002E         DACS      DC      END_DACS-DACS-1
1902      Y:00002F Y:00002F                   DC      (CLK2<<8)+(0<<14)+CLK_HIGH        ; Pin #1, RESET
1903      Y:000030 Y:000030                   DC      (CLK2<<8)+(1<<14)+CLK_LOW
1904      Y:000031 Y:000031                   DC      (CLK2<<8)+(2<<14)+CLK_HIGH        ; Pin #2, LINE
1905      Y:000032 Y:000032                   DC      (CLK2<<8)+(3<<14)+CLK_LOW
1906      Y:000033 Y:000033                   DC      (CLK2<<8)+(4<<14)+CLK_HIGH        ; Pin #3, LSYNC
1907      Y:000034 Y:000034                   DC      (CLK2<<8)+(5<<14)+CLK_LOW
1908      Y:000035 Y:000035                   DC      (CLK2<<8)+(6<<14)+CLK_HIGH        ; Pin #4, FSYNC
1909      Y:000036 Y:000036                   DC      (CLK2<<8)+(7<<14)+CLK_LOW
1910      Y:000037 Y:000037                   DC      (CLK2<<8)+(10<<14)+CLK_HIGH       ; Pin #6, READ
1911      Y:000038 Y:000038                   DC      (CLK2<<8)+(11<<14)+CLK_LOW
1912   
1913      Y:000039 Y:000039                   DC      (CLK2<<8)+(24<<14)+CLK_HIGH       ; Pin #13, PIXEL
1914      Y:00003A Y:00003A                   DC      (CLK2<<8)+(25<<14)+CLK_LOW
1915                                END_DACS
1916   
1917                                ; Define switch state bits for the first group of 12 clocks = CLK2
1918      000001                    H_RESET   EQU     1                                 ; Pin #1
1919      000000                    L_RESET   EQU     0
1920      000002                    H_LINE    EQU     2                                 ; Pin #2
1921      000000                    L_LINE    EQU     0
1922      000004                    H_LSYNC   EQU     4                                 ; Pin #3
1923      000000                    L_LSYNC   EQU     0
1924      000008                    H_FSYNC   EQU     8                                 ; Pin #4
1925      000000                    L_FSYNC   EQU     0
1926      000020                    H_READ    EQU     $20                               ; Pin #6
1927      000000                    L_READ    EQU     0
1928   
1929                                ; Define switch state bits for the second group of 12 clocks = CLK3
1930      000001                    H_PIXEL   EQU     1                                 ; Pin #13
1931      000000                    L_PIXEL   EQU     0
1932   
1933                                ;SXMIT  EQU     $00F0C0                         ; Transmit A/Ds = 0 to 3
1934                                ;SXMIT  EQU     $00F000                         ; Transmit A/D = 0
1935                                ;SXMIT  EQU     $00F041                         ; Transmit A/D = 1
1936                                ;SXMIT  EQU     $00F082                         ; Transmit A/D = 2
1937                                ;SXMIT  EQU     $00F0C3                         ; Transmit A/D = 3
1938   
1939                                ; Symbolic definitions
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  PICNIC.waveforms  Page 36



1940                                ;       DC      CLK2+DELAY+L_FSYNC+L_LSYNC+L_LINE+L_READ+L_RESET
1941                                ;       DC      CLK3+DELAY+L_PIXEL
1942   
1943                                ; Turn READ ON for readout and reset
1944                                READ_ON
1945      Y:00003B Y:00003B                   DC      END_READ_ON-READ_ON-1
1946      Y:00003C Y:00003C                   DC      CLK3+DELAY+L_PIXEL
1947      Y:00003D Y:00003D                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1948                                END_READ_ON
1949   
1950                                ; Turn READ OFF during exposure
1951                                READ_OFF
1952      Y:00003E Y:00003E                   DC      END_READ_OFF-READ_OFF-1
1953      Y:00003F Y:00003F                   DC      CLK3+DELAY+L_PIXEL
1954      Y:000040 Y:000040                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+L_READ+L_RESET
1955                                END_READ_OFF
1956   
1957                                ;  Initialize the frame for readout, including shift register (slow row scanner)
1958                                INIT_FRAME
1959      Y:000041 Y:000041                   DC      END_INIT_FRAME-INIT_FRAME-1
1960      Y:000042 Y:000042                   DC      CLK3+DELAY+L_PIXEL
1961      Y:000043 Y:000043                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1962      Y:000044 Y:000044                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+L_RESET
1963      Y:000045 Y:000045                   DC      CLK2+DELAY+L_FSYNC+L_LSYNC+L_LINE+H_READ+L_RESET
1964                                END_INIT_FRAME
1965   
1966                                SHIFT_RESET_ODD_ROW
1967      Y:000046 Y:000046                   DC      END_SHIFT_RESET_ODD_ROW-SHIFT_RESET_ODD_ROW-1
1968      Y:000047 Y:000047                   DC      CLK3+DELAY+L_PIXEL
1969      Y:000048 Y:000048                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+L_RESET
1970      Y:000049 Y:000049                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1971      Y:00004A Y:00004A                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
1972      Y:00004B Y:00004B                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
1973      Y:00004C Y:00004C                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
1974                                END_SHIFT_RESET_ODD_ROW
1975   
1976                                SHIFT_RESET_EVEN_ROW
1977      Y:00004D Y:00004D                   DC      END_SHIFT_RESET_EVEN_ROW-SHIFT_RESET_EVEN_ROW-1
1978      Y:00004E Y:00004E                   DC      CLK3+DELAY+L_PIXEL
1979      Y:00004F Y:00004F                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+L_RESET
1980      Y:000050 Y:000050                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
1981      Y:000051 Y:000051                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1982      Y:000052 Y:000052                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
1983      Y:000053 Y:000053                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1984                                END_SHIFT_RESET_EVEN_ROW
1985   
1986                                SHIFT_EVEN_ROW
1987      Y:000054 Y:000054                   DC      END_SHIFT_EVEN_ROW-SHIFT_EVEN_ROW-1
1988      Y:000055 Y:000055                   DC      CLK3+DELAY+L_PIXEL
1989      Y:000056 Y:000056                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+L_RESET
1990      Y:000057 Y:000057                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+L_RESET
1991      Y:000058 Y:000058                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
1992      Y:000059 Y:000059                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
1993                                ;       DC      CLK3+DELAY+H_PIXEL
1994                                END_SHIFT_EVEN_ROW
1995   
1996                                SHIFT_ODD_ROW
1997      Y:00005A Y:00005A                   DC      END_SHIFT_ODD_ROW-SHIFT_ODD_ROW-1
1998      Y:00005B Y:00005B                   DC      CLK3+DELAY+L_PIXEL
1999      Y:00005C Y:00005C                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+L_RESET
2000      Y:00005D Y:00005D                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+L_RESET
2001      Y:00005E Y:00005E                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
Motorola DSP56300 Assembler  Version 6.3.22   05-09-16  09:53:07  PICNIC.waveforms  Page 37



2002      Y:00005F Y:00005F                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
2003                                ;       DC      CLK3+DELAY+H_PIXEL
2004                                END_SHIFT_ODD_ROW
2005   
2006                                SHIFT_READ_PIXELS
2007      Y:000060 Y:000060                   DC      END_SHIFT_READ_PIXELS-SHIFT_READ_PIXELS-1
2008      Y:000061 Y:000061                   DC      CLK3+DELAY+H_PIXEL
2009      Y:000062 Y:000062                   DC      $400000                           ; A/D sample
2010      Y:000063 Y:000063                   DC      $010033                           ; Start A/D conversion
2011      Y:000064 Y:000064         SXMIT0    DC      SXMIT                             ; Series transmit four pixels' data
2012      Y:000065 Y:000065                   DC      0                                 ; Return SXMIT to zero
2013      Y:000066 Y:000066                   DC      CLK3+DELAY+L_PIXEL
2014      Y:000067 Y:000067                   DC      $400000                           ; A/D sample
2015      Y:000068 Y:000068                   DC      $010033                           ; Start A/D conversion
2016      Y:000069 Y:000069         SXMIT1    DC      SXMIT                             ; Series transmit four pixels' data
2017      Y:00006A Y:00006A                   DC      0                                 ; Return SXMIT to zero
2018                                END_SHIFT_READ_PIXELS
2019   
2020                                ; Advance the row shift register as quickly as possible, 240 nsec/pixel
2021                                SHIFT_PIXELS
2022      Y:00006B Y:00006B                   DC      END_SHIFT_PIXELS-SHIFT_PIXELS-1
2023      Y:00006C Y:00006C                   DC      CLK3+DELAY+H_PIXEL
2024      Y:00006D Y:00006D                   DC      CLK3+DELAY+L_PIXEL
2025                                END_SHIFT_PIXELS
2026   
2027                                READ_PIXEL
2028      Y:00006E Y:00006E                   DC      END_READ_PIXEL-READ_PIXEL-1
2029      Y:00006F Y:00006F                   DC      $140000                           ; A/D sample
2030      Y:000070 Y:000070                   DC      $010033                           ; Start A/D conversion
2031      Y:000071 Y:000071         SXMIT00   DC      SXMIT                             ; Series transmit four pixels' data
2032      Y:000072 Y:000072                   DC      0                                 ; Return SXMIT to zero
2033                                END_READ_PIXEL
2034   
2035                                SXMIT_EIGHT_PIXELS
2036      Y:000073 Y:000073                   DC      END_SXMIT_EIGHT_PIXELS-SXMIT_EIGHT_PIXELS-1
2037      Y:000074 Y:000074                   DC      DELAY+$000033
2038      Y:000075 Y:000075                   DC      VP_DLY                            ; A/D sample
2039      Y:000076 Y:000076                   DC      $000033                           ; Start A/D conversion
2040      Y:000077 Y:000077         SXMIT2    DC      SXMIT                             ; Series transmit four pixels' data
2041      Y:000078 Y:000078                   DC      DELAY+$000033
2042      Y:000079 Y:000079                   DC      VP_DLY                            ; A/D sample
2043      Y:00007A Y:00007A                   DC      $000033                           ; Start A/D conversion
2044      Y:00007B Y:00007B         SXMIT3    DC      SXMIT                             ; Series transmit four pixels' data
2045      Y:00007C Y:00007C                   DC      0                                 ; Return SXMIT to zero
2046                                END_SXMIT_EIGHT_PIXELS
2047   
2048                                 END_APPLICATON_Y_MEMORY
2049      00007D                              EQU     @LCV(L)
2050   
2051                                ; End of program
2052                                          END

0    Errors
0    Warnings


