Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 1



1                                 COMMENT *
2      
3                          This file is used to generate DSP code for the a Gen III = ARC22
4                                  timing board to operate a 256 x 256 pixel PICNIC IR FPA
5                             *
6      
7                                    PAGE    132                               ; Printronix page width - 132 columns
8      
9                          ; Include the boot and header files so addressing is easy
10                                   INCLUDE "timhdr.asm"
11                                COMMENT *
12     
13                         This is a header file that is shared between the fiber optic timing board
14                         boot and application code files for Rev. 5 = 250 MHz timing boards
15                                 *
16     
17                                   PAGE    132                               ; Printronix page width - 132 columns
18     
19                         ; Various addressing control registers
20        FFFFFB           BCR       EQU     $FFFFFB                           ; Bus Control Register
21        FFFFF9           AAR0      EQU     $FFFFF9                           ; Address Attribute Register, channel 0
22        FFFFF8           AAR1      EQU     $FFFFF8                           ; Address Attribute Register, channel 1
23        FFFFF7           AAR2      EQU     $FFFFF7                           ; Address Attribute Register, channel 2
24        FFFFF6           AAR3      EQU     $FFFFF6                           ; Address Attribute Register, channel 3
25        FFFFFD           PCTL      EQU     $FFFFFD                           ; PLL control register
26        FFFFFE           IPRP      EQU     $FFFFFE                           ; Interrupt Priority register - Peripheral
27        FFFFFF           IPRC      EQU     $FFFFFF                           ; Interrupt Priority register - Core
28     
29                         ; Port E is the Synchronous Communications Interface (SCI) port
30        FFFF9F           PCRE      EQU     $FFFF9F                           ; Port Control Register
31        FFFF9E           PRRE      EQU     $FFFF9E                           ; Port Direction Register
32        FFFF9D           PDRE      EQU     $FFFF9D                           ; Port Data Register
33        FFFF9C           SCR       EQU     $FFFF9C                           ; SCI Control Register
34        FFFF9B           SCCR      EQU     $FFFF9B                           ; SCI Clock Control Register
35     
36        FFFF9A           SRXH      EQU     $FFFF9A                           ; SCI Receive Data Register, High byte
37        FFFF99           SRXM      EQU     $FFFF99                           ; SCI Receive Data Register, Middle byte
38        FFFF98           SRXL      EQU     $FFFF98                           ; SCI Receive Data Register, Low byte
39     
40        FFFF97           STXH      EQU     $FFFF97                           ; SCI Transmit Data register, High byte
41        FFFF96           STXM      EQU     $FFFF96                           ; SCI Transmit Data register, Middle byte
42        FFFF95           STXL      EQU     $FFFF95                           ; SCI Transmit Data register, Low byte
43     
44        FFFF94           STXA      EQU     $FFFF94                           ; SCI Transmit Address Register
45        FFFF93           SSR       EQU     $FFFF93                           ; SCI Status Register
46     
47        000009           SCITE     EQU     9                                 ; X:SCR bit set to enable the SCI transmitter
48        000008           SCIRE     EQU     8                                 ; X:SCR bit set to enable the SCI receiver
49        000000           TRNE      EQU     0                                 ; This is set in X:SSR when the transmitter
50                                                                             ;  shift and data registers are both empty
51        000001           TDRE      EQU     1                                 ; This is set in X:SSR when the transmitter
52                                                                             ;  data register is empty
53        000002           RDRF      EQU     2                                 ; X:SSR bit set when receiver register is full
54        00000F           SELSCI    EQU     15                                ; 1 for SCI to backplane, 0 to front connector
55     
56     
57                         ; ESSI Flags
58        000006           TDE       EQU     6                                 ; Set when transmitter data register is empty
59        000007           RDF       EQU     7                                 ; Set when receiver is full of data
60        000010           TE        EQU     16                                ; Transmitter enable
61     
62                         ; Phase Locked Loop initialization
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timhdr.asm  Page 2



63        050003           PLL_INIT  EQU     $050003                           ; PLL = 25 MHz x 2 = 100 MHz
64     
65                         ; Port B general purpose I/O
66        FFFFC4           HPCR      EQU     $FFFFC4                           ; Control register (bits 1-6 cleared for GPIO)
67        FFFFC9           HDR       EQU     $FFFFC9                           ; Data register
68        FFFFC8           HDDR      EQU     $FFFFC8                           ; Data Direction Register bits (=1 for output)
69     
70                         ; Port C is Enhanced Synchronous Serial Port 0 = ESSI0
71        FFFFBF           PCRC      EQU     $FFFFBF                           ; Port C Control Register
72        FFFFBE           PRRC      EQU     $FFFFBE                           ; Port C Data direction Register
73        FFFFBD           PDRC      EQU     $FFFFBD                           ; Port C GPIO Data Register
74        FFFFBC           TX00      EQU     $FFFFBC                           ; Transmit Data Register #0
75        FFFFB8           RX0       EQU     $FFFFB8                           ; Receive data register
76        FFFFB7           SSISR0    EQU     $FFFFB7                           ; Status Register
77        FFFFB6           CRB0      EQU     $FFFFB6                           ; Control Register B
78        FFFFB5           CRA0      EQU     $FFFFB5                           ; Control Register A
79     
80                         ; Port D is Enhanced Synchronous Serial Port 1 = ESSI1
81        FFFFAF           PCRD      EQU     $FFFFAF                           ; Port D Control Register
82        FFFFAE           PRRD      EQU     $FFFFAE                           ; Port D Data direction Register
83        FFFFAD           PDRD      EQU     $FFFFAD                           ; Port D GPIO Data Register
84        FFFFAC           TX10      EQU     $FFFFAC                           ; Transmit Data Register 0
85        FFFFA7           SSISR1    EQU     $FFFFA7                           ; Status Register
86        FFFFA6           CRB1      EQU     $FFFFA6                           ; Control Register B
87        FFFFA5           CRA1      EQU     $FFFFA5                           ; Control Register A
88     
89                         ; Timer module addresses
90        FFFF8F           TCSR0     EQU     $FFFF8F                           ; Timer control and status register
91        FFFF8E           TLR0      EQU     $FFFF8E                           ; Timer load register = 0
92        FFFF8D           TCPR0     EQU     $FFFF8D                           ; Timer compare register = exposure time
93        FFFF8C           TCR0      EQU     $FFFF8C                           ; Timer count register = elapsed time
94        FFFF83           TPLR      EQU     $FFFF83                           ; Timer prescaler load register => milliseconds
95        FFFF82           TPCR      EQU     $FFFF82                           ; Timer prescaler count register
96        000000           TIM_BIT   EQU     0                                 ; Set to enable the timer
97        000009           TRM       EQU     9                                 ; Set to enable the timer preloading
98        000015           TCF       EQU     21                                ; Set when timer counter = compare register
99     
100                        ; Board specific addresses and constants
101       FFFFF1           RDFO      EQU     $FFFFF1                           ; Read incoming fiber optic data byte
102       FFFFF2           WRFO      EQU     $FFFFF2                           ; Write fiber optic data replies
103       FFFFF3           WRSS      EQU     $FFFFF3                           ; Write switch state
104       FFFFF5           WRLATCH   EQU     $FFFFF5                           ; Write to a latch
105       010000           RDAD      EQU     $010000                           ; Read A/D values into the DSP
106       000009           EF        EQU     9                                 ; Serial receiver empty flag
107    
108                        ; DSP port A bit equates
109       000000           PWROK     EQU     0                                 ; Power control board says power is OK
110       000001           LED1      EQU     1                                 ; Control one of two LEDs
111       000002           LVEN      EQU     2                                 ; Low voltage power enable
112       000003           HVEN      EQU     3                                 ; High voltage power enable
113       00000E           SSFHF     EQU     14                                ; Switch state FIFO half full flag
114       00000A           EXT_IN0   EQU     10                                ; External digital I/O to the timing board
115       00000B           EXT_IN1   EQU     11
116       00000C           EXT_OUT0  EQU     12
117       00000D           EXT_OUT1  EQU     13
118    
119                        ; Port D equate
120       000001           SSFEF     EQU     1                                 ; Switch state FIFO empty flag
121    
122                        ; Other equates
123       000002           WRENA     EQU     2                                 ; Enable writing to the EEPROM
124    
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timhdr.asm  Page 3



125                        ; Latch U12 bit equates
126       000000           CDAC      EQU     0                                 ; Clear the analog board DACs
127       000002           ENCK      EQU     2                                 ; Enable the clock outputs
128       000004           SHUTTER   EQU     4                                 ; Control the shutter
129       000005           TIM_U_RST EQU     5                                 ; Reset the utility board
130    
131                        ; Software status bits, defined at X:<STATUS = X:0
132       000000           ST_RCV    EQU     0                                 ; Set to indicate word is from SCI = utility board
133       000002           IDLMODE   EQU     2                                 ; Set if need to idle after readout
134       000003           ST_SHUT   EQU     3                                 ; Set to indicate shutter is closed, clear for open
135       000004           ST_RDC    EQU     4                                 ; Set if executing 'RDC' command - reading out
136       000005           SPLIT_S   EQU     5                                 ; Set if split serial
137       000006           SPLIT_P   EQU     6                                 ; Set if split parallel
138       000007           MPP       EQU     7                                 ; Set if parallels are in MPP mode
139       000008           NOT_CLR   EQU     8                                 ; Set if not to clear CCD before exposure
140       00000A           TST_IMG   EQU     10                                ; Set if controller is to generate a test image
141       00000B           SHUT      EQU     11                                ; Set if opening shutter at beginning of exposure
142       00000C           ST_DITH   EQU     12                                ; Set if to dither during exposure
143       00000D           ST_SYNC   EQU     13                                ; Set if starting exposure on SYNC = high signal
144       00000E           ST_CNRD   EQU     14                                ; Set if in continous readout mode
145       00000F           ST_CDS    EQU     15                                ; Set if correlated double sample
146       000010           ST_RD     EQU     16                                ; Set if the signal 'READ' should be turned on and of
f
147    
148                        ; Address for the table containing the incoming SCI words
149       000400           SCI_TABLE EQU     $400
150    
151    
152                        ; Specify controller configuration bits of the X:STATUS word
153                        ;   to describe the software capabilities of this application file
154                        ; The bit is set (=1) if the capability is supported by the controller
155    
156    
157                                COMMENT *
158    
159                        BIT #'s         FUNCTION
160                        2,1,0           Video Processor
161                                                000     CCD Rev. 3
162                                                001     CCD Gen I
163                                                010     IR Rev. 4
164                                                011     IR Coadder
165                                                100     CCD Rev. 5, Differential input
166                                                101     8x IR
167    
168                        4,3             Timing Board
169                                                00      Rev. 4, Gen II
170                                                01      Gen I
171                                                10      Rev. 5, Gen III, 250 MHz
172    
173                        6,5             Utility Board
174                                                00      No utility board
175                                                01      Utility Rev. 3
176    
177                        7               Shutter
178                                                0       No shutter support
179                                                1       Yes shutter support
180    
181                        9,8             Temperature readout
182                                                00      No temperature readout
183                                                01      Polynomial Diode calibration
184                                                10      Linear temperature sensor calibration
185    
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timhdr.asm  Page 4



186                        10              Subarray readout
187                                                0       Not supported
188                                                1       Yes supported
189    
190                        11              Binning
191                                                0       Not supported
192                                                1       Yes supported
193    
194                        12              Split-Serial readout
195                                                0       Not supported
196                                                1       Yes supported
197    
198                        13              Split-Parallel readout
199                                                0       Not supported
200                                                1       Yes supported
201    
202                        14              MPP = Inverted parallel clocks
203                                                0       Not supported
204                                                1       Yes supported
205    
206                        16,15           Clock Driver Board
207                                                00      Rev. 3
208                                                11      No clock driver board (Gen I)
209    
210                        19,18,17                Special implementations
211                                                000     Somewhere else
212                                                001     Mount Laguna Observatory
213                                                010     NGST Aladdin
214                                                xxx     Other
215                                *
216    
217                        CCDVIDREV3B
218       000000                     EQU     $000000                           ; CCD Video Processor Rev. 3
219       000001           VIDGENI   EQU     $000001                           ; CCD Video Processor Gen I
220       000002           IRREV4    EQU     $000002                           ; IR Video Processor Rev. 4
221       000003           COADDER   EQU     $000003                           ; IR Coadder
222       000004           CCDVIDREV5 EQU    $000004                           ; Differential input CCD video Rev. 5
223       000000           TIMREV4   EQU     $000000                           ; Timing Revision 4 = 50 MHz
224       000008           TIMGENI   EQU     $000008                           ; Timing Gen I = 40 MHz
225       000010           TIMREV5   EQU     $000010                           ; Timing Revision 5 = 250 MHz
226       000020           UTILREV3  EQU     $000020                           ; Utility Rev. 3 supported
227       000080           SHUTTER_CC EQU    $000080                           ; Shutter supported
228       000100           TEMP_POLY EQU     $000100                           ; Polynomial calibration
229                        TEMP_LINEAR
230       000200                     EQU     $000200                           ; Linear calibration
231       000400           SUBARRAY  EQU     $000400                           ; Subarray readout supported
232       000800           BINNING   EQU     $000800                           ; Binning supported
233                        SPLIT_SERIAL
234       001000                     EQU     $001000                           ; Split serial supported
235                        SPLIT_PARALLEL
236       002000                     EQU     $002000                           ; Split parallel supported
237       004000           MPP_CC    EQU     $004000                           ; Inverted clocks supported
238       018000           CLKDRVGENI EQU    $018000                           ; No clock driver board - Gen I
239       020000           MLO       EQU     $020000                           ; Set if Mount Laguna Observatory
240       040000           NGST      EQU     $040000                           ; NGST Aladdin implementation
241       100000           CONT_RD   EQU     $100000                           ; Continuous readout implemented
242    
243                                  INCLUDE "timboot.asm"
244                               COMMENT *
245    
246                        This file is used to generate boot DSP code for the 250 MHz fiber optic
247                                timing board using a DSP56303 as its main processor.
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 5



248                        Added utility board support Dec. 2002
249                                *
250                                  PAGE    132                               ; Printronix page width - 132 columns
251    
252                        ; Special address for two words for the DSP to bootstrap code from the EEPROM
253                                  IF      @SCP("HOST","ROM")
260                                  ENDIF
261    
262                                  IF      @SCP("HOST","HOST")
263       P:000000 P:000000                   ORG     P:0,P:0
264       P:000000 P:000000 0C0190            JMP     <INIT
265       P:000001 P:000001 000000            NOP
266                                           ENDIF
267    
268                                 ;  This ISR receives serial words a byte at a time over the asynchronous
269                                 ;    serial link (SCI) and squashes them into a single 24-bit word
270       P:000002 P:000002 602400  SCI_RCV   MOVE              R0,X:<SAVE_R0           ; Save R0
271       P:000003 P:000003 052139            MOVEC             SR,X:<SAVE_SR           ; Save Status Register
272       P:000004 P:000004 60A700            MOVE              X:<SCI_R0,R0            ; Restore R0 = pointer to SCI receive regist
er
273       P:000005 P:000005 542300            MOVE              A1,X:<SAVE_A1           ; Save A1
274       P:000006 P:000006 452200            MOVE              X1,X:<SAVE_X1           ; Save X1
275       P:000007 P:000007 54A600            MOVE              X:<SCI_A1,A1            ; Get SRX value of accumulator contents
276       P:000008 P:000008 45E000            MOVE              X:(R0),X1               ; Get the SCI byte
277       P:000009 P:000009 0AD041            BCLR    #1,R0                             ; Test for the address being $FFF6 = last by
te
278       P:00000A P:00000A 000000            NOP
279       P:00000B P:00000B 000000            NOP
280       P:00000C P:00000C 000000            NOP
281       P:00000D P:00000D 205862            OR      X1,A      (R0)+                   ; Add the byte into the 24-bit word
282       P:00000E P:00000E 0E0013            JCC     <MID_BYT                          ; Not the last byte => only restore register
s
283       P:00000F P:00000F 545C00  END_BYT   MOVE              A1,X:(R4)+              ; Put the 24-bit word into the SCI buffer
284       P:000010 P:000010 60F400            MOVE              #SRXL,R0                ; Re-establish first address of SCI interfac
e
                            FFFF98
285       P:000012 P:000012 2C0000            MOVE              #0,A1                   ; For zeroing out SCI_A1
286       P:000013 P:000013 602700  MID_BYT   MOVE              R0,X:<SCI_R0            ; Save the SCI receiver address
287       P:000014 P:000014 542600            MOVE              A1,X:<SCI_A1            ; Save A1 for next interrupt
288       P:000015 P:000015 05A139            MOVEC             X:<SAVE_SR,SR           ; Restore Status Register
289       P:000016 P:000016 54A300            MOVE              X:<SAVE_A1,A1           ; Restore A1
290       P:000017 P:000017 45A200            MOVE              X:<SAVE_X1,X1           ; Restore X1
291       P:000018 P:000018 60A400            MOVE              X:<SAVE_R0,R0           ; Restore R0
292       P:000019 P:000019 000004            RTI                                       ; Return from interrupt service
293    
294                                 ; Clear error condition and interrupt on SCI receiver
295       P:00001A P:00001A 077013  CLR_ERR   MOVEP             X:SSR,X:RCV_ERR         ; Read SCI status register
                            000025
296       P:00001C P:00001C 077018            MOVEP             X:SRXL,X:RCV_ERR        ; This clears any error
                            000025
297       P:00001E P:00001E 000004            RTI
298    
299       P:00001F P:00001F                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
300       P:000030 P:000030                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
301       P:000040 P:000040                   DC      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
302    
303                                 ; Tune the table so the following instruction is at P:$50 exactly.
304       P:000050 P:000050 0D0002            JSR     SCI_RCV                           ; SCI receive data interrupt
305       P:000051 P:000051 000000            NOP
306       P:000052 P:000052 0D001A            JSR     CLR_ERR                           ; SCI receive error interrupt
307       P:000053 P:000053 000000            NOP
308    
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 6



309                                 ; *******************  Command Processing  ******************
310    
311                                 ; Read the header and check it for self-consistency
312       P:000054 P:000054 609F00  START     MOVE              X:<IDL_ADR,R0
313       P:000055 P:000055 018FA0            JSET    #TIM_BIT,X:TCSR0,EXPOSING         ; If exposing go check the timer
                            000323
314       P:000057 P:000057 0A00A4            JSET    #ST_RDC,X:<STATUS,CONTINUE_READING
                            000380
315       P:000059 P:000059 0AE080            JMP     (R0)
316    
317       P:00005A P:00005A 330700  TST_RCV   MOVE              #<COM_BUF,R3
318       P:00005B P:00005B 0D00A5            JSR     <GET_RCV
319       P:00005C P:00005C 0E005B            JCC     *-1
320    
321                                 ; Check the header and read all the remaining words in the command
322       P:00005D P:00005D 0C00FF  PRC_RCV   JMP     <CHK_HDR                          ; Update HEADER and NWORDS
323       P:00005E P:00005E 578600  PR_RCV    MOVE              X:<NWORDS,B             ; Read this many words total in the command
324       P:00005F P:00005F 000000            NOP
325       P:000060 P:000060 01418C            SUB     #1,B                              ; We've already read the header
326       P:000061 P:000061 000000            NOP
327       P:000062 P:000062 06CF00            DO      B,RD_COM
                            00006A
328       P:000064 P:000064 205B00            MOVE              (R3)+                   ; Increment past what's been read already
329       P:000065 P:000065 0B0080  GET_WRD   JSCLR   #ST_RCV,X:STATUS,CHK_FO
                            0000A9
330       P:000067 P:000067 0B00A0            JSSET   #ST_RCV,X:STATUS,CHK_SCI
                            0000D5
331       P:000069 P:000069 0E0065            JCC     <GET_WRD
332       P:00006A P:00006A 000000            NOP
333       P:00006B P:00006B 330700  RD_COM    MOVE              #<COM_BUF,R3            ; Restore R3 = beginning of the command
334    
335                                 ; Is this command for the timing board?
336       P:00006C P:00006C 448500            MOVE              X:<HEADER,X0
337       P:00006D P:00006D 579B00            MOVE              X:<DMASK,B
338       P:00006E P:00006E 459A4E            AND     X0,B      X:<TIM_DRB,X1           ; Extract destination byte
339       P:00006F P:00006F 20006D            CMP     X1,B                              ; Does header = timing board number?
340       P:000070 P:000070 0EA080            JEQ     <COMMAND                          ; Yes, process it here
341       P:000071 P:000071 0E909D            JLT     <FO_XMT                           ; Send it to fiber optic transmitter
342    
343                                 ; Transmit the command to the utility board over the SCI port
344       P:000072 P:000072 060600            DO      X:<NWORDS,DON_XMT                 ; Transmit NWORDS
                            00007E
345       P:000074 P:000074 60F400            MOVE              #STXL,R0                ; SCI first byte address
                            FFFF95
346       P:000076 P:000076 44DB00            MOVE              X:(R3)+,X0              ; Get the 24-bit word to transmit
347       P:000077 P:000077 060380            DO      #3,SCI_SPT
                            00007D
348       P:000079 P:000079 019381            JCLR    #TDRE,X:SSR,*                     ; Continue ONLY if SCI XMT is empty
                            000079
349       P:00007B P:00007B 445800            MOVE              X0,X:(R0)+              ; Write to SCI, byte pointer + 1
350       P:00007C P:00007C 000000            NOP                                       ; Delay for the status flag to be set
351       P:00007D P:00007D 000000            NOP
352                                 SCI_SPT
353       P:00007E P:00007E 000000            NOP
354                                 DON_XMT
355       P:00007F P:00007F 0C0054            JMP     <START
356    
357                                 ; Process the receiver entry - is it in the command table ?
358       P:000080 P:000080 0203DF  COMMAND   MOVE              X:(R3+1),B              ; Get the command
359       P:000081 P:000081 205B00            MOVE              (R3)+
360       P:000082 P:000082 205B00            MOVE              (R3)+                   ; Point R3 to the first argument
361       P:000083 P:000083 302800            MOVE              #<COM_TBL,R0            ; Get the command table starting address
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 7



362       P:000084 P:000084 061B80            DO      #NUM_COM,END_COM                  ; Loop over the command table
                            00008B
363       P:000086 P:000086 47D800            MOVE              X:(R0)+,Y1              ; Get the command table entry
364       P:000087 P:000087 62E07D            CMP     Y1,B      X:(R0),R2               ; Does receiver = table entries address?
365       P:000088 P:000088 0E208B            JNE     <NOT_COM                          ; No, keep looping
366       P:000089 P:000089 00008C            ENDDO                                     ; Restore the DO loop system registers
367       P:00008A P:00008A 0AE280            JMP     (R2)                              ; Jump execution to the command
368       P:00008B P:00008B 205800  NOT_COM   MOVE              (R0)+                   ; Increment the register past the table addr
ess
369                                 END_COM
370       P:00008C P:00008C 0C008D            JMP     <ERROR                            ; The command is not in the table
371    
372                                 ; It's not in the command table - send an error message
373       P:00008D P:00008D 479D00  ERROR     MOVE              X:<ERR,Y1               ; Send the message - there was an error
374       P:00008E P:00008E 0C0090            JMP     <FINISH1                          ; This protects against unknown commands
375    
376                                 ; Send a reply packet - header and reply
377       P:00008F P:00008F 479800  FINISH    MOVE              X:<DONE,Y1              ; Send 'DON' as the reply
378       P:000090 P:000090 578500  FINISH1   MOVE              X:<HEADER,B             ; Get header of incoming command
379       P:000091 P:000091 469C00            MOVE              X:<SMASK,Y0             ; This was the source byte, and is to
380       P:000092 P:000092 330700            MOVE              #<COM_BUF,R3            ;     become the destination byte
381       P:000093 P:000093 46935E            AND     Y0,B      X:<TWO,Y0
382       P:000094 P:000094 0C1ED1            LSR     #8,B                              ; Shift right eight bytes, add it to the
383       P:000095 P:000095 460600            MOVE              Y0,X:<NWORDS            ;     header, and put 2 as the number
384       P:000096 P:000096 469958            ADD     Y0,B      X:<SBRD,Y0              ;     of words in the string
385       P:000097 P:000097 200058            ADD     Y0,B                              ; Add source board's header, set Y1 for abov
e
386       P:000098 P:000098 000000            NOP
387       P:000099 P:000099 575B00            MOVE              B,X:(R3)+               ; Put the new header on the transmitter stac
k
388       P:00009A P:00009A 475B00            MOVE              Y1,X:(R3)+              ; Put the argument on the transmitter stack
389       P:00009B P:00009B 570500            MOVE              B,X:<HEADER
390       P:00009C P:00009C 0C006B            JMP     <RD_COM                           ; Decide where to send the reply, and do it
391    
392                                 ; Transmit words to the host computer over the fiber optics link
393       P:00009D P:00009D 63F400  FO_XMT    MOVE              #COM_BUF,R3
                            000007
394       P:00009F P:00009F 060600            DO      X:<NWORDS,DON_FFO                 ; Transmit all the words in the command
                            0000A3
395       P:0000A1 P:0000A1 57DB00            MOVE              X:(R3)+,B
396       P:0000A2 P:0000A2 0D00EB            JSR     <XMT_WRD
397       P:0000A3 P:0000A3 000000            NOP
398       P:0000A4 P:0000A4 0C0054  DON_FFO   JMP     <START
399    
400                                 ; Check for commands from the fiber optic FIFO and the utility board (SCI)
401       P:0000A5 P:0000A5 0D00A9  GET_RCV   JSR     <CHK_FO                           ; Check for fiber optic command from FIFO
402       P:0000A6 P:0000A6 0E80A8            JCS     <RCV_RTS                          ; If there's a command, check the header
403       P:0000A7 P:0000A7 0D00D5            JSR     <CHK_SCI                          ; Check for an SCI command
404       P:0000A8 P:0000A8 00000C  RCV_RTS   RTS
405    
406                                 ; Because of FIFO metastability require that EF be stable for two tests
407       P:0000A9 P:0000A9 0A8989  CHK_FO    JCLR    #EF,X:HDR,TST2                    ; EF = Low,  Low  => CLR SR, return
                            0000AC
408       P:0000AB P:0000AB 0C00AF            JMP     <TST3                             ;      High, Low  => try again
409       P:0000AC P:0000AC 0A8989  TST2      JCLR    #EF,X:HDR,CLR_CC                  ;      Low,  High => try again
                            0000D1
410       P:0000AE P:0000AE 0C00A9            JMP     <CHK_FO                           ;      High, High => read FIFO
411       P:0000AF P:0000AF 0A8989  TST3      JCLR    #EF,X:HDR,CHK_FO
                            0000A9
412    
413       P:0000B1 P:0000B1 08F4BB            MOVEP             #$028FE2,X:BCR          ; Slow down RDFO access
                            028FE2
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 8



414       P:0000B3 P:0000B3 000000            NOP
415       P:0000B4 P:0000B4 000000            NOP
416       P:0000B5 P:0000B5 5FF000            MOVE                          Y:RDFO,B
                            FFFFF1
417       P:0000B7 P:0000B7 2B0000            MOVE              #0,B2
418       P:0000B8 P:0000B8 0140CE            AND     #$FF,B
                            0000FF
419       P:0000BA P:0000BA 0140CD            CMP     #>$AC,B                           ; It must be $AC to be a valid word
                            0000AC
420       P:0000BC P:0000BC 0E20D1            JNE     <CLR_CC
421       P:0000BD P:0000BD 4EF000            MOVE                          Y:RDFO,Y0   ; Read the MS byte
                            FFFFF1
422       P:0000BF P:0000BF 0C1951            INSERT  #$008010,Y0,B
                            008010
423       P:0000C1 P:0000C1 4EF000            MOVE                          Y:RDFO,Y0   ; Read the middle byte
                            FFFFF1
424       P:0000C3 P:0000C3 0C1951            INSERT  #$008008,Y0,B
                            008008
425       P:0000C5 P:0000C5 4EF000            MOVE                          Y:RDFO,Y0   ; Read the LS byte
                            FFFFF1
426       P:0000C7 P:0000C7 0C1951            INSERT  #$008000,Y0,B
                            008000
427       P:0000C9 P:0000C9 000000            NOP
428       P:0000CA P:0000CA 516300            MOVE              B0,X:(R3)               ; Put the word into COM_BUF
429       P:0000CB P:0000CB 0A0000            BCLR    #ST_RCV,X:<STATUS                 ; Its a command from the host computer
430       P:0000CC P:0000CC 000000  SET_CC    NOP
431       P:0000CD P:0000CD 0AF960            BSET    #0,SR                             ; Valid word => SR carry bit = 1
432       P:0000CE P:0000CE 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
433       P:0000D0 P:0000D0 00000C            RTS
434       P:0000D1 P:0000D1 0AF940  CLR_CC    BCLR    #0,SR                             ; Not valid word => SR carry bit = 0
435       P:0000D2 P:0000D2 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
436       P:0000D4 P:0000D4 00000C            RTS
437    
438                                 ; Test the SCI (= synchronous communications interface) for new words
439       P:0000D5 P:0000D5 44F000  CHK_SCI   MOVE              X:(SCI_TABLE+33),X0
                            000421
440       P:0000D7 P:0000D7 228E00            MOVE              R4,A
441       P:0000D8 P:0000D8 209000            MOVE              X0,R0
442       P:0000D9 P:0000D9 200045            CMP     X0,A
443       P:0000DA P:0000DA 0EA0D1            JEQ     <CLR_CC                           ; There is no new SCI word
444       P:0000DB P:0000DB 44D800            MOVE              X:(R0)+,X0
445       P:0000DC P:0000DC 446300            MOVE              X0,X:(R3)
446       P:0000DD P:0000DD 220E00            MOVE              R0,A
447       P:0000DE P:0000DE 0140C5            CMP     #(SCI_TABLE+32),A                 ; Wrap it around the circular
                            000420
448       P:0000E0 P:0000E0 0EA0E4            JEQ     <INIT_PROCESSED_SCI               ;   buffer boundary
449       P:0000E1 P:0000E1 547000            MOVE              A1,X:(SCI_TABLE+33)
                            000421
450       P:0000E3 P:0000E3 0C00E9            JMP     <SCI_END
451                                 INIT_PROCESSED_SCI
452       P:0000E4 P:0000E4 56F400            MOVE              #SCI_TABLE,A
                            000400
453       P:0000E6 P:0000E6 000000            NOP
454       P:0000E7 P:0000E7 567000            MOVE              A,X:(SCI_TABLE+33)
                            000421
455       P:0000E9 P:0000E9 0A0020  SCI_END   BSET    #ST_RCV,X:<STATUS                 ; Its a utility board (SCI) word
456       P:0000EA P:0000EA 0C00CC            JMP     <SET_CC
457    
458                                 ; Transmit the word in B1 to the host computer over the fiber optic data link
459                                 XMT_WRD
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 9



460       P:0000EB P:0000EB 08F4BB            MOVEP             #$028FE2,X:BCR          ; Slow down RDFO access
                            028FE2
461       P:0000ED P:0000ED 60F400            MOVE              #FO_HDR+1,R0
                            000002
462       P:0000EF P:0000EF 060380            DO      #3,XMT_WRD1
                            0000F3
463       P:0000F1 P:0000F1 0C1D91            ASL     #8,B,B
464       P:0000F2 P:0000F2 000000            NOP
465       P:0000F3 P:0000F3 535800            MOVE              B2,X:(R0)+
466                                 XMT_WRD1
467       P:0000F4 P:0000F4 60F400            MOVE              #FO_HDR,R0
                            000001
468       P:0000F6 P:0000F6 61F400            MOVE              #WRFO,R1
                            FFFFF2
469       P:0000F8 P:0000F8 060480            DO      #4,XMT_WRD2
                            0000FB
470       P:0000FA P:0000FA 46D800            MOVE              X:(R0)+,Y0              ; Should be MOVEP  X:(R0)+,Y:WRFO
471       P:0000FB P:0000FB 4E6100            MOVE                          Y0,Y:(R1)
472                                 XMT_WRD2
473       P:0000FC P:0000FC 08F4BB            MOVEP             #$028FE1,X:BCR          ; Restore RDFO access
                            028FE1
474       P:0000FE P:0000FE 00000C            RTS
475    
476                                 ; Check the command or reply header in X:(R3) for self-consistency
477       P:0000FF P:0000FF 46E300  CHK_HDR   MOVE              X:(R3),Y0
478       P:000100 P:000100 579600            MOVE              X:<MASK1,B              ; Test for S.LE.3 and D.LE.3 and N.LE.7
479       P:000101 P:000101 20005E            AND     Y0,B
480       P:000102 P:000102 0E208D            JNE     <ERROR                            ; Test failed
481       P:000103 P:000103 579700            MOVE              X:<MASK2,B              ; Test for either S.NE.0 or D.NE.0
482       P:000104 P:000104 20005E            AND     Y0,B
483       P:000105 P:000105 0EA08D            JEQ     <ERROR                            ; Test failed
484       P:000106 P:000106 579500            MOVE              X:<SEVEN,B
485       P:000107 P:000107 20005E            AND     Y0,B                              ; Extract NWORDS, must be > 0
486       P:000108 P:000108 0EA08D            JEQ     <ERROR
487       P:000109 P:000109 44E300            MOVE              X:(R3),X0
488       P:00010A P:00010A 440500            MOVE              X0,X:<HEADER            ; Its a correct header
489       P:00010B P:00010B 550600            MOVE              B1,X:<NWORDS            ; Number of words in the command
490       P:00010C P:00010C 0C005E            JMP     <PR_RCV
491    
492                                 ;  *****************  Boot Commands  *******************
493    
494                                 ; Test Data Link - simply return value received after 'TDL'
495       P:00010D P:00010D 47DB00  TDL       MOVE              X:(R3)+,Y1              ; Get the data value
496       P:00010E P:00010E 0C0090            JMP     <FINISH1                          ; Return from executing TDL command
497    
498                                 ; Read DSP or EEPROM memory ('RDM' address): read memory, reply with value
499       P:00010F P:00010F 47DB00  RDMEM     MOVE              X:(R3)+,Y1
500       P:000110 P:000110 20EF00            MOVE              Y1,B
501       P:000111 P:000111 0140CE            AND     #$0FFFFF,B                        ; Bits 23-20 need to be zeroed
                            0FFFFF
502       P:000113 P:000113 21B000            MOVE              B1,R0                   ; Need the address in an address register
503       P:000114 P:000114 20EF00            MOVE              Y1,B
504       P:000115 P:000115 000000            NOP
505       P:000116 P:000116 0ACF14            JCLR    #20,B,RDX                         ; Test address bit for Program memory
                            00011A
506       P:000118 P:000118 07E087            MOVE              P:(R0),Y1               ; Read from Program Memory
507       P:000119 P:000119 0C0090            JMP     <FINISH1                          ; Send out a header with the value
508       P:00011A P:00011A 0ACF15  RDX       JCLR    #21,B,RDY                         ; Test address bit for X: memory
                            00011E
509       P:00011C P:00011C 47E000            MOVE              X:(R0),Y1               ; Write to X data memory
510       P:00011D P:00011D 0C0090            JMP     <FINISH1                          ; Send out a header with the value
511       P:00011E P:00011E 0ACF16  RDY       JCLR    #22,B,RDR                         ; Test address bit for Y: memory
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 10



                            000122
512       P:000120 P:000120 4FE000            MOVE                          Y:(R0),Y1   ; Read from Y data memory
513       P:000121 P:000121 0C0090            JMP     <FINISH1                          ; Send out a header with the value
514       P:000122 P:000122 0ACF17  RDR       JCLR    #23,B,ERROR                       ; Test address bit for read from EEPROM memo
ry
                            00008D
515       P:000124 P:000124 479400            MOVE              X:<THREE,Y1             ; Convert to word address to a byte address
516       P:000125 P:000125 220600            MOVE              R0,Y0                   ; Get 16-bit address in a data register
517       P:000126 P:000126 2000B8            MPY     Y0,Y1,B                           ; Multiply
518       P:000127 P:000127 20002A            ASR     B                                 ; Eliminate zero fill of fractional multiply
519       P:000128 P:000128 213000            MOVE              B0,R0                   ; Need to address memory
520       P:000129 P:000129 0AD06F            BSET    #15,R0                            ; Set bit so its in EEPROM space
521       P:00012A P:00012A 0D0178            JSR     <RD_WORD                          ; Read word from EEPROM
522       P:00012B P:00012B 21A700            MOVE              B1,Y1                   ; FINISH1 transmits Y1 as its reply
523       P:00012C P:00012C 0C0090            JMP     <FINISH1
524    
525                                 ; Program WRMEM ('WRM' address datum): write to memory, reply 'DON'.
526       P:00012D P:00012D 47DB00  WRMEM     MOVE              X:(R3)+,Y1              ; Get the address to be written to
527       P:00012E P:00012E 20EF00            MOVE              Y1,B
528       P:00012F P:00012F 0140CE            AND     #$0FFFFF,B                        ; Bits 23-20 need to be zeroed
                            0FFFFF
529       P:000131 P:000131 21B000            MOVE              B1,R0                   ; Need the address in an address register
530       P:000132 P:000132 20EF00            MOVE              Y1,B
531       P:000133 P:000133 46DB00            MOVE              X:(R3)+,Y0              ; Get datum into Y0 so MOVE works easily
532       P:000134 P:000134 0ACF14            JCLR    #20,B,WRX                         ; Test address bit for Program memory
                            000138
533       P:000136 P:000136 076086            MOVE              Y0,P:(R0)               ; Write to Program memory
534       P:000137 P:000137 0C008F            JMP     <FINISH
535       P:000138 P:000138 0ACF15  WRX       JCLR    #21,B,WRY                         ; Test address bit for X: memory
                            00013C
536       P:00013A P:00013A 466000            MOVE              Y0,X:(R0)               ; Write to X: memory
537       P:00013B P:00013B 0C008F            JMP     <FINISH
538       P:00013C P:00013C 0ACF16  WRY       JCLR    #22,B,WRR                         ; Test address bit for Y: memory
                            000140
539       P:00013E P:00013E 4E6000            MOVE                          Y0,Y:(R0)   ; Write to Y: memory
540       P:00013F P:00013F 0C008F            JMP     <FINISH
541       P:000140 P:000140 0ACF17  WRR       JCLR    #23,B,ERROR                       ; Test address bit for write to EEPROM
                            00008D
542       P:000142 P:000142 013D02            BCLR    #WRENA,X:PDRC                     ; WR_ENA* = 0 to enable EEPROM writing
543       P:000143 P:000143 460E00            MOVE              Y0,X:<SV_A1             ; Save the datum to be written
544       P:000144 P:000144 479400            MOVE              X:<THREE,Y1             ; Convert word address to a byte address
545       P:000145 P:000145 220600            MOVE              R0,Y0                   ; Get 16-bit address in a data register
546       P:000146 P:000146 2000B8            MPY     Y1,Y0,B                           ; Multiply
547       P:000147 P:000147 20002A            ASR     B                                 ; Eliminate zero fill of fractional multiply
548       P:000148 P:000148 213000            MOVE              B0,R0                   ; Need to address memory
549       P:000149 P:000149 0AD06F            BSET    #15,R0                            ; Set bit so its in EEPROM space
550       P:00014A P:00014A 558E00            MOVE              X:<SV_A1,B1             ; Get the datum to be written
551       P:00014B P:00014B 060380            DO      #3,L1WRR                          ; Loop over three bytes of the word
                            000154
552       P:00014D P:00014D 07588D            MOVE              B1,P:(R0)+              ; Write each EEPROM byte
553       P:00014E P:00014E 0C1C91            ASR     #8,B,B
554       P:00014F P:00014F 469E00            MOVE              X:<C100K,Y0             ; Move right one byte, enter delay = 1 msec
555       P:000150 P:000150 06C600            DO      Y0,L2WRR                          ; Delay by 12 milliseconds for EEPROM write
                            000153
556       P:000152 P:000152 060CA0            REP     #12                               ; Assume 100 MHz DSP56303
557       P:000153 P:000153 000000            NOP
558                                 L2WRR
559       P:000154 P:000154 000000            NOP                                       ; DO loop nesting restriction
560                                 L1WRR
561       P:000155 P:000155 013D22            BSET    #WRENA,X:PDRC                     ; WR_ENA* = 1 to disable EEPROM writing
562       P:000156 P:000156 0C008F            JMP     <FINISH
563    
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 11



564                                 ; Load application code from P: memory into its proper locations
565       P:000157 P:000157 47DB00  LDAPPL    MOVE              X:(R3)+,Y1              ; Application number, not used yet
566       P:000158 P:000158 0D015A            JSR     <LOAD_APPLICATION
567       P:000159 P:000159 0C008F            JMP     <FINISH
568    
569                                 LOAD_APPLICATION
570       P:00015A P:00015A 60F400            MOVE              #$8000,R0               ; Starting EEPROM address
                            008000
571       P:00015C P:00015C 0D0178            JSR     <RD_WORD                          ; Number of words in boot code
572       P:00015D P:00015D 21A600            MOVE              B1,Y0
573       P:00015E P:00015E 479400            MOVE              X:<THREE,Y1
574       P:00015F P:00015F 2000B8            MPY     Y0,Y1,B
575       P:000160 P:000160 20002A            ASR     B
576       P:000161 P:000161 213000            MOVE              B0,R0                   ; EEPROM address of start of P: application
577       P:000162 P:000162 0AD06F            BSET    #15,R0                            ; To access EEPROM
578       P:000163 P:000163 0D0178            JSR     <RD_WORD                          ; Read number of words in application P:
579       P:000164 P:000164 61F400            MOVE              #(X_BOOT_START+1),R1    ; End of boot P: code that needs keeping
                            000228
580       P:000166 P:000166 06CD00            DO      B1,RD_APPL_P
                            000169
581       P:000168 P:000168 0D0178            JSR     <RD_WORD
582       P:000169 P:000169 07598D            MOVE              B1,P:(R1)+
583                                 RD_APPL_P
584       P:00016A P:00016A 0D0178            JSR     <RD_WORD                          ; Read number of words in application X:
585       P:00016B P:00016B 61F400            MOVE              #END_COMMAND_TABLE,R1
                            000036
586       P:00016D P:00016D 06CD00            DO      B1,RD_APPL_X
                            000170
587       P:00016F P:00016F 0D0178            JSR     <RD_WORD
588       P:000170 P:000170 555900            MOVE              B1,X:(R1)+
589                                 RD_APPL_X
590       P:000171 P:000171 0D0178            JSR     <RD_WORD                          ; Read number of words in application Y:
591       P:000172 P:000172 310100            MOVE              #1,R1                   ; There is no Y: memory in the boot code
592       P:000173 P:000173 06CD00            DO      B1,RD_APPL_Y
                            000176
593       P:000175 P:000175 0D0178            JSR     <RD_WORD
594       P:000176 P:000176 5D5900            MOVE                          B1,Y:(R1)+
595                                 RD_APPL_Y
596       P:000177 P:000177 00000C            RTS
597    
598                                 ; Read one word from EEPROM location R0 into accumulator B1
599       P:000178 P:000178 060380  RD_WORD   DO      #3,L_RDBYTE
                            00017B
600       P:00017A P:00017A 07D88B            MOVE              P:(R0)+,B2
601       P:00017B P:00017B 0C1C91            ASR     #8,B,B
602                                 L_RDBYTE
603       P:00017C P:00017C 00000C            RTS
604    
605                                 ; Come to here on a 'STP' command so 'DON' can be sent
606                                 STOP_IDLE_CLOCKING
607       P:00017D P:00017D 305A00            MOVE              #<TST_RCV,R0            ; Execution address when idle => when not
608       P:00017E P:00017E 601F00            MOVE              R0,X:<IDL_ADR           ;   processing commands or reading out
609       P:00017F P:00017F 0A0002            BCLR    #IDLMODE,X:<STATUS                ; Don't idle after readout
610       P:000180 P:000180 0C008F            JMP     <FINISH
611    
612                                 ; Routines executed after the DSP boots and initializes
613       P:000181 P:000181 305A00  STARTUP   MOVE              #<TST_RCV,R0            ; Execution address when idle => when not
614       P:000182 P:000182 601F00            MOVE              R0,X:<IDL_ADR           ;   processing commands or reading out
615       P:000183 P:000183 44F400            MOVE              #50000,X0               ; Delay by 500 milliseconds
                            00C350
616       P:000185 P:000185 06C400            DO      X0,L_DELAY
                            000188
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 12



617       P:000187 P:000187 06E8A3            REP     #1000
618       P:000188 P:000188 000000            NOP
619                                 L_DELAY
620       P:000189 P:000189 57F400            MOVE              #$020002,B              ; Normal reply after booting is 'SYR'
                            020002
621       P:00018B P:00018B 0D00EB            JSR     <XMT_WRD
622       P:00018C P:00018C 57F400            MOVE              #'SYR',B
                            535952
623       P:00018E P:00018E 0D00EB            JSR     <XMT_WRD
624    
625       P:00018F P:00018F 0C0054            JMP     <START                            ; Start normal command processing
626    
627                                 ; *******************  DSP  INITIALIZATION  CODE  **********************
628                                 ; This code initializes the DSP right after booting, and is overwritten
629                                 ;   by application code
630       P:000190 P:000190 08F4BD  INIT      MOVEP             #PLL_INIT,X:PCTL        ; Initialize PLL to 100 MHz
                            050003
631       P:000192 P:000192 000000            NOP
632    
633                                 ; Set operation mode register OMR to normal expanded
634       P:000193 P:000193 0500BA            MOVEC             #$0000,OMR              ; Operating Mode Register = Normal Expanded
635       P:000194 P:000194 0500BB            MOVEC             #0,SP                   ; Reset the Stack Pointer SP
636    
637                                 ; Program the AA = address attribute pins
638       P:000195 P:000195 08F4B9            MOVEP             #$FFFC21,X:AAR0         ; Y = $FFF000 to $FFFFFF asserts commands
                            FFFC21
639       P:000197 P:000197 08F4B8            MOVEP             #$008909,X:AAR1         ; P = $008000 to $00FFFF accesses the EEPROM
                            008909
640       P:000199 P:000199 08F4B7            MOVEP             #$010C11,X:AAR2         ; X = $010000 to $010FFF reads A/D values
                            010C11
641       P:00019B P:00019B 08F4B6            MOVEP             #$080621,X:AAR3         ; Y = $080000 to $0BFFFF R/W from SRAM
                            080621
642    
643                                 ; Program the DRAM memory access and addressing
644       P:00019D P:00019D 08F4BB            MOVEP             #$028FE1,X:BCR          ; Bus Control Register
                            028FE1
645    
646                                 ; Program the Host port B for parallel I/O
647       P:00019F P:00019F 08F484            MOVEP             #>1,X:HPCR              ; All pins enabled as GPIO
                            000001
648       P:0001A1 P:0001A1 08F489            MOVEP             #$810C,X:HDR
                            00810C
649       P:0001A3 P:0001A3 08F488            MOVEP             #$B10E,X:HDDR           ; Data Direction Register
                            00B10E
650                                                                                     ;  (1 for Output, 0 for Input)
651    
652                                 ; Port B conversion from software bits to schematic labels
653                                 ;       PB0 = PWROK             PB08 = PRSFIFO*
654                                 ;       PB1 = LED1              PB09 = EF*
655                                 ;       PB2 = LVEN              PB10 = EXT-IN0
656                                 ;       PB3 = HVEN              PB11 = EXT-IN1
657                                 ;       PB4 = STATUS0           PB12 = EXT-OUT0
658                                 ;       PB5 = STATUS1           PB13 = EXT-OUT1
659                                 ;       PB6 = STATUS2           PB14 = SSFHF*
660                                 ;       PB7 = STATUS3           PB15 = SELSCI
661    
662                                 ; Program the serial port ESSI0 = Port C for serial communication with
663                                 ;   the utility board
664       P:0001A5 P:0001A5 07F43F            MOVEP             #>0,X:PCRC              ; Software reset of ESSI0
                            000000
665       P:0001A7 P:0001A7 07F435            MOVEP             #$180809,X:CRA0         ; Divide 100 MHz by 20 to get 5.0 MHz
                            180809
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 13



666                                                                                     ; DC[4:0] = 0 for non-network operation
667                                                                                     ; WL0-WL2 = 3 for 24-bit data words
668                                                                                     ; SSC1 = 0 for SC1 not used
669       P:0001A9 P:0001A9 07F436            MOVEP             #$020020,X:CRB0         ; SCKD = 1 for internally generated clock
                            020020
670                                                                                     ; SCD2 = 0 so frame sync SC2 is an output
671                                                                                     ; SHFD = 0 for MSB shifted first
672                                                                                     ; FSL = 0, frame sync length not used
673                                                                                     ; CKP = 0 for rising clock edge transitions
674                                                                                     ; SYN = 0 for asynchronous
675                                                                                     ; TE0 = 1 to enable transmitter #0
676                                                                                     ; MOD = 0 for normal, non-networked mode
677                                                                                     ; TE0 = 0 to NOT enable transmitter #0 yet
678                                                                                     ; RE = 1 to enable receiver
679       P:0001AB P:0001AB 07F43F            MOVEP             #%111001,X:PCRC         ; Control Register (0 for GPIO, 1 for ESSI)
                            000039
680       P:0001AD P:0001AD 07F43E            MOVEP             #%000110,X:PRRC         ; Data Direction Register (0 for In, 1 for O
ut)
                            000006
681       P:0001AF P:0001AF 07F43D            MOVEP             #%000100,X:PDRC         ; Data Register - WR_ENA* = 1
                            000004
682    
683                                 ; Port C version = Analog boards
684                                 ;       MOVEP   #$000809,X:CRA0 ; Divide 100 MHz by 20 to get 5.0 MHz
685                                 ;       MOVEP   #$000030,X:CRB0 ; SCKD = 1 for internally generated clock
686                                 ;       MOVEP   #%100000,X:PCRC ; Control Register (0 for GPIO, 1 for ESSI)
687                                 ;       MOVEP   #%000100,X:PRRC ; Data Direction Register (0 for In, 1 for Out)
688                                 ;       MOVEP   #%000000,X:PDRC ; Data Register: 'not used' = 0 outputs
689    
690       P:0001B1 P:0001B1 07F43C            MOVEP             #0,X:TX00               ; Initialize the transmitter to zero
                            000000
691       P:0001B3 P:0001B3 000000            NOP
692       P:0001B4 P:0001B4 000000            NOP
693       P:0001B5 P:0001B5 013630            BSET    #TE,X:CRB0                        ; Enable the SSI transmitter
694    
695                                 ; Conversion from software bits to schematic labels for Port C
696                                 ;       PC0 = SC00 = UTL-T-SCK
697                                 ;       PC1 = SC01 = 2_XMT = SYNC on prototype
698                                 ;       PC2 = SC02 = WR_ENA*
699                                 ;       PC3 = SCK0 = TIM-U-SCK
700                                 ;       PC4 = SRD0 = UTL-T-STD
701                                 ;       PC5 = STD0 = TIM-U-STD
702    
703                                 ; Program the serial port ESSI1 = Port D for serial transmission to
704                                 ;   the analog boards and two parallel I/O input pins
705       P:0001B6 P:0001B6 07F42F            MOVEP             #>0,X:PCRD              ; Software reset of ESSI0
                            000000
706       P:0001B8 P:0001B8 07F425            MOVEP             #$000809,X:CRA1         ; Divide 100 MHz by 20 to get 5.0 MHz
                            000809
707                                                                                     ; DC[4:0] = 0
708                                                                                     ; WL[2:0] = ALC = 0 for 8-bit data words
709                                                                                     ; SSC1 = 0 for SC1 not used
710       P:0001BA P:0001BA 07F426            MOVEP             #$000030,X:CRB1         ; SCKD = 1 for internally generated clock
                            000030
711                                                                                     ; SCD2 = 1 so frame sync SC2 is an output
712                                                                                     ; SHFD = 0 for MSB shifted first
713                                                                                     ; CKP = 0 for rising clock edge transitions
714                                                                                     ; TE0 = 0 to NOT enable transmitter #0 yet
715                                                                                     ; MOD = 0 so its not networked mode
716       P:0001BC P:0001BC 07F42F            MOVEP             #%100000,X:PCRD         ; Control Register (0 for GPIO, 1 for ESSI)
                            000020
717                                                                                     ; PD3 = SCK1, PD5 = STD1 for ESSI
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 14



718       P:0001BE P:0001BE 07F42E            MOVEP             #%000100,X:PRRD         ; Data Direction Register (0 for In, 1 for O
ut)
                            000004
719       P:0001C0 P:0001C0 07F42D            MOVEP             #%000100,X:PDRD         ; Data Register: 'not used' = 0 outputs
                            000004
720       P:0001C2 P:0001C2 07F42C            MOVEP             #0,X:TX10               ; Initialize the transmitter to zero
                            000000
721       P:0001C4 P:0001C4 000000            NOP
722       P:0001C5 P:0001C5 000000            NOP
723       P:0001C6 P:0001C6 012630            BSET    #TE,X:CRB1                        ; Enable the SSI transmitter
724    
725                                 ; Conversion from software bits to schematic labels for Port D
726                                 ; PD0 = SC10 = 2_XMT_? input
727                                 ; PD1 = SC11 = SSFEF* input
728                                 ; PD2 = SC12 = PWR_EN
729                                 ; PD3 = SCK1 = TIM-A-SCK
730                                 ; PD4 = SRD1 = PWRRST
731                                 ; PD5 = STD1 = TIM-A-STD
732    
733                                 ; Program the SCI port to communicate with the utility board
734       P:0001C7 P:0001C7 07F41C            MOVEP             #$0B04,X:SCR            ; SCI programming: 11-bit asynchronous
                            000B04
735                                                                                     ;   protocol (1 start, 8 data, 1 even parity
,
736                                                                                     ;   1 stop); LSB before MSB; enable receiver
737                                                                                     ;   and its interrupts; transmitter interrup
ts
738                                                                                     ;   disabled.
739       P:0001C9 P:0001C9 07F41B            MOVEP             #$0003,X:SCCR           ; SCI clock: utility board data rate =
                            000003
740                                                                                     ;   (390,625 kbits/sec); internal clock.
741       P:0001CB P:0001CB 07F41F            MOVEP             #%011,X:PCRE            ; Port Control Register = RXD, TXD enabled
                            000003
742       P:0001CD P:0001CD 07F41E            MOVEP             #%000,X:PRRE            ; Port Direction Register (0 = Input)
                            000000
743    
744                                 ;       PE0 = RXD
745                                 ;       PE1 = TXD
746                                 ;       PE2 = SCLK
747    
748                                 ; Program one of the three timers as an exposure timer
749       P:0001CF P:0001CF 07F403            MOVEP             #$C34F,X:TPLR           ; Prescaler to generate millisecond timer,
                            00C34F
750                                                                                     ;  counting from the system clock / 2 = 50 M
Hz
751       P:0001D1 P:0001D1 07F40F            MOVEP             #$208200,X:TCSR0        ; Clear timer complete bit and enable presca
ler
                            208200
752       P:0001D3 P:0001D3 07F40E            MOVEP             #0,X:TLR0               ; Timer load register
                            000000
753    
754                                 ; Enable interrupts for the SCI port only
755       P:0001D5 P:0001D5 08F4BF            MOVEP             #$000000,X:IPRC         ; No interrupts allowed
                            000000
756       P:0001D7 P:0001D7 08F4BE            MOVEP             #>$80,X:IPRP            ; Enable SCI interrupt only, IPR = 1
                            000080
757       P:0001D9 P:0001D9 00FCB8            ANDI    #$FC,MR                           ; Unmask all interrupt levels
758    
759                                 ; Initialize the fiber optic serial receiver circuitry
760       P:0001DA P:0001DA 061480            DO      #20,L_FO_INIT
                            0001DF
761       P:0001DC P:0001DC 5FF000            MOVE                          Y:RDFO,B
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 15



                            FFFFF1
762       P:0001DE P:0001DE 0605A0            REP     #5
763       P:0001DF P:0001DF 000000            NOP
764                                 L_FO_INIT
765    
766                                 ; Pulse PRSFIFO* low to revive the CMDRST* instruction and reset the FIFO
767       P:0001E0 P:0001E0 44F400            MOVE              #1000000,X0             ; Delay by 10 milliseconds
                            0F4240
768       P:0001E2 P:0001E2 06C400            DO      X0,*+3
                            0001E4
769       P:0001E4 P:0001E4 000000            NOP
770       P:0001E5 P:0001E5 0A8908            BCLR    #8,X:HDR
771       P:0001E6 P:0001E6 0614A0            REP     #20
772       P:0001E7 P:0001E7 000000            NOP
773       P:0001E8 P:0001E8 0A8928            BSET    #8,X:HDR
774    
775                                 ; Reset the utility board
776       P:0001E9 P:0001E9 0A0F05            BCLR    #5,X:<LATCH
777       P:0001EA P:0001EA 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Clear reset utility board bit
                            00000F
778       P:0001EC P:0001EC 06C8A0            REP     #200                              ; Delay by RESET* low time
779       P:0001ED P:0001ED 000000            NOP
780       P:0001EE P:0001EE 0A0F25            BSET    #5,X:<LATCH
781       P:0001EF P:0001EF 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Clear reset utility board bit
                            00000F
782       P:0001F1 P:0001F1 56F400            MOVE              #200000,A               ; Delay 2 msec for utility boot
                            030D40
783       P:0001F3 P:0001F3 06CE00            DO      A,*+3
                            0001F5
784       P:0001F5 P:0001F5 000000            NOP
785    
786                                 ; Put all the analog switch inputs to low so they draw minimum current
787       P:0001F6 P:0001F6 012F23            BSET    #3,X:PCRD                         ; Turn the serial clock on
788       P:0001F7 P:0001F7 56F400            MOVE              #$0C3000,A              ; Value of integrate speed and gain switches
                            0C3000
789       P:0001F9 P:0001F9 20001B            CLR     B
790       P:0001FA P:0001FA 241000            MOVE              #$100000,X0             ; Increment over board numbers for DAC write
s
791       P:0001FB P:0001FB 45F400            MOVE              #$001000,X1             ; Increment over board numbers for WRSS writ
es
                            001000
792       P:0001FD P:0001FD 060F80            DO      #15,L_ANALOG                      ; Fifteen video processor boards maximum
                            000205
793       P:0001FF P:0001FF 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
794       P:000200 P:000200 200040            ADD     X0,A
795       P:000201 P:000201 5F7000            MOVE                          B,Y:WRSS    ; This is for the fast analog switches
                            FFFFF3
796       P:000203 P:000203 0620A3            REP     #800                              ; Delay for the serial data transmission
797       P:000204 P:000204 000000            NOP
798       P:000205 P:000205 200068            ADD     X1,B                              ; Increment the video and clock driver numbe
rs
799                                 L_ANALOG
800       P:000206 P:000206 0A0F00            BCLR    #CDAC,X:<LATCH                    ; Enable clearing of DACs
801       P:000207 P:000207 0A0F02            BCLR    #ENCK,X:<LATCH                    ; Disable clock and DAC output switches
802       P:000208 P:000208 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Execute these two operations
                            00000F
803       P:00020A P:00020A 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
804       P:00020B P:00020B 0C0220            JMP     <SKIP
805    
806                                 ; Transmit contents of accumulator A1 over the synchronous serial transmitter
807                                 XMIT_A_WORD
808       P:00020C P:00020C 547000            MOVE              A1,X:SV_A1
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 16



                            00000E
809       P:00020E P:00020E 01A786            JCLR    #TDE,X:SSISR1,*                   ; Start bit
                            00020E
810       P:000210 P:000210 07F42C            MOVEP             #$010000,X:TX10
                            010000
811       P:000212 P:000212 060380            DO      #3,L_XMIT
                            000218
812       P:000214 P:000214 01A786            JCLR    #TDE,X:SSISR1,*                   ; Three data bytes
                            000214
813       P:000216 P:000216 04CCCC            MOVEP             A1,X:TX10
814       P:000217 P:000217 0C1E90            LSL     #8,A
815       P:000218 P:000218 000000            NOP
816                                 L_XMIT
817       P:000219 P:000219 01A786            JCLR    #TDE,X:SSISR1,*                   ; Zeroes to bring transmitter low
                            000219
818       P:00021B P:00021B 07F42C            MOVEP             #0,X:TX10
                            000000
819       P:00021D P:00021D 54F000            MOVE              X:SV_A1,A1
                            00000E
820       P:00021F P:00021F 00000C            RTS
821    
822                                 SKIP
823    
824                                 ; Set up the circular SCI buffer, 32 words in size
825       P:000220 P:000220 64F400            MOVE              #SCI_TABLE,R4
                            000400
826       P:000222 P:000222 051FA4            MOVE              #31,M4
827       P:000223 P:000223 647000            MOVE              R4,X:(SCI_TABLE+33)
                            000421
828    
829                                           IF      @SCP("HOST","ROM")
837                                           ENDIF
838    
839       P:000225 P:000225 44F400            MOVE              #>$AC,X0
                            0000AC
840       P:000227 P:000227 440100            MOVE              X0,X:<FO_HDR
841    
842       P:000228 P:000228 0C0181            JMP     <STARTUP
843    
844                                 ;  ****************  X: Memory tables  ********************
845    
846                                 ; Define the address in P: space where the table of constants begins
847    
848                                  X_BOOT_START
849       000227                              EQU     @LCV(L)-2
850    
851                                           IF      @SCP("HOST","ROM")
853                                           ENDIF
854                                           IF      @SCP("HOST","HOST")
855       X:000000 X:000000                   ORG     X:0,X:0
856                                           ENDIF
857    
858                                 ; Special storage area - initialization constants and scratch space
859       X:000000 X:000000         STATUS    DC      $18000                            ; Controller status bits
860                                                                                     ; Correlated double sample (#15)
861                                                                                     ; Turn READ on and off (#16)
862    
863       000001                    FO_HDR    EQU     STATUS+1                          ; Fiber optic write bytes
864       000005                    HEADER    EQU     FO_HDR+4                          ; Command header
865       000006                    NWORDS    EQU     HEADER+1                          ; Number of words in the command
866       000007                    COM_BUF   EQU     NWORDS+1                          ; Command buffer
867       00000E                    SV_A1     EQU     COM_BUF+7                         ; Save accumulator A1
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 17



868    
869                                           IF      @SCP("HOST","ROM")
874                                           ENDIF
875    
876                                           IF      @SCP("HOST","HOST")
877       X:00000F X:00000F                   ORG     X:$F,X:$F
878                                           ENDIF
879    
880                                 ; Parameter table in P: space to be copied into X: space during
881                                 ;   initialization, and is copied from ROM by the DSP boot
882       X:00000F X:00000F         LATCH     DC      $7A                               ; Starting value in latch chip U25
883                                  EXPOSURE_TIME
884       X:000010 X:000010                   DC      0                                 ; Exposure time in milliseconds
885                                  ELAPSED_TIME
886       X:000011 X:000011                   DC      0                                 ; Time elapsed so far in the exposure
887       X:000012 X:000012         ONE       DC      1                                 ; One
888       X:000013 X:000013         TWO       DC      2                                 ; Two
889       X:000014 X:000014         THREE     DC      3                                 ; Three
890       X:000015 X:000015         SEVEN     DC      7                                 ; Seven
891       X:000016 X:000016         MASK1     DC      $FCFCF8                           ; Mask for checking header
892       X:000017 X:000017         MASK2     DC      $030300                           ; Mask for checking header
893       X:000018 X:000018         DONE      DC      'DON'                             ; Standard reply
894       X:000019 X:000019         SBRD      DC      $020000                           ; Source Identification number
895       X:00001A X:00001A         TIM_DRB   DC      $000200                           ; Destination = timing board number
896       X:00001B X:00001B         DMASK     DC      $00FF00                           ; Mask to get destination board number
897       X:00001C X:00001C         SMASK     DC      $FF0000                           ; Mask to get source board number
898       X:00001D X:00001D         ERR       DC      'ERR'                             ; An error occurred
899       X:00001E X:00001E         C100K     DC      100000                            ; Delay for WRROM = 1 millisec
900       X:00001F X:00001F         IDL_ADR   DC      TST_RCV                           ; Address of idling routine
901       X:000020 X:000020         EXP_ADR   DC      0                                 ; Jump to this address during exposures
902    
903                                 ; Places for saving register values
904       X:000021 X:000021         SAVE_SR   DC      0                                 ; Status Register
905       X:000022 X:000022         SAVE_X1   DC      0
906       X:000023 X:000023         SAVE_A1   DC      0
907       X:000024 X:000024         SAVE_R0   DC      0
908       X:000025 X:000025         RCV_ERR   DC      0
909       X:000026 X:000026         SCI_A1    DC      0                                 ; Contents of accumulator A1 in RCV ISR
910       X:000027 X:000027         SCI_R0    DC      SRXL
911    
912                                 ; Command table
913       000028                    COM_TBL_R EQU     @LCV(R)
914       X:000028 X:000028         COM_TBL   DC      'TDL',TDL                         ; Test Data Link
915       X:00002A X:00002A                   DC      'RDM',RDMEM                       ; Read from DSP or EEPROM memory
916       X:00002C X:00002C                   DC      'WRM',WRMEM                       ; Write to DSP memory
917       X:00002E X:00002E                   DC      'LDA',LDAPPL                      ; Load application from EEPROM to DSP
918       X:000030 X:000030                   DC      'STP',STOP_IDLE_CLOCKING
919       X:000032 X:000032                   DC      'DON',START                       ; Nothing special
920       X:000034 X:000034                   DC      'ERR',START                       ; Nothing special
921    
922                                  END_COMMAND_TABLE
923       000036                              EQU     @LCV(R)
924    
925                                 ; The table at SCI_TABLE is for words received from the utility board, written by
926                                 ;   the interrupt service routine SCI_RCV. Note that it is 32 words long,
927                                 ;   hard coded, and the 33rd location contains the pointer to words that have
928                                 ;   been processed by moving them from the SCI_TABLE to the COM_BUF.
929    
930                                           IF      @SCP("HOST","ROM")
932                                           ENDIF
933    
934       000036                    END_ADR   EQU     @LCV(L)                           ; End address of P: code written to ROM
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timboot.asm  Page 18



935    
936       P:000229 P:000229                   ORG     P:,P:
937    
938       100012                    CC        EQU     IRREV4+TIMREV5+CONT_RD
939    
940    
941                                 ; Put number of words of application in P: for loading application from EEPROM
942       P:000229 P:000229                   DC      TIMBOOT_X_MEMORY-@LCV(L)-1
943    
944                                 ;  Reset entire array and don't transmit any pixel data
945                                 RESET_ARRAY
946       P:00022A P:00022A 306000            MOVE              #<READ_ON,R0            ; Turn Read ON
947       P:00022B P:00022B 0D03E6            JSR     <CLOCK
948       P:00022C P:00022C 306600            MOVE              #<INIT_FRAME,R0
949       P:00022D P:00022D 0D03E6            JSR     <CLOCK
950    
951       P:00022E P:00022E 060081            DO      #256,END_FRAME
                            000242
952       P:000230 P:000230 306B00            MOVE              #<SHIFT_RESET_ODD_ROW,R0
953       P:000231 P:000231 0D03E6            JSR     <CLOCK
954       P:000232 P:000232 060081            DO      #256,L_ODD
                            000236
955       P:000234 P:000234 309000            MOVE              #<SHIFT_PIXELS,R0
956       P:000235 P:000235 0D03E6            JSR     <CLOCK
957       P:000236 P:000236 000000            NOP
958                                 L_ODD
959       P:000237 P:000237 307200            MOVE              #<SHIFT_RESET_EVEN_ROW,R0
960       P:000238 P:000238 0D03E6            JSR     <CLOCK
961       P:000239 P:000239 060081            DO      #256,L_EVEN
                            00023D
962       P:00023B P:00023B 309000            MOVE              #<SHIFT_PIXELS,R0
963       P:00023C P:00023C 0D03E6            JSR     <CLOCK
964       P:00023D P:00023D 000000            NOP
965                                 L_EVEN
966       P:00023E P:00023E 0BE580            JSR     (R5)                              ; Check for incoming command if in
967       P:00023F P:00023F 0E0242            JCC     <NOT_COMMAND                      ;  continuous reset mode
968       P:000240 P:000240 00008C            ENDDO                                     ; If there is an incoming command then
969       P:000241 P:000241 0C0247            JMP     <RST_END                          ;  exit continuous mode and return
970                                 NOT_COMMAND
971       P:000242 P:000242 000000            NOP
972       P:000243 P:000243 000000  END_FRAME NOP
973       P:000244 P:000244 306300            MOVE              #<READ_OFF,R0           ; Turn Read OFF
974       P:000245 P:000245 0D03E6            JSR     <CLOCK
975       P:000246 P:000246 00000C            RTS                                       ; Return from subroutine call
976    
977       P:000247 P:000247 306300  RST_END   MOVE              #<READ_OFF,R0           ; Turn Read OFF
978       P:000248 P:000248 0D03E6            JSR     <CLOCK
979       P:000249 P:000249 0AF960            BSET    #0,SR                             ; Set carry bit to indicate command was rece
ived
980       P:00024A P:00024A 000000            NOP
981       P:00024B P:00024B 00000C            RTS
982    
983                                 ; Dummy subroutine to not call receiver checking routine
984       P:00024C P:00024C 0AF940  NO_CHK    BCLR    #0,SR                             ; Clear status register clear bit
985       P:00024D P:00024D 000000            NOP
986       P:00024E P:00024E 00000C            RTS
987    
988                                 ; Continuously reset array, checking for host commands every line
989                                 CONT_RST
990       P:00024F P:00024F 330700            MOVE              #<COM_BUF,R3
991       P:000250 P:000250 35A500            MOVE              #<GET_RCV,R5
992       P:000251 P:000251 0D022A            JSR     <RESET_ARRAY
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 19



993       P:000252 P:000252 0E805D            JCS     <PRC_RCV                          ; Process the command if its there
994       P:000253 P:000253 0C024F            JMP     <CONT_RST
995    
996                                 ;  ***********************   ARRAY READOUT   ********************
997                                 RD_ARRAY
998       P:000254 P:000254 0D03D5            JSR     <PCI_READ_IMAGE                   ; Wake up the PCI interface board
999       P:000255 P:000255 0A00AA            JSET    #TST_IMG,X:STATUS,SYNTHETIC_IMAGE
                            0003BD
1000   
1001      P:000257 P:000257 0A0090            JCLR    #ST_RD,X:<STATUS,C_RD
                            00025F
1002      P:000259 P:000259 306000            MOVE              #<READ_ON,R0            ; Turn the PICNIC 'READ' line ON
1003      P:00025A P:00025A 0D03E6            JSR     <CLOCK
1004      P:00025B P:00025B 065882            DO      #600,DLY_ON                       ; Wait 5 msec for the signal to settle
                            00025E
1005      P:00025D P:00025D 0D03F1            JSR     <PAL_DLY
1006      P:00025E P:00025E 000000            NOP
1007                                DLY_ON
1008   
1009                                ; Compute NXLOOP and NYLOOP including the number of readout channels
1010      P:00025F P:00025F 5E8F00  C_RD      MOVE                          Y:<OS,A
1011      P:000260 P:000260 0140C5            CMP     #'ALL',A
                            414C4C
1012      P:000262 P:000262 0E226F            JNE     <ONE_RD
1013      P:000263 P:000263 5E8200            MOVE                          Y:<NROWS,A  ; Read from all four corners
1014      P:000264 P:000264 200023            LSR     A
1015      P:000265 P:000265 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS1
                            000269
1016      P:000267 P:000267 200023            LSR     A                                 ; If CDS read only half of NROWS at a time
1017      P:000268 P:000268 000000            NOP
1018      P:000269 P:000269 5C1100  NO_CDS1   MOVE                          A1,Y:<NYLOOP
1019      P:00026A P:00026A 5E8100            MOVE                          Y:<NCOLS,A
1020      P:00026B P:00026B 200023            LSR     A
1021      P:00026C P:00026C 000000            NOP
1022      P:00026D P:00026D 5C1000            MOVE                          A1,Y:<NXLOOP
1023      P:00026E P:00026E 0C0277            JMP     <RDFRAME
1024   
1025                                ; Dimensions for reading from just one quadrant
1026      P:00026F P:00026F 5E8200  ONE_RD    MOVE                          Y:<NROWS,A
1027      P:000270 P:000270 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS2
                            000274
1028      P:000272 P:000272 200023            LSR     A                                 ; If CDS read only half of NROWS at a time
1029      P:000273 P:000273 000000            NOP
1030      P:000274 P:000274 5C1100  NO_CDS2   MOVE                          A1,Y:<NYLOOP
1031      P:000275 P:000275 4C8100            MOVE                          Y:<NCOLS,X0
1032      P:000276 P:000276 4C1000            MOVE                          X0,Y:<NXLOOP
1033   
1034                                ; Initialize the reading of the frame
1035      P:000277 P:000277 306600  RDFRAME   MOVE              #<INIT_FRAME,R0
1036      P:000278 P:000278 0D03E6            JSR     <CLOCK
1037   
1038                                ; Skip over Y:ROW_OFFSET rows, keeping track of even/odd effects
1039      P:000279 P:000279 0A0D60            BSET    #0,Y:<ODD_ROW
1040      P:00027A P:00027A 5E8400            MOVE                          Y:<ROW_OFFSET,A
1041      P:00027B P:00027B 200003            TST     A
1042      P:00027C P:00027C 0EF28A            JLE     <WHOLE_FRAME
1043      P:00027D P:00027D 307F00  ROWSKIP   MOVE              #<SHIFT_ODD_ROW,R0
1044      P:00027E P:00027E 0D03E6            JSR     <CLOCK
1045      P:00027F P:00027F 0B0D40            BCHG    #0,Y:<ODD_ROW
1046      P:000280 P:000280 014184            SUB     #1,A
1047      P:000281 P:000281 200003            TST     A
1048      P:000282 P:000282 0EA28C            JEQ     <READOUT
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 20



1049      P:000283 P:000283 307900            MOVE              #<SHIFT_EVEN_ROW,R0
1050      P:000284 P:000284 0D03E6            JSR     <CLOCK
1051      P:000285 P:000285 0B0D40            BCHG    #0,Y:<ODD_ROW
1052      P:000286 P:000286 014184            SUB     #1,A
1053      P:000287 P:000287 200003            TST     A
1054      P:000288 P:000288 0EA28C            JEQ     <READOUT
1055      P:000289 P:000289 0C027D            JMP     <ROWSKIP
1056   
1057                                WHOLE_FRAME
1058      P:00028A P:00028A 307F00            MOVE              #<SHIFT_ODD_ROW,R0
1059      P:00028B P:00028B 0D03E6            JSR     <CLOCK
1060   
1061      P:00028C P:00028C 5E9100  READOUT   MOVE                          Y:<NYLOOP,A
1062      P:00028D P:00028D 0B0D40  NXT_ROW   BCHG    #0,Y:<ODD_ROW
1063   
1064      P:00028E P:00028E 0A0E40            BCLR    #0,Y:<ODD_COL
1065      P:00028F P:00028F 5F8300            MOVE                          Y:<COL_OFFSET,B
1066      P:000290 P:000290 20000B            TST     B
1067      P:000291 P:000291 0EF2B5            JLE     <WHOLE_ROW
1068      P:000292 P:000292 0A898E  COLSKIP   JCLR    #SSFHF,X:HDR,*                    ; Only write to FIFO if < half full
                            000292
1069      P:000294 P:000294 09F4B3            MOVEP             #(CLK3+DELAY+H_PIXEL),Y:WRSS
                            053001
1070      P:000296 P:000296 0B0E40            BCHG    #0,Y:<ODD_COL
1071      P:000297 P:000297 01418C            SUB     #1,B
1072      P:000298 P:000298 20000B            TST     B
1073      P:000299 P:000299 0EF2A1            JLE     <RD_PXLS
1074      P:00029A P:00029A 09F4B3            MOVEP             #(CLK3+DELAY+L_PIXEL),Y:WRSS
                            053000
1075      P:00029C P:00029C 0B0E40            BCHG    #0,Y:<ODD_COL
1076      P:00029D P:00029D 01418C            SUB     #1,B
1077      P:00029E P:00029E 20000B            TST     B
1078      P:00029F P:00029F 0EF2A1            JLE     <RD_PXLS
1079      P:0002A0 P:0002A0 0C0292            JMP     <COLSKIP
1080   
1081      P:0002A1 P:0002A1 5F9000  RD_PXLS   MOVE                          Y:<NXLOOP,B
1082      P:0002A2 P:0002A2 0A0EE0  RD_LINE   JSET    #0,Y:<ODD_COL,O_COL
                            0002A9
1083      P:0002A4 P:0002A4 0A898E            JCLR    #SSFHF,X:HDR,*
                            0002A4
1084      P:0002A6 P:0002A6 09F4B3            MOVEP             #(CLK3+DELAY+H_PIXEL),Y:WRSS
                            053001
1085      P:0002A8 P:0002A8 0C02AB            JMP     <RD_PXL
1086      P:0002A9 P:0002A9 09F4B3  O_COL     MOVEP             #(CLK3+DELAY+L_PIXEL),Y:WRSS
                            053000
1087   
1088      P:0002AB P:0002AB 0B0E40  RD_PXL    BCHG    #0,Y:<ODD_COL
1089      P:0002AC P:0002AC 060540            DO      Y:<NUM_RDS,RD_PXL0
                            0002B0
1090      P:0002AE P:0002AE 309300            MOVE              #<READ_PIXEL,R0
1091      P:0002AF P:0002AF 0D03E6            JSR     <CLOCK
1092      P:0002B0 P:0002B0 01418C            SUB     #1,B
1093      P:0002B1 P:0002B1 000000  RD_PXL0   NOP
1094      P:0002B2 P:0002B2 20000B            TST     B
1095      P:0002B3 P:0002B3 0E72A2            JGT     <RD_LINE
1096      P:0002B4 P:0002B4 0C02BD            JMP     <END_LINE
1097   
1098                                ; Read out the entire row
1099                                WHOLE_ROW
1100      P:0002B5 P:0002B5 5F9000            MOVE                          Y:<NXLOOP,B
1101      P:0002B6 P:0002B6 20002B            LSR     B
1102      P:0002B7 P:0002B7 000000            NOP                                       ; SHIFT_READ_PIXELS processes two pixels
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 21



1103      P:0002B8 P:0002B8 06CD00            DO      B1,RD_PIX0                        ;   each time it is called
                            0002BC
1104      P:0002BA P:0002BA 308500            MOVE              #<SHIFT_READ_PIXELS,R0
1105      P:0002BB P:0002BB 0D03E6            JSR     <CLOCK
1106      P:0002BC P:0002BC 000000            NOP
1107                                RD_PIX0
1108   
1109                                END_LINE
1110      P:0002BD P:0002BD 014184            SUB     #1,A                              ; A = ROW number down counter
1111      P:0002BE P:0002BE 200003            TST     A
1112      P:0002BF P:0002BF 0EA2C8            JEQ     <READ_END
1113      P:0002C0 P:0002C0 0A0DE0            JSET    #0,Y:<ODD_ROW,ODD
                            0002C5
1114   
1115                                ; Shift either and odd or an even row number depending on where we are
1116      P:0002C2 P:0002C2 307900  EVEN      MOVE              #<SHIFT_EVEN_ROW,R0
1117      P:0002C3 P:0002C3 0D03E6            JSR     <CLOCK
1118      P:0002C4 P:0002C4 0C028D            JMP     <NXT_ROW
1119      P:0002C5 P:0002C5 307F00  ODD       MOVE              #<SHIFT_ODD_ROW,R0
1120      P:0002C6 P:0002C6 0D03E6            JSR     <CLOCK
1121      P:0002C7 P:0002C7 0C028D            JMP     <NXT_ROW
1122   
1123                                READ_END
1124      P:0002C8 P:0002C8 309800            MOVE              #<SXMIT_EIGHT_PIXELS,R0
1125      P:0002C9 P:0002C9 0D03E6            JSR     <CLOCK
1126      P:0002CA P:0002CA 000000            NOP
1127   
1128      P:0002CB P:0002CB 0A0090            JCLR    #ST_RD,X:<STATUS,NO_RD
                            0002CF
1129      P:0002CD P:0002CD 306300            MOVE              #<READ_OFF,R0           ; Turn the PICNIC Read line OFF
1130      P:0002CE P:0002CE 0D03E6            JSR     <CLOCK
1131                                NO_RD
1132   
1133                                ; We're all done with the readout, so return
1134      P:0002CF P:0002CF 00000C            RTS
1135   
1136                                ; ******  Minclude many routines not directly needed for readout  *******
1137                                          INCLUDE "timIRmisc.asm"
1138                                ; Miscellaneous IR array control routines, customized for John Monnier
1139   
1140                                POWER_OFF
1141      P:0002D0 P:0002D0 0D0302            JSR     <CLEAR_SWITCHES                   ; Clear switches and DACs
1142      P:0002D1 P:0002D1 0A8922            BSET    #LVEN,X:HDR
1143      P:0002D2 P:0002D2 0A8923            BSET    #HVEN,X:HDR
1144      P:0002D3 P:0002D3 0C008F            JMP     <FINISH
1145   
1146                                ; Start power-on cycle
1147                                POWER_ON
1148      P:0002D4 P:0002D4 0D0302            JSR     <CLEAR_SWITCHES                   ; Clear all analog switches
1149      P:0002D5 P:0002D5 0D02E1            JSR     <PON                              ; Turn on the power control board
1150      P:0002D6 P:0002D6 0A8980            JCLR    #PWROK,X:HDR,PWR_ERR              ; Test if the power turned on properly
                            0002DE
1151      P:0002D8 P:0002D8 305A00            MOVE              #TST_RCV,R0             ; For testing only, don't reset array
1152      P:0002D9 P:0002D9 601F00            MOVE              R0,X:<IDL_ADR
1153      P:0002DA P:0002DA 60F400            MOVE              #CONT_RST,R0            ; Put controller in continuous readout
                            00024F
1154      P:0002DC P:0002DC 601F00            MOVE              R0,X:<IDL_ADR           ;   state
1155      P:0002DD P:0002DD 0C008F            JMP     <FINISH
1156   
1157                                ; The power failed to turn on because of an error on the power control board
1158      P:0002DE P:0002DE 0A8922  PWR_ERR   BSET    #LVEN,X:HDR                       ; Turn off the low voltage emable line
1159      P:0002DF P:0002DF 0A8923            BSET    #HVEN,X:HDR                       ; Turn off the high voltage emable line
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 22



1160      P:0002E0 P:0002E0 0C008D            JMP     <ERROR
1161   
1162                                ; Now ramp up the low voltages (+/- 6.5V, 16.5V) and delay them to turn on
1163      P:0002E1 P:0002E1 0A0F20  PON       BSET    #CDAC,X:<LATCH                    ; Disable clearing of DACs
1164      P:0002E2 P:0002E2 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Write it to the hardware
                            00000F
1165      P:0002E4 P:0002E4 0A8902            BCLR    #LVEN,X:HDR                       ; LVEN = Low => Turn on +/- 6.5V,
1166      P:0002E5 P:0002E5 5E8900            MOVE                          Y:<PWR_DLY,A ;   +/- 16.5V
1167      P:0002E6 P:0002E6 0D047A            JSR     <MILLISEC_DELAY
1168   
1169                                ; Write all the bias voltages to the DACs
1170                                SET_BIASES
1171      P:0002E7 P:0002E7 012F23            BSET    #3,X:PCRD                         ; Turn on the serial clock
1172      P:0002E8 P:0002E8 0A0F01            BCLR    #1,X:<LATCH                       ; Separate updates of clock driver
1173      P:0002E9 P:0002E9 302100            MOVE              #<ZERO_BIASES,R0        ; Get starting address of DAC values
1174      P:0002EA P:0002EA 0D0474            JSR     <SET_DAC                          ; Write it to the hardware
1175      P:0002EB P:0002EB 569400            MOVE              X:<THREE,A
1176      P:0002EC P:0002EC 0D047A            JSR     <MILLISEC_DELAY
1177      P:0002ED P:0002ED 0A0F22            BSET    #ENCK,X:<LATCH                    ; Enable clock and DAC output switches
1178      P:0002EE P:0002EE 09F0B5            MOVEP             X:LATCH,Y:WRLATCH
                            00000F
1179   
1180                                ; Turn on Vdd = digital power unit cell to the IR array
1181      P:0002F0 P:0002F0 5EF000            MOVE                          Y:VDD,A     ; pin #5 = Vdd = array digital power
                            00001F
1182      P:0002F2 P:0002F2 0D020C            JSR     XMIT_A_WORD
1183      P:0002F3 P:0002F3 5E8A00            MOVE                          Y:<VDD_DLY,A ; Delay for the IR array to settle
1184      P:0002F4 P:0002F4 0D047A            JSR     <MILLISEC_DELAY
1185   
1186      P:0002F5 P:0002F5 301600            MOVE              #<DC_BIASES,R0          ; Get starting address of DAC values
1187      P:0002F6 P:0002F6 0D0474            JSR     <SET_DAC
1188      P:0002F7 P:0002F7 569400            MOVE              X:<THREE,A              ; Delay three millisec to settle
1189      P:0002F8 P:0002F8 0D047A            JSR     <MILLISEC_DELAY
1190   
1191                                ; Set clock driver DACs
1192      P:0002F9 P:0002F9 302E00            MOVE              #<DACS,R0               ; Get starting address of DAC values
1193      P:0002FA P:0002FA 0D0474            JSR     <SET_DAC
1194      P:0002FB P:0002FB 0D03F1            JSR     <PAL_DLY
1195   
1196                                ; Turn continuous reset mode on, disable the SSI, and return
1197      P:0002FC P:0002FC 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1198      P:0002FD P:0002FD 00000C            RTS
1199   
1200                                SET_BIAS_VOLTAGES
1201      P:0002FE P:0002FE 0D02E7            JSR     <SET_BIASES
1202      P:0002FF P:0002FF 0C008F            JMP     <FINISH
1203   
1204      P:000300 P:000300 0D0302  CLR_SWS   JSR     <CLEAR_SWITCHES
1205      P:000301 P:000301 0C008F            JMP     <FINISH
1206   
1207                                CLEAR_SWITCHES
1208      P:000302 P:000302 012F23            BSET    #3,X:PCRD                         ; Turn the serial clock on
1209      P:000303 P:000303 56F400            MOVE              #$0C3000,A              ; Value of integrate speed and gain switches
                            0C3000
1210      P:000305 P:000305 20001B            CLR     B
1211      P:000306 P:000306 241000            MOVE              #$100000,X0             ; Increment over board numbers for DAC write
s
1212      P:000307 P:000307 45F400            MOVE              #$001000,X1             ; Increment over board numbers for WRSS writ
es
                            001000
1213      P:000309 P:000309 060F80            DO      #15,L_VIDEO                       ; Fifteen video processor boards maximum
                            000310
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 23



1214      P:00030B P:00030B 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1215      P:00030C P:00030C 200040            ADD     X0,A
1216      P:00030D P:00030D 5F7000            MOVE                          B,Y:WRSS
                            FFFFF3
1217      P:00030F P:00030F 0D03F1            JSR     <PAL_DLY                          ; Delay for the serial data transmission
1218      P:000310 P:000310 200068            ADD     X1,B
1219                                L_VIDEO
1220      P:000311 P:000311 0A0F00            BCLR    #CDAC,X:<LATCH                    ; Clear the DACs
1221      P:000312 P:000312 0A0F02            BCLR    #ENCK,X:<LATCH                    ; Disable clock and DAC output switches
1222      P:000313 P:000313 09F0B5            MOVEP             X:LATCH,Y:WRLATCH       ; Execute these two operations
                            00000F
1223      P:000315 P:000315 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1224      P:000316 P:000316 00000C            RTS
1225   
1226                                ; Start the exposure timer and monitor its progress
1227      P:000317 P:000317 579000  EXPOSE    MOVE              X:<EXPOSURE_TIME,B
1228      P:000318 P:000318 20000B            TST     B                                 ; Special test for zero exposure time
1229      P:000319 P:000319 0EA325            JEQ     <END_EXP                          ; Don't even start an exposure
1230      P:00031A P:00031A 01418C            SUB     #1,B                              ; Timer counts from X:TCPR0+1 to zero
1231      P:00031B P:00031B 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Enable the timer #0
1232      P:00031C P:00031C 577000            MOVE              B,X:TCPR0
                            FFFF8D
1233      P:00031E P:00031E 330700  CHK_RCV   MOVE              #COM_BUF,R3             ; The beginning of the command buffer
1234      P:00031F P:00031F 0A8989            JCLR    #EF,X:HDR,CHK_TIM                 ; Simple test for fast execution
                            000323
1235      P:000321 P:000321 0D00A5            JSR     <GET_RCV                          ; Check for an incoming command
1236      P:000322 P:000322 0E805D            JCS     <PRC_RCV                          ; If command is received, go check it
1237      P:000323 P:000323 018F95  CHK_TIM   JCLR    #TCF,X:TCSR0,CHK_RCV              ; Wait for timer to equal compare value
                            00031E
1238      P:000325 P:000325 010F00  END_EXP   BCLR    #TIM_BIT,X:TCSR0                  ; Disable the timer
1239      P:000326 P:000326 0AE780            JMP     (R7)                              ; This contains the return address
1240   
1241                                ; Start the exposure, expose, and initiate the IR array readout
1242                                START_EXPOSURE                                      ; Test for continuous readout
1243      P:000327 P:000327 5E9200            MOVE                          Y:<NCOADDS,A
1244      P:000328 P:000328 014185            CMP     #1,A
1245      P:000329 P:000329 0E732E            JGT     <SETUP_CONT_RD
1246      P:00032A P:00032A 0A008E            JCLR    #ST_CNRD,X:STATUS,INIT_PCI_BOARD  ; We are in single mode
                            000348
1247      P:00032C P:00032C 0A000E            BCLR    #ST_CNRD,X:<STATUS
1248      P:00032D P:00032D 0C0331            JMP     <INIT_FRAME_COUNT                 ; Must send IFC if exiting cont. mode
1249   
1250                                ; Initialize the coaddition sequence
1251                                SETUP_CONT_RD
1252      P:00032E P:00032E 0A002E            BSET    #ST_CNRD,X:<STATUS                ; We are in continous readout mode
1253      P:00032F P:00032F 306000            MOVE              #<READ_ON,R0            ; Turn PICNIC Read line ON
1254      P:000330 P:000330 0D03E6            JSR     <CLOCK
1255   
1256                                INIT_FRAME_COUNT
1257      P:000331 P:000331 0D03E3            JSR     <WAIT_TO_FINISH_CLOCKING
1258      P:000332 P:000332 57F400            MOVE              #$020102,B              ; Initialize the PCI frame counter
                            020102
1259      P:000334 P:000334 0D00EB            JSR     <XMT_WRD
1260      P:000335 P:000335 57F400            MOVE              #'IFC',B
                            494643
1261      P:000337 P:000337 0D00EB            JSR     <XMT_WRD
1262      P:000338 P:000338 240000            MOVE              #0,X0
1263      P:000339 P:000339 4C1300            MOVE                          X0,Y:<ICOADD ; Initialize the coaddition counter
1264      P:00033A P:00033A 4C0700            MOVE                          X0,Y:<I_FPR ; Initialize the reads per reset counter
1265      P:00033B P:00033B 0C0348            JMP     <INIT_PCI_BOARD
1266   
1267                                ; Start up the next frame of the coaddition series
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 24



1268                                NEXT_COADD
1269      P:00033C P:00033C 5E9300            MOVE                          Y:<ICOADD,A ; Get the # of frames coadded so far
1270      P:00033D P:00033D 014180            ADD     #1,A
1271      P:00033E P:00033E 4C9200            MOVE                          Y:<NCOADDS,X0 ; See if we've coadded enough frames
1272      P:00033F P:00033F 5C1300            MOVE                          A1,Y:<ICOADD ; Increment the coaddition frame counter
1273      P:000340 P:000340 200045            CMP     X0,A
1274      P:000341 P:000341 0E1380            JGE     <CONTINUE_READ                    ; End of coaddition sequence
1275   
1276      P:000342 P:000342 5E9400            MOVE                          Y:<IBUFFER,A ; Get the position in the buffer
1277      P:000343 P:000343 014180            ADD     #1,A
1278      P:000344 P:000344 4C9500            MOVE                          Y:<N_FPB,X0
1279      P:000345 P:000345 5C1400            MOVE                          A1,Y:<IBUFFER
1280      P:000346 P:000346 200045            CMP     X0,A
1281      P:000347 P:000347 0E9350            JLT     <TST_RST                          ; Test if the frame buffer is full
1282   
1283                                INIT_PCI_BOARD                                      ; Initialize PCI pointer if full
1284      P:000348 P:000348 240000            MOVE              #0,X0
1285      P:000349 P:000349 4C1400            MOVE                          X0,Y:<IBUFFER ; IBUFFER counts from 0 to N_FPB
1286      P:00034A P:00034A 57F400            MOVE              #$020102,B
                            020102
1287      P:00034C P:00034C 0D00EB            JSR     <XMT_WRD
1288      P:00034D P:00034D 57F400            MOVE              #'IIA',B
                            494941
1289      P:00034F P:00034F 0D00EB            JSR     <XMT_WRD
1290   
1291                                ; Test if a reset of the IR array is needed
1292      P:000350 P:000350 5E8700  TST_RST   MOVE                          Y:<I_FPR,A  ; Get the "frames per reset" counter
1293      P:000351 P:000351 014180            ADD     #1,A
1294      P:000352 P:000352 4C8600            MOVE                          Y:<N_FPR,X0
1295      P:000353 P:000353 5C0700            MOVE                          A1,Y:<I_FPR
1296      P:000354 P:000354 200045            CMP     X0,A
1297      P:000355 P:000355 0E9359            JLT     <TRIGGER                          ; Test if need to reset the array
1298      P:000356 P:000356 240000            MOVE              #0,X0
1299      P:000357 P:000357 4C0700            MOVE                          X0,Y:<I_FPR ; Initialize the reads per reset counter
1300      P:000358 P:000358 0D0381            JSR     <RST_FPA                          ; Reset the array
1301   
1302                                ; Sample the EXT_IN0 bit, waiting for a trigger, which is high true.
1303      P:000359 P:000359 0A008D  TRIGGER   JCLR    #ST_SYNC,X:<STATUS,AGAIN
                            000361
1304      P:00035B P:00035B 0A898A  WAIT_RD   JCLR    #EXT_IN0,X:HDR,WAIT_RD            ; Wait for the trigger to go high
                            00035B
1305      P:00035D P:00035D 0606A0            REP     #6                                ; Wait 150 nsec, as a noise filter
1306      P:00035E P:00035E 000000            NOP
1307      P:00035F P:00035F 0A898A            JCLR    #EXT_IN0,X:HDR,WAIT_RD            ; If trigger is low start over
                            00035B
1308   
1309                                ; Begin the exposure and one or two readouts depending on the CDS setting
1310      P:000361 P:000361 0A008F  AGAIN     JCLR    #ST_CDS,X:<STATUS,EX_STRT
                            000369
1311      P:000363 P:000363 0D0254            JSR     <RD_ARRAY                         ; Read before expose
1312      P:000364 P:000364 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1313      P:000365 P:000365 0A0090            JCLR    #ST_RD,X:<STATUS,EX_STRT
                            000369
1314      P:000367 P:000367 306300            MOVE              #<READ_OFF,R0           ; Turn PICNIC Read line OFF
1315      P:000368 P:000368 0D03E6            JSR     <CLOCK
1316      P:000369 P:000369 67F400  EX_STRT   MOVE              #EXP_END,R7
                            00036C
1317      P:00036B P:00036B 0C0317            JMP     <EXPOSE
1318      P:00036C P:00036C 0D0254  EXP_END   JSR     <RD_ARRAY                         ; Read after expose
1319      P:00036D P:00036D 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1320      P:00036E P:00036E 0A0090            JCLR    #ST_RD,X:<STATUS,RDA_END
                            000372
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 25



1321      P:000370 P:000370 306300            MOVE              #<READ_OFF,R0           ; Turn PICNIC Read line OFF
1322      P:000371 P:000371 0D03E6            JSR     <CLOCK
1323   
1324                                ; Check for a command at the end of readout. Only ABORT should be issued.
1325      P:000372 P:000372 330700  RDA_END   MOVE              #<COM_BUF,R3
1326      P:000373 P:000373 0D00A5            JSR     <GET_RCV                          ; Was a command received?
1327      P:000374 P:000374 0E8398            JCS     <CHK_ABORT_COMMAND                ; If yes, see if its an abort command
1328   
1329                                ; Check for coaddition mode
1330      P:000375 P:000375 5E9200  CHK_ADD   MOVE                          Y:<NCOADDS,A
1331      P:000376 P:000376 014185            CMP     #1,A
1332      P:000377 P:000377 0EF380            JLE     <CONTINUE_READ
1333      P:000378 P:000378 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1334      P:000379 P:000379 0D03E3            JSR     <WAIT_TO_FINISH_CLOCKING
1335   
1336                                ; Delay a minimum of 70 microsec for the pixel data to be written to the PCI bus
1337      P:00037A P:00037A 44F400            MOVE              #1000000,X0             ; = 100 microsec, #100 per microsec
                            0F4240
1338      P:00037C P:00037C 06C400            DO      X0,L_RDDLY
                            00037E
1339      P:00037E P:00037E 000000            NOP
1340                                L_RDDLY
1341      P:00037F P:00037F 0C033C            JMP     <NEXT_COADD
1342   
1343                                CONTINUE_READ
1344      P:000380 P:000380 0C0054            JMP     <START
1345   
1346                                ; Reset array, as a subroutine
1347      P:000381 P:000381 65F400  RST_FPA   MOVE              #NO_CHK,R5              ; Don't check for incoming commands
                            00024C
1348      P:000383 P:000383 0D022A            JSR     <RESET_ARRAY                      ; Reset the array
1349      P:000384 P:000384 5E8800            MOVE                          Y:<RST_DLY,A ; Enter reset delay into timer
1350      P:000385 P:000385 0D047A            JSR     <MILLISEC_DELAY                   ; Let the reset signal settle down
1351      P:000386 P:000386 00000C            RTS
1352   
1353                                ; ****************  End of START_EXPOSURE routine  **********************
1354   
1355                                ; Set the desired exposure time
1356                                SET_EXPOSURE_TIME
1357      P:000387 P:000387 46DB00            MOVE              X:(R3)+,Y0
1358      P:000388 P:000388 461000            MOVE              Y0,X:EXPOSURE_TIME
1359      P:000389 P:000389 07F00D            MOVEP             X:EXPOSURE_TIME,X:TCPR0
                            000010
1360      P:00038B P:00038B 0C008F            JMP     <FINISH
1361   
1362                                ; Read the time remaining until the exposure ends
1363                                READ_EXPOSURE_TIME
1364      P:00038C P:00038C 47F000            MOVE              X:TCR0,Y1               ; Read elapsed exposure time
                            FFFF8C
1365      P:00038E P:00038E 0C0090            JMP     <FINISH1
1366   
1367                                ; Pause the exposure - close the shutter, and stop the timer
1368                                PAUSE_EXPOSURE
1369      P:00038F P:00038F 07700C            MOVEP             X:TCR0,X:ELAPSED_TIME   ; Save the elapsed exposure time
                            000011
1370      P:000391 P:000391 010F00            BCLR    #TIM_BIT,X:TCSR0                  ; Disable the DSP exposure timer
1371      P:000392 P:000392 0C008F            JMP     <FINISH
1372   
1373                                ; Resume the exposure - open the shutter if needed and restart the timer
1374                                RESUME_EXPOSURE
1375      P:000393 P:000393 010F29            BSET    #TRM,X:TCSR0                      ; To be sure it will load TLR0
1376      P:000394 P:000394 07700C            MOVEP             X:TCR0,X:TLR0           ; Restore elapsed exposure time
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 26



                            FFFF8E
1377      P:000396 P:000396 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Re-enable the DSP exposure timer
1378      P:000397 P:000397 0C008F            JMP     <FINISH
1379   
1380                                ; See if the command issued during readout is a 'ABR'. If not continue readout
1381                                CHK_ABORT_COMMAND
1382      P:000398 P:000398 44DB00            MOVE              X:(R3)+,X0              ; Get candidate header
1383      P:000399 P:000399 56F400            MOVE              #$000202,A
                            000202
1384      P:00039B P:00039B 200045            CMP     X0,A
1385      P:00039C P:00039C 0E23A4            JNE     <RD_CONT
1386      P:00039D P:00039D 0D00A5  WT_COM    JSR     <GET_RCV                          ; Get the command
1387      P:00039E P:00039E 0E039D            JCC     <WT_COM
1388      P:00039F P:00039F 44DB00            MOVE              X:(R3)+,X0              ; Get candidate header
1389      P:0003A0 P:0003A0 56F400            MOVE              #'ABR',A
                            414252
1390      P:0003A2 P:0003A2 200045            CMP     X0,A
1391      P:0003A3 P:0003A3 0EA3A7            JEQ     <RDCCD_END_ABORT
1392      P:0003A4 P:0003A4 330700  RD_CONT   MOVE              #<COM_BUF,R3            ; Continue reading out the CCD
1393      P:0003A5 P:0003A5 227400            MOVE              R3,R4
1394      P:0003A6 P:0003A6 0C0375            JMP     <CHK_ADD
1395   
1396                                ; Special ending after abort command to send a 'DON' to the host computer
1397                                RDCCD_END_ABORT
1398      P:0003A7 P:0003A7 0A0084            JCLR    #ST_RDC,X:<STATUS,ABORT_EXPOSURE
                            0003BB
1399      P:0003A9 P:0003A9 569200            MOVE              X:<ONE,A
1400      P:0003AA P:0003AA 0D047A            JSR     <MILLISEC_DELAY                   ; Wait one millisec
1401      P:0003AB P:0003AB 0A0082            JCLR    #IDLMODE,X:<STATUS,NO_IDL2        ; Don't idle after readout
                            0003B1
1402      P:0003AD P:0003AD 60F400            MOVE              #CONT_RST,R0
                            00024F
1403      P:0003AF P:0003AF 601F00            MOVE              R0,X:<IDL_ADR
1404      P:0003B0 P:0003B0 0C03B3            JMP     <RDC_E2
1405      P:0003B1 P:0003B1 305A00  NO_IDL2   MOVE              #TST_RCV,R0
1406      P:0003B2 P:0003B2 601F00            MOVE              R0,X:<IDL_ADR
1407      P:0003B3 P:0003B3 0D03E3  RDC_E2    JSR     <WAIT_TO_FINISH_CLOCKING
1408      P:0003B4 P:0003B4 0A0004            BCLR    #ST_RDC,X:<STATUS                 ; Set status to not reading out
1409      P:0003B5 P:0003B5 240000            MOVE              #0,X0
1410      P:0003B6 P:0003B6 4C1200            MOVE                          X0,Y:<NCOADDS ; Terminate coaddition
1411      P:0003B7 P:0003B7 44F400            MOVE              #$000202,X0             ; Send 'DON' to the host computer
                            000202
1412      P:0003B9 P:0003B9 440500            MOVE              X0,X:<HEADER
1413      P:0003BA P:0003BA 0C008F            JMP     <FINISH
1414   
1415                                ; Abort exposure - close the shutter, stop the timer and resume idle mode
1416                                ABORT_EXPOSURE
1417      P:0003BB P:0003BB 010F00            BCLR    #TIM_BIT,X:TCSR0                  ; Disable the DSP exposure timer
1418      P:0003BC P:0003BC 0C0372            JMP     <RDA_END
1419   
1420                                ; Generate a synthetic image by simply incrementing the pixel counts
1421                                SYNTHETIC_IMAGE
1422      P:0003BD P:0003BD 200013            CLR     A
1423      P:0003BE P:0003BE 060240            DO      Y:<NROWS,LPR_TST                  ; Loop over each line readout
                            0003C9
1424      P:0003C0 P:0003C0 060140            DO      Y:<NCOLS,LSR_TST                  ; Loop over number of pixels per line
                            0003C8
1425      P:0003C2 P:0003C2 0614A0            REP     #20                               ; #20 => 1.0 microsec per pixel
1426      P:0003C3 P:0003C3 000000            NOP
1427      P:0003C4 P:0003C4 014180            ADD     #1,A                              ; Pixel data = Pixel data + 1
1428      P:0003C5 P:0003C5 000000            NOP
1429      P:0003C6 P:0003C6 21CF00            MOVE              A,B
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 27



1430      P:0003C7 P:0003C7 0D03CB            JSR     <XMT_PIX                          ;  transmit them
1431      P:0003C8 P:0003C8 000000            NOP
1432                                LSR_TST
1433      P:0003C9 P:0003C9 000000            NOP
1434                                LPR_TST
1435      P:0003CA P:0003CA 0C0372            JMP     <RDA_END                          ; Normal exit
1436   
1437                                ; Transmit the 16-bit pixel datum in B1 to the host computer
1438      P:0003CB P:0003CB 0C1DA1  XMT_PIX   ASL     #16,B,B
1439      P:0003CC P:0003CC 000000            NOP
1440      P:0003CD P:0003CD 216500            MOVE              B2,X1
1441      P:0003CE P:0003CE 0C1D91            ASL     #8,B,B
1442      P:0003CF P:0003CF 000000            NOP
1443      P:0003D0 P:0003D0 216400            MOVE              B2,X0
1444      P:0003D1 P:0003D1 000000            NOP
1445      P:0003D2 P:0003D2 09C532            MOVEP             X1,Y:WRFO
1446      P:0003D3 P:0003D3 09C432            MOVEP             X0,Y:WRFO
1447      P:0003D4 P:0003D4 00000C            RTS
1448   
1449                                ; Alert the PCI interface board that images are coming soon
1450                                PCI_READ_IMAGE
1451      P:0003D5 P:0003D5 57F400            MOVE              #$020104,B              ; Send header word to the FO transmitter
                            020104
1452      P:0003D7 P:0003D7 0D00EB            JSR     <XMT_WRD
1453      P:0003D8 P:0003D8 57F400            MOVE              #'RDA',B
                            524441
1454      P:0003DA P:0003DA 0D00EB            JSR     <XMT_WRD
1455      P:0003DB P:0003DB 5F8100            MOVE                          Y:<NCOLS,B  ; Number of columns to read
1456      P:0003DC P:0003DC 0D00EB            JSR     <XMT_WRD
1457      P:0003DD P:0003DD 5F8200            MOVE                          Y:<NROWS,B  ; Number of rows to read
1458      P:0003DE P:0003DE 0A008F            JCLR    #ST_CDS,X:<STATUS,NO_CDS3
                            0003E1
1459      P:0003E0 P:0003E0 20002B            LSR     B
1460      P:0003E1 P:0003E1 0D00EB  NO_CDS3   JSR     <XMT_WRD
1461      P:0003E2 P:0003E2 00000C            RTS
1462   
1463                                ; Wait for the clocking to be complete before proceeding
1464                                WAIT_TO_FINISH_CLOCKING
1465      P:0003E3 P:0003E3 01ADA1            JSET    #SSFEF,X:PDRD,*                   ; Wait for the SS FIFO to be empty
                            0003E3
1466      P:0003E5 P:0003E5 00000C            RTS
1467   
1468                                ; This MOVEP instruction executes in 30 nanosec, 20 nanosec for the MOVEP,
1469                                ;   and 10 nanosec for the wait state that is required for SRAM writes and
1470                                ;   FIFO setup times. It looks reliable, so will be used for now.
1471   
1472                                ; Core subroutine for clocking
1473                                CLOCK
1474      P:0003E6 P:0003E6 0A898E            JCLR    #SSFHF,X:HDR,*                    ; Only write to FIFO if < half full
                            0003E6
1475      P:0003E8 P:0003E8 000000            NOP
1476      P:0003E9 P:0003E9 0A898E            JCLR    #SSFHF,X:HDR,CLOCK                ; Guard against metastability
                            0003E6
1477      P:0003EB P:0003EB 4CD800            MOVE                          Y:(R0)+,X0  ; # of waveform entries
1478      P:0003EC P:0003EC 06C400            DO      X0,CLK1                           ; Repeat X0 times
                            0003EE
1479      P:0003EE P:0003EE 09D8F3            MOVEP             Y:(R0)+,Y:WRSS          ; 30 nsec Write the waveform to the SS
1480                                CLK1
1481      P:0003EF P:0003EF 000000            NOP
1482      P:0003F0 P:0003F0 00000C            RTS                                       ; Return from subroutine
1483   
1484                                ; Delay for serial writes to the PALs and DACs by 8 microsec
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 28



1485      P:0003F1 P:0003F1 062083  PAL_DLY   DO      #800,DLY                          ; Wait 8 usec for serial data transmission
                            0003F3
1486      P:0003F3 P:0003F3 000000            NOP
1487      P:0003F4 P:0003F4 000000  DLY       NOP
1488      P:0003F5 P:0003F5 00000C            RTS
1489   
1490                                ; Let the host computer read the controller configuration
1491                                READ_CONTROLLER_CONFIGURATION
1492      P:0003F6 P:0003F6 4F8B00            MOVE                          Y:<CONFIG,Y1 ; Just transmit the configuration
1493      P:0003F7 P:0003F7 0C0090            JMP     <FINISH1
1494   
1495                                ; Set a particular DAC numbers, for setting DC bias voltages, clock driver
1496                                ;   voltages and video processor offset
1497                                ;
1498                                ; SBN  #BOARD  #DAC  ['CLK' or 'VID']  voltage
1499                                ;
1500                                ;                               #BOARD is from 0 to 15
1501                                ;                               #DAC number
1502                                ;                               #voltage is from 0 to 4095
1503   
1504                                SET_BIAS_NUMBER                                     ; Set bias number
1505      P:0003F8 P:0003F8 012F23            BSET    #3,X:PCRD                         ; Turn on the serial clock
1506      P:0003F9 P:0003F9 56DB00            MOVE              X:(R3)+,A               ; First argument is board number, 0 to 15
1507      P:0003FA P:0003FA 0614A0            REP     #20
1508      P:0003FB P:0003FB 200033            LSL     A
1509      P:0003FC P:0003FC 000000            NOP
1510      P:0003FD P:0003FD 21C400            MOVE              A,X0
1511      P:0003FE P:0003FE 56DB00            MOVE              X:(R3)+,A               ; Second argument is DAC number
1512      P:0003FF P:0003FF 060EA0            REP     #14
1513      P:000400 P:000400 200033            LSL     A
1514      P:000401 P:000401 200042            OR      X0,A
1515      P:000402 P:000402 57DB00            MOVE              X:(R3)+,B               ; Third argument is 'VID' or 'CLK' string
1516      P:000403 P:000403 44F400            MOVE              #'VID',X0
                            564944
1517      P:000405 P:000405 20004D            CMP     X0,B
1518      P:000406 P:000406 0E240B            JNE     <CLK_DRV
1519      P:000407 P:000407 0ACC73            BSET    #19,A1                            ; Set bits to mean video processor DAC
1520      P:000408 P:000408 000000            NOP
1521      P:000409 P:000409 0ACC72            BSET    #18,A1
1522      P:00040A P:00040A 0C040F            JMP     <VID_BRD
1523      P:00040B P:00040B 44F400  CLK_DRV   MOVE              #'CLK',X0
                            434C4B
1524      P:00040D P:00040D 20004D            CMP     X0,B
1525      P:00040E P:00040E 0E2419            JNE     <ERR_SBN
1526      P:00040F P:00040F 21C400  VID_BRD   MOVE              A,X0
1527      P:000410 P:000410 56DB00            MOVE              X:(R3)+,A               ; Fourth argument is voltage value, 0 to $ff
f
1528      P:000411 P:000411 46F400            MOVE              #$000FFF,Y0             ; Mask off just 12 bits to be sure
                            000FFF
1529      P:000413 P:000413 200056            AND     Y0,A
1530      P:000414 P:000414 200042            OR      X0,A
1531      P:000415 P:000415 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1532      P:000416 P:000416 0D03F1            JSR     <PAL_DLY                          ; Wait for the number to be sent
1533      P:000417 P:000417 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1534      P:000418 P:000418 0C008F            JMP     <FINISH
1535      P:000419 P:000419 56DB00  ERR_SBN   MOVE              X:(R3)+,A               ; Read and discard the fourth argument
1536      P:00041A P:00041A 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1537      P:00041B P:00041B 0C008D            JMP     <ERROR
1538   
1539                                ; Specify the MUX value to be output on the clock driver board
1540                                ; Command syntax is  SMX  #clock_driver_board #MUX1 #MUX2
1541                                ;                               #clock_driver_board from 0 to 15
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 29



1542                                ;                               #MUX1, #MUX2 from 0 to 23
1543   
1544      P:00041C P:00041C 012F23  SET_MUX   BSET    #3,X:PCRD                         ; Turn on the serial clock
1545      P:00041D P:00041D 56DB00            MOVE              X:(R3)+,A               ; Clock driver board number
1546      P:00041E P:00041E 0614A0            REP     #20
1547      P:00041F P:00041F 200033            LSL     A
1548      P:000420 P:000420 44F400            MOVE              #$003000,X0
                            003000
1549      P:000422 P:000422 200042            OR      X0,A
1550      P:000423 P:000423 000000            NOP
1551      P:000424 P:000424 21C500            MOVE              A,X1                    ; Move here for storage
1552   
1553                                ; Get the first MUX number
1554      P:000425 P:000425 56DB00            MOVE              X:(R3)+,A               ; Get the first MUX number
1555      P:000426 P:000426 0AF0A9            JLT     ERR_SM1
                            00046A
1556      P:000428 P:000428 44F400            MOVE              #>24,X0                 ; Check for argument less than 32
                            000018
1557      P:00042A P:00042A 200045            CMP     X0,A
1558      P:00042B P:00042B 0AF0A1            JGE     ERR_SM1
                            00046A
1559      P:00042D P:00042D 21CF00            MOVE              A,B
1560      P:00042E P:00042E 44F400            MOVE              #>7,X0
                            000007
1561      P:000430 P:000430 20004E            AND     X0,B
1562      P:000431 P:000431 44F400            MOVE              #>$18,X0
                            000018
1563      P:000433 P:000433 200046            AND     X0,A
1564      P:000434 P:000434 0E2437            JNE     <SMX_1                            ; Test for 0 <= MUX number <= 7
1565      P:000435 P:000435 0ACD63            BSET    #3,B1
1566      P:000436 P:000436 0C0442            JMP     <SMX_A
1567      P:000437 P:000437 44F400  SMX_1     MOVE              #>$08,X0
                            000008
1568      P:000439 P:000439 200045            CMP     X0,A                              ; Test for 8 <= MUX number <= 15
1569      P:00043A P:00043A 0E243D            JNE     <SMX_2
1570      P:00043B P:00043B 0ACD64            BSET    #4,B1
1571      P:00043C P:00043C 0C0442            JMP     <SMX_A
1572      P:00043D P:00043D 44F400  SMX_2     MOVE              #>$10,X0
                            000010
1573      P:00043F P:00043F 200045            CMP     X0,A                              ; Test for 16 <= MUX number <= 23
1574      P:000440 P:000440 0E246A            JNE     <ERR_SM1
1575      P:000441 P:000441 0ACD65            BSET    #5,B1
1576      P:000442 P:000442 20006A  SMX_A     OR      X1,B1                             ; Add prefix to MUX numbers
1577      P:000443 P:000443 000000            NOP
1578      P:000444 P:000444 21A700            MOVE              B1,Y1
1579   
1580                                ; Add on the second MUX number
1581      P:000445 P:000445 56DB00            MOVE              X:(R3)+,A               ; Get the next MUX number
1582      P:000446 P:000446 0E908D            JLT     <ERROR
1583      P:000447 P:000447 44F400            MOVE              #>24,X0                 ; Check for argument less than 32
                            000018
1584      P:000449 P:000449 200045            CMP     X0,A
1585      P:00044A P:00044A 0E108D            JGE     <ERROR
1586      P:00044B P:00044B 0606A0            REP     #6
1587      P:00044C P:00044C 200033            LSL     A
1588      P:00044D P:00044D 000000            NOP
1589      P:00044E P:00044E 21CF00            MOVE              A,B
1590      P:00044F P:00044F 44F400            MOVE              #$1C0,X0
                            0001C0
1591      P:000451 P:000451 20004E            AND     X0,B
1592      P:000452 P:000452 44F400            MOVE              #>$600,X0
                            000600
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 30



1593      P:000454 P:000454 200046            AND     X0,A
1594      P:000455 P:000455 0E2458            JNE     <SMX_3                            ; Test for 0 <= MUX number <= 7
1595      P:000456 P:000456 0ACD69            BSET    #9,B1
1596      P:000457 P:000457 0C0463            JMP     <SMX_B
1597      P:000458 P:000458 44F400  SMX_3     MOVE              #>$200,X0
                            000200
1598      P:00045A P:00045A 200045            CMP     X0,A                              ; Test for 8 <= MUX number <= 15
1599      P:00045B P:00045B 0E245E            JNE     <SMX_4
1600      P:00045C P:00045C 0ACD6A            BSET    #10,B1
1601      P:00045D P:00045D 0C0463            JMP     <SMX_B
1602      P:00045E P:00045E 44F400  SMX_4     MOVE              #>$400,X0
                            000400
1603      P:000460 P:000460 200045            CMP     X0,A                              ; Test for 16 <= MUX number <= 23
1604      P:000461 P:000461 0E208D            JNE     <ERROR
1605      P:000462 P:000462 0ACD6B            BSET    #11,B1
1606      P:000463 P:000463 200078  SMX_B     ADD     Y1,B                              ; Add prefix to MUX numbers
1607      P:000464 P:000464 000000            NOP
1608      P:000465 P:000465 21AE00            MOVE              B1,A
1609      P:000466 P:000466 0D020C            JSR     <XMIT_A_WORD                      ; Transmit A to TIM-A-STD
1610      P:000467 P:000467 0D03F1            JSR     <PAL_DLY                          ; Delay for all this to happen
1611      P:000468 P:000468 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1612      P:000469 P:000469 0C008F            JMP     <FINISH
1613      P:00046A P:00046A 56DB00  ERR_SM1   MOVE              X:(R3)+,A
1614      P:00046B P:00046B 012F03            BCLR    #3,X:PCRD                         ; Turn the serial clock off
1615      P:00046C P:00046C 0C008D            JMP     <ERROR
1616   
1617                                ; Write a number to an analog board over the serial link
1618      P:00046D P:00046D 012F23  WR_BIAS   BSET    #3,X:PCRD                         ; Turn on the serial clock
1619      P:00046E P:00046E 0D03F1            JSR     <PAL_DLY
1620      P:00046F P:00046F 0D020C            JSR     <XMIT_A_WORD                      ; Transmit it to TIM-A-STD
1621      P:000470 P:000470 0D03F1            JSR     <PAL_DLY
1622      P:000471 P:000471 012F03            BCLR    #3,X:PCRD                         ; Turn off the serial clock
1623      P:000472 P:000472 0D03F1            JSR     <PAL_DLY
1624      P:000473 P:000473 00000C            RTS
1625   
1626                                ; Read DAC values from a table, and write them to the DACs
1627      P:000474 P:000474 065840  SET_DAC   DO      Y:(R0)+,L_DAC                     ; Repeat Y:(R0)+ times
                            000478
1628      P:000476 P:000476 5ED800            MOVE                          Y:(R0)+,A   ; Read the table entry
1629      P:000477 P:000477 0D020C            JSR     <XMIT_A_WORD                      ; Transmit it to TIM-A-STD
1630      P:000478 P:000478 000000            NOP
1631      P:000479 P:000479 00000C  L_DAC     RTS
1632   
1633                                ; Short delay for the array to settle down after a global reset
1634                                MILLISEC_DELAY
1635      P:00047A P:00047A 200003            TST     A
1636      P:00047B P:00047B 0E247D            JNE     <DLY_IT
1637      P:00047C P:00047C 00000C            RTS
1638      P:00047D P:00047D 014184  DLY_IT    SUB     #1,A
1639      P:00047E P:00047E 07F40E            MOVEP             #0,X:TLR0               ; Load 0 into counter timer
                            000000
1640      P:000480 P:000480 010F20            BSET    #TIM_BIT,X:TCSR0                  ; Enable the timer #0
1641      P:000481 P:000481 567000            MOVE              A,X:TCPR0               ; Desired elapsed time
                            FFFF8D
1642      P:000483 P:000483 018F95  CNT_DWN   JCLR    #TCF,X:TCSR0,CNT_DWN              ; Wait here for timer to count down
                            000483
1643      P:000485 P:000485 010F00            BCLR    #TIM_BIT,X:TCSR0
1644      P:000486 P:000486 00000C            RTS
1645   
1646                                ; Put PCI board in reading image out mode to block commands to the timing board
1647                                READING_IMAGE_ON
1648      P:000487 P:000487 57F400            MOVE              #$020102,B              ; Send header word to the FO transmitter
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 31



                            020102
1649      P:000489 P:000489 0D00EB            JSR     <XMT_WRD
1650      P:00048A P:00048A 57F400            MOVE              #'RDI',B
                            524449
1651      P:00048C P:00048C 0D00EB            JSR     <XMT_WRD
1652      P:00048D P:00048D 00000C            RTS
1653   
1654                                ; Select which readouts to readout - 'SOS'  Amplifier_name
1655                                ;       Amplifier_name = 0, 1, 2, 3 or 'ALL'
1656   
1657                                SELECT_OUTPUT_SOURCE
1658      P:00048E P:00048E 44DB00            MOVE              X:(R3)+,X0              ; Get amplifier(s) name or number
1659      P:00048F P:00048F 4C0F00            MOVE                          X0,Y:<OS
1660      P:000490 P:000490 56F400            MOVE              #'ALL',A                ; All amplifiers = readouts #0 to #3
                            414C4C
1661      P:000492 P:000492 200045            CMP     X0,A
1662      P:000493 P:000493 0E2497            JNE     <CHK_0
1663      P:000494 P:000494 44F400            MOVE              #$00F0C0,X0
                            00F0C0
1664      P:000496 P:000496 0C04B2            JMP     <SOS
1665      P:000497 P:000497 56F400  CHK_0     MOVE              #>0,A                   ; Amplifier 0 = Upper Left
                            000000
1666      P:000499 P:000499 200045            CMP     X0,A
1667      P:00049A P:00049A 0E249E            JNE     <CHK_1
1668      P:00049B P:00049B 44F400            MOVE              #$00F000,X0
                            00F000
1669      P:00049D P:00049D 0C04B2            JMP     <SOS
1670      P:00049E P:00049E 56F400  CHK_1     MOVE              #>1,A                   ; Amplifier 1 = Upper Right
                            000001
1671      P:0004A0 P:0004A0 200045            CMP     X0,A
1672      P:0004A1 P:0004A1 0E24A5            JNE     <CHK_2
1673      P:0004A2 P:0004A2 44F400            MOVE              #$00F041,X0
                            00F041
1674      P:0004A4 P:0004A4 0C04B2            JMP     <SOS
1675      P:0004A5 P:0004A5 56F400  CHK_2     MOVE              #>2,A                   ; Amplifier 2 = Lower Right
                            000002
1676      P:0004A7 P:0004A7 200045            CMP     X0,A
1677      P:0004A8 P:0004A8 0E24AC            JNE     <CHK_3
1678      P:0004A9 P:0004A9 44F400            MOVE              #$00F082,X0
                            00F082
1679      P:0004AB P:0004AB 0C04B2            JMP     <SOS
1680      P:0004AC P:0004AC 56F400  CHK_3     MOVE              #>3,A                   ; Amplifier 3 = Lower Left
                            000003
1681      P:0004AE P:0004AE 200045            CMP     X0,A
1682      P:0004AF P:0004AF 0E208D            JNE     <ERROR
1683      P:0004B0 P:0004B0 44F400            MOVE              #$00F0C3,X0
                            00F0C3
1684   
1685      P:0004B2 P:0004B2 4C7000  SOS       MOVE                          X0,Y:SXMIT0
                            000089
1686      P:0004B4 P:0004B4 4C7000            MOVE                          X0,Y:SXMIT1
                            00008E
1687      P:0004B6 P:0004B6 4C7000            MOVE                          X0,Y:SXMIT2
                            00009C
1688      P:0004B8 P:0004B8 4C7000            MOVE                          X0,Y:SXMIT3
                            0000A0
1689      P:0004BA P:0004BA 4C7000            MOVE                          X0,Y:SXMIT00
                            000096
1690      P:0004BC P:0004BC 0C008F            JMP     <FINISH
1691   
1692                                ; Special continuous readout commands
1693                                SET_NUMBER_OF_COADDS
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  timIRmisc.asm  Page 32



1694      P:0004BD P:0004BD 44DB00            MOVE              X:(R3)+,X0
1695      P:0004BE P:0004BE 4C1200            MOVE                          X0,Y:<NCOADDS
1696      P:0004BF P:0004BF 0C008F            JMP     <FINISH
1697   
1698                                SET_NUMBER_OF_FRAMES_PER_BUFFER
1699      P:0004C0 P:0004C0 44DB00            MOVE              X:(R3)+,X0
1700      P:0004C1 P:0004C1 4C1500            MOVE                          X0,Y:<N_FPB
1701      P:0004C2 P:0004C2 0C008F            JMP     <FINISH
1702   
1703                                ; Set number of readout times per pixel
1704                                SET_NUM_READS
1705      P:0004C3 P:0004C3 44DB00            MOVE              X:(R3)+,X0
1706      P:0004C4 P:0004C4 4C0500            MOVE                          X0,Y:<NUM_RDS
1707      P:0004C5 P:0004C5 0C008F            JMP     <FINISH
1708   
1709                                SET_NUMBER_OF_FRAMES_PER_RESET
1710      P:0004C6 P:0004C6 44DB00            MOVE              X:(R3)+,X0
1711      P:0004C7 P:0004C7 4C0600            MOVE                          X0,Y:<N_FPR
1712      P:0004C8 P:0004C8 0C008F            JMP     <FINISH
1713   
1714                                ; Subarray readout - specify region to read
1715                                SPECIFY_SUB_ARRAY
1716      P:0004C9 P:0004C9 44DB00            MOVE              X:(R3)+,X0
1717      P:0004CA P:0004CA 4C0300            MOVE                          X0,Y:<COL_OFFSET
1718      P:0004CB P:0004CB 44DB00            MOVE              X:(R3)+,X0
1719      P:0004CC P:0004CC 4C0400            MOVE                          X0,Y:<ROW_OFFSET
1720      P:0004CD P:0004CD 0C008F            JMP     <FINISH
1721   
1722                                ; Set trigger mode, to start readout on trigger true.
1723                                SET_TRIGGER_MODE
1724      P:0004CE P:0004CE 0A5B80            JCLR    #0,X:(R3)+,NO_TRIGGER             ; 1 for external triggering 0 for not
                            0004D2
1725      P:0004D0 P:0004D0 0A002D            BSET    #ST_SYNC,X:<STATUS
1726      P:0004D1 P:0004D1 0C008F            JMP     <FINISH
1727                                NO_TRIGGER
1728      P:0004D2 P:0004D2 0A000D            BCLR    #ST_SYNC,X:<STATUS
1729      P:0004D3 P:0004D3 0C008F            JMP     <FINISH
1730   
1731                                ; Set correlated double sample (CDS) mode, to readout before and after exposure
1732                                SET_CDS_MODE
1733      P:0004D4 P:0004D4 0A5B80            JCLR    #0,X:(R3)+,NO_CDS4                ; 1 for CDS, 0 for not
                            0004D8
1734      P:0004D6 P:0004D6 0A002F            BSET    #ST_CDS,X:<STATUS
1735      P:0004D7 P:0004D7 0C008F            JMP     <FINISH
1736                                NO_CDS4
1737      P:0004D8 P:0004D8 0A000F            BCLR    #ST_CDS,X:<STATUS
1738      P:0004D9 P:0004D9 0C008F            JMP     <FINISH
1739   
1740                                ; Turn the PICNIC signal READ on before an exposure and off after it?
1741                                SET_READ_MODE
1742      P:0004DA P:0004DA 0A5B80            JCLR    #0,X:(R3)+,NO_READ_ON_AND_OFF     ; 1 for turning it on and off
                            0004DE
1743      P:0004DC P:0004DC 0A0030            BSET    #ST_RD,X:<STATUS
1744      P:0004DD P:0004DD 0C008F            JMP     <FINISH
1745                                NO_READ_ON_AND_OFF
1746      P:0004DE P:0004DE 0A0010            BCLR    #ST_RD,X:<STATUS
1747      P:0004DF P:0004DF 0C008F            JMP     <FINISH
1748   
1749   
1750                                 TIMBOOT_X_MEMORY
1751      0004E0                              EQU     @LCV(L)
1752   
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 33



1753                                ; Define the address in P: space where the table of constants begins
1754   
1755                                          IF      @SCP("HOST","HOST")
1756      X:000036 X:000036                   ORG     X:END_COMMAND_TABLE,X:END_COMMAND_TABLE
1757                                          ENDIF
1758   
1759                                          IF      @SCP("HOST","ROM")
1761                                          ENDIF
1762   
1763      X:000036 X:000036                   DC      'SEX',START_EXPOSURE
1764      X:000038 X:000038                   DC      'AEX',ABORT_EXPOSURE
1765      X:00003A X:00003A                   DC      'PON',POWER_ON
1766      X:00003C X:00003C                   DC      'POF',POWER_OFF
1767      X:00003E X:00003E                   DC      'SET',SET_EXPOSURE_TIME
1768      X:000040 X:000040                   DC      'RET',READ_EXPOSURE_TIME
1769      X:000042 X:000042                   DC      'SBN',SET_BIAS_NUMBER
1770      X:000044 X:000044                   DC      'SMX',SET_MUX
1771      X:000046 X:000046                   DC      'SBV',SET_BIASES
1772      X:000048 X:000048                   DC      'RCC',READ_CONTROLLER_CONFIGURATION
1773      X:00004A X:00004A                   DC      'DON',START
1774   
1775                                ; Continuous readout commands
1776      X:00004C X:00004C                   DC      'SNC',SET_NUMBER_OF_COADDS
1777      X:00004E X:00004E                   DC      'FPB',SET_NUMBER_OF_FRAMES_PER_BUFFER
1778   
1779                                ; Custom commands
1780      X:000050 X:000050                   DC      'STM',SET_TRIGGER_MODE
1781      X:000052 X:000052                   DC      'SOS',SELECT_OUTPUT_SOURCE
1782      X:000054 X:000054                   DC      'SNR',SET_NUM_READS
1783      X:000056 X:000056                   DC      'SFR',SET_NUMBER_OF_FRAMES_PER_RESET
1784      X:000058 X:000058                   DC      'SSA',SPECIFY_SUB_ARRAY
1785      X:00005A X:00005A                   DC      'CDS',SET_CDS_MODE
1786      X:00005C X:00005C                   DC      'SRD',SET_READ_MODE               ; READ signal on PICNIC on and off?
1787   
1788                                 END_APPLICATON_COMMAND_TABLE
1789      00005E                              EQU     @LCV(L)
1790   
1791                                          IF      @SCP("HOST","HOST")
1792      00001B                    NUM_COM   EQU     (@LCV(R)-COM_TBL_R)/2             ; Number of boot +
1793                                                                                    ;  application commands
1794      000323                    EXPOSING  EQU     CHK_TIM                           ; Address if exposing
1795                                 CONTINUE_READING
1796      000380                              EQU     CONTINUE_READ                     ; Address if reading out
1797                                          ENDIF
1798   
1799                                          IF      @SCP("HOST","ROM")
1801                                          ENDIF
1802   
1803                                ; Now let's go for the timing waveform tables
1804                                          IF      @SCP("HOST","HOST")
1805      Y:000000 Y:000000                   ORG     Y:0,Y:0
1806                                          ENDIF
1807   
1808      Y:000000 Y:000000         GAIN      DC      END_APPLICATON_Y_MEMORY-@LCV(L)-1
1809   
1810      Y:000001 Y:000001         NCOLS     DC      1024                              ; Number of columns
1811      Y:000002 Y:000002         NROWS     DC      1024                              ; Number of rows
1812      Y:000003 Y:000003         COL_OFFSET DC     0                                 ; Number of columns to skip in subarray mode
1813      Y:000004 Y:000004         ROW_OFFSET DC     0                                 ; Number of rows to skip in subarray mode
1814      Y:000005 Y:000005         NUM_RDS   DC      1                                 ; Number of reads per reset
1815      Y:000006 Y:000006         N_FPR     DC      1                                 ; Number of frames per reset
1816      Y:000007 Y:000007         I_FPR     DC      1                                 ; Counter for frames per reset
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  tim.asm  Page 34



1817      Y:000008 Y:000008         RST_DLY   DC      50                                ; Delay after array reset for settling
1818      Y:000009 Y:000009         PWR_DLY   DC      100                               ; Delay in millisec for power to turn on
1819      Y:00000A Y:00000A         VDD_DLY   DC      300                               ; Delay in millise for VDD to settle
1820      Y:00000B Y:00000B         CONFIG    DC      CC                                ; Controller configuration
1821      Y:00000C Y:00000C         TST_DAT   DC      0                                 ; Synthetic image test datum
1822      Y:00000D Y:00000D         ODD_ROW   DC      0                                 ; Odd or even row number
1823      Y:00000E Y:00000E         ODD_COL   DC      0                                 ; Odd or even column number
1824      Y:00000F Y:00000F         OS        DC      'ALL'                             ; Number of readouts
1825      Y:000010 Y:000010         NXLOOP    DC      0                                 ; Loop index for the columns
1826      Y:000011 Y:000011         NYLOOP    DC      0                                 ; Loop index for the rows
1827   
1828                                ; Continuous readout mode constants
1829      Y:000012 Y:000012         NCOADDS   DC      1                                 ; Number of coadditions per exposure
1830      Y:000013 Y:000013         ICOADD    DC      0                                 ; Counter of number of coadds done so far
1831      Y:000014 Y:000014         IBUFFER   DC      0                                 ; Buffer pointer - counts from 0 to N_FPB
1832      Y:000015 Y:000015         N_FPB     DC      1                                 ; Number of frames in each image buffer
1833   
1834                                ; Include the waveform table for the PICNIC focal plane array
1835                                          INCLUDE "HAWAII.waveforms"                ; Readout and clocking waveform file
1836   
1837                                ; Miscellaneous definitions
1838      000000                    VIDEO     EQU     $000000                           ; Video board select = 0 for first A/D board
 with biases
1839      002000                    CLK2      EQU     $002000                           ; Clock board select = 2
1840      003000                    CLK3      EQU     $003000                           ; Clock board select = 3
1841      200000                    CLKV      EQU     $200000                           ; Clock driver board DAC voltage selection a
ddress
1842      050000                    DELAY     EQU     $050000                           ; Delay for clocking operations
1843                                                                                    ;    (20 ns unit, 160 if MSB set)
1844      100000                    VP_DLY    EQU     $100000                           ; Video delay time
1845      00F0C0                    SXMIT     EQU     $00F0C0                           ; Series transmit A/D channels #0 to 3
1846   
1847                                ;  Clock voltage definitions
1848      4.000000E+000             CLK_HIGH  EQU     4.0
1849      3.000000E-001             CLK_LOW   EQU     0.3
1850      5.000000E+000             Vmax      EQU     +5.0
1851      0.000000E+000             ZERO      EQU     0.0
1852   
1853                                ; Table of offset values begins at Y:$10
1854   
1855                                ; DAC settings for the video offsets
1856      Y:000016 Y:000016         DC_BIASES DC      END_DC_BIASES-DC_BIASES-1
1857      Y:000017 Y:000017         OFF_0     DC      $0c0000                           ; Input offset board #0, channel A
1858      Y:000018 Y:000018         OFF_1     DC      $0c4000                           ; Input offset board #0, channel B
1859      Y:000019 Y:000019         OFF_2     DC      $1c0000                           ; Input offset board #1, channel A
1860      Y:00001A Y:00001A         OFF_3     DC      $1c4000                           ; Input offset board #1, channel B
1861   
1862                                ; DAC settings to generate DC bias voltages for the PICNIC array
1863                                ;VOFFSET     DC    $0c8bd4     ; pin #1 = preamp offset = +3.7 volts
1864      Y:00001B Y:00001B         VOFFSET   DC      $0c8eb7                           ; pin #1 = preamp offset = +4.6 volts
1865      Y:00001C Y:00001C         VRESET    DC      $0cc195                           ; pin #2 = reset = +0.5 volts
1866      Y:00001D Y:00001D         VD        DC      $0d0fff                           ; pin #3 = analog power = +5.0 volts
1867                                ;ICTL        DC    $0d4bd4     ; pin #4 = current control = +3.7 volts
1868      Y:00001E Y:00001E         ICTL      DC      $0d4a8e                           ; pin #4 = current control = +3.3 volts
1869      Y:00001F Y:00001F         VDD       DC      $0d8ccb                           ; pin #5 = digital power = +4.0 volts
1870      Y:000020 Y:000020         VUNUSED   DC      $0dc000                           ; pin #6 = unused to 0V
1871                                END_DC_BIASES
1872   
1873                                ;  Zero out the DC biases during the power-on sequence
1874                                ZERO_BIASES
1875      Y:000021 Y:000021                   DC      END_ZERO_BIASES-ZERO_BIASES-1
1876      Y:000022 Y:000022                   DC      $0c8000                           ; Pin #1, board #0
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  HAWAII.waveforms  Page 35



1877      Y:000023 Y:000023                   DC      $0cc000                           ; Pin #2
1878      Y:000024 Y:000024                   DC      $0d0000                           ; Pin #3
1879      Y:000025 Y:000025                   DC      $0d4000                           ; Pin #4
1880      Y:000026 Y:000026                   DC      $0d8000                           ; Pin #5
1881      Y:000027 Y:000027                   DC      $0dc000                           ; Pin #6
1882   
1883      Y:000028 Y:000028                   DC      $1c8000                           ; Pin #1, board #1
1884      Y:000029 Y:000029                   DC      $1cc000                           ; Pin #2
1885      Y:00002A Y:00002A                   DC      $1d0000                           ; Pin #3
1886      Y:00002B Y:00002B                   DC      $1d4000                           ; Pin #4
1887      Y:00002C Y:00002C                   DC      $1d8000                           ; Pin #5
1888      Y:00002D Y:00002D                   DC      $1dc000                           ; Pin #6
1889                                END_ZERO_BIASES
1890   
1891                                ; Initialize all DACs, starting with the clock driver ones
1892      Y:00002E Y:00002E         DACS      DC      END_DACS-DACS-1
1893      Y:00002F Y:00002F                   DC      CLKV+$0A0080                      ; DAC = unbuffered mode
1894      Y:000030 Y:000030                   DC      CLKV+$000100+@CVI((CLK_HIGH/Vmax)*255) ; Pin #1, RESET
1895      Y:000031 Y:000031                   DC      CLKV+$000200+@CVI((CLK_LOW/Vmax)*255)
1896      Y:000032 Y:000032                   DC      CLKV+$000400+@CVI((CLK_HIGH/Vmax)*255) ; Pin #2, LINE
1897      Y:000033 Y:000033                   DC      CLKV+$000800+@CVI((CLK_LOW/Vmax)*255)
1898      Y:000034 Y:000034                   DC      CLKV+$002000+@CVI((CLK_HIGH/Vmax)*255) ; Pin #3, LSYNC
1899      Y:000035 Y:000035                   DC      CLKV+$004000+@CVI((CLK_LOW/Vmax)*255)
1900      Y:000036 Y:000036                   DC      CLKV+$008000+@CVI((CLK_HIGH/Vmax)*255) ; Pin #4, FSYNC
1901      Y:000037 Y:000037                   DC      CLKV+$010000+@CVI((CLK_LOW/Vmax)*255)
1902      Y:000038 Y:000038                   DC      CLKV+$020100+@CVI((ZERO/Vmax)*255) ; Pin #5, Unused
1903      Y:000039 Y:000039                   DC      CLKV+$020200+@CVI((ZERO/Vmax)*255)
1904      Y:00003A Y:00003A                   DC      CLKV+$020400+@CVI((CLK_HIGH/Vmax)*255) ; Pin #6, READ
1905      Y:00003B Y:00003B                   DC      CLKV+$020800+@CVI((CLK_LOW/Vmax)*255)
1906      Y:00003C Y:00003C                   DC      CLKV+$022000+@CVI((ZERO/Vmax)*255) ; Pin #7, Unused
1907      Y:00003D Y:00003D                   DC      CLKV+$024000+@CVI((ZERO/Vmax)*255)
1908      Y:00003E Y:00003E                   DC      CLKV+$028000+@CVI((ZERO/Vmax)*255) ; Pin #8, Unused
1909      Y:00003F Y:00003F                   DC      CLKV+$030000+@CVI((ZERO/Vmax)*255)
1910      Y:000040 Y:000040                   DC      CLKV+$040100+@CVI((ZERO/Vmax)*255) ; Pin #9, Unused
1911      Y:000041 Y:000041                   DC      CLKV+$040200+@CVI((ZERO/Vmax)*255)
1912      Y:000042 Y:000042                   DC      CLKV+$040400+@CVI((ZERO/Vmax)*255) ; Pin #10, Unused
1913      Y:000043 Y:000043                   DC      CLKV+$040800+@CVI((ZERO/Vmax)*255)
1914      Y:000044 Y:000044                   DC      CLKV+$042000+@CVI((ZERO/Vmax)*255) ; Pin #11, Unused
1915      Y:000045 Y:000045                   DC      CLKV+$044000+@CVI((ZERO/Vmax)*255)
1916      Y:000046 Y:000046                   DC      CLKV+$048000+@CVI((ZERO/Vmax)*255) ; Pin #12, Unused
1917      Y:000047 Y:000047                   DC      CLKV+$050000+@CVI((ZERO/Vmax)*255)
1918   
1919      Y:000048 Y:000048                   DC      CLKV+$060100+@CVI((CLK_HIGH/Vmax)*255) ; Pin #13, PIXEL
1920      Y:000049 Y:000049                   DC      CLKV+$060200+@CVI((CLK_LOW/Vmax)*255)
1921      Y:00004A Y:00004A                   DC      CLKV+$060400+@CVI((ZERO/Vmax)*255) ; Pin #14, Unused
1922      Y:00004B Y:00004B                   DC      CLKV+$060800+@CVI((ZERO/Vmax)*255)
1923      Y:00004C Y:00004C                   DC      CLKV+$062000+@CVI((ZERO/Vmax)*255) ; Pin #15, Unused
1924      Y:00004D Y:00004D                   DC      CLKV+$064000+@CVI((ZERO/Vmax)*255)
1925      Y:00004E Y:00004E                   DC      CLKV+$068000+@CVI((ZERO/Vmax)*255) ; Pin #16, Unused
1926      Y:00004F Y:00004F                   DC      CLKV+$070000+@CVI((ZERO/Vmax)*255)
1927      Y:000050 Y:000050                   DC      CLKV+$080100+@CVI((ZERO/Vmax)*255) ; Pin #17, Unused
1928      Y:000051 Y:000051                   DC      CLKV+$080200+@CVI((ZERO/Vmax)*255)
1929      Y:000052 Y:000052                   DC      CLKV+$080400+@CVI((ZERO/Vmax)*255) ; Pin #18, Unused
1930      Y:000053 Y:000053                   DC      CLKV+$080800+@CVI((ZERO/Vmax)*255)
1931      Y:000054 Y:000054                   DC      CLKV+$082000+@CVI((ZERO/Vmax)*255) ; Pin #19, Unused
1932      Y:000055 Y:000055                   DC      CLKV+$084000+@CVI((ZERO/Vmax)*255)
1933      Y:000056 Y:000056                   DC      CLKV+$088000+@CVI((ZERO/Vmax)*255) ; Pin #33, Unused
1934      Y:000057 Y:000057                   DC      CLKV+$090000+@CVI((ZERO/Vmax)*255)
1935      Y:000058 Y:000058                   DC      CLKV+$0A0100+@CVI((ZERO/Vmax)*255) ; Pin #34, Unused
1936      Y:000059 Y:000059                   DC      CLKV+$0A0200+@CVI((ZERO/Vmax)*255)
1937      Y:00005A Y:00005A                   DC      CLKV+$0A0400+@CVI((ZERO/Vmax)*255) ; Pin #35, Unused
1938      Y:00005B Y:00005B                   DC      CLKV+$0A0800+@CVI((ZERO/Vmax)*255)
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  HAWAII.waveforms  Page 36



1939      Y:00005C Y:00005C                   DC      CLKV+$0A2000+@CVI((ZERO/Vmax)*255) ; Pin #36, Unused
1940      Y:00005D Y:00005D                   DC      CLKV+$0A4000+@CVI((ZERO/Vmax)*255)
1941      Y:00005E Y:00005E                   DC      CLKV+$0A8000+@CVI((ZERO/Vmax)*255) ; Pin #37, Unused
1942      Y:00005F Y:00005F                   DC      CLKV+$0B0000+@CVI((ZERO/Vmax)*255)
1943                                END_DACS
1944   
1945                                ; Define switch state bits for the first group of 12 clocks = CLK2
1946      000001                    H_RESET   EQU     1                                 ; Pin #1
1947      000000                    L_RESET   EQU     0
1948      000002                    H_LINE    EQU     2                                 ; Pin #2
1949      000000                    L_LINE    EQU     0
1950      000004                    H_LSYNC   EQU     4                                 ; Pin #3
1951      000000                    L_LSYNC   EQU     0
1952      000008                    H_FSYNC   EQU     8                                 ; Pin #4
1953      000000                    L_FSYNC   EQU     0
1954      000020                    H_READ    EQU     $20                               ; Pin #6
1955      000000                    L_READ    EQU     0
1956   
1957                                ; Define switch state bits for the second group of 12 clocks = CLK3
1958      000001                    H_PIXEL   EQU     1                                 ; Pin #13
1959      000000                    L_PIXEL   EQU     0
1960   
1961                                ;SXMIT  EQU     $00F0C0                         ; Transmit A/Ds = 0 to 3
1962                                ;SXMIT  EQU     $00F000                         ; Transmit A/D = 0
1963                                ;SXMIT  EQU     $00F041                         ; Transmit A/D = 1
1964                                ;SXMIT  EQU     $00F082                         ; Transmit A/D = 2
1965                                ;SXMIT  EQU     $00F0C3                         ; Transmit A/D = 3
1966   
1967                                ; Symbolic definitions
1968                                ;       DC      CLK2+DELAY+L_FSYNC+L_LSYNC+L_LINE+L_READ+H_RESET
1969                                ;       DC      CLK3+DELAY+L_PIXEL
1970   
1971                                ; Turn READ ON for readout and reset
1972                                READ_ON
1973      Y:000060 Y:000060                   DC      END_READ_ON-READ_ON-1
1974      Y:000061 Y:000061                   DC      CLK3+DELAY+L_PIXEL
1975      Y:000062 Y:000062                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
1976                                END_READ_ON
1977   
1978                                ; Turn READ OFF during exposure
1979                                READ_OFF
1980      Y:000063 Y:000063                   DC      END_READ_OFF-READ_OFF-1
1981      Y:000064 Y:000064                   DC      CLK3+DELAY+L_PIXEL
1982      Y:000065 Y:000065                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+L_READ+H_RESET
1983                                END_READ_OFF
1984   
1985                                ;  Initialize the frame for readout, including shift register (slow row scanner)
1986                                INIT_FRAME
1987      Y:000066 Y:000066                   DC      END_INIT_FRAME-INIT_FRAME-1
1988      Y:000067 Y:000067                   DC      CLK3+DELAY+L_PIXEL
1989      Y:000068 Y:000068                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
1990      Y:000069 Y:000069                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+H_RESET
1991      Y:00006A Y:00006A                   DC      CLK2+DELAY+L_FSYNC+L_LSYNC+L_LINE+H_READ+H_RESET
1992                                END_INIT_FRAME
1993   
1994                                SHIFT_RESET_ODD_ROW
1995      Y:00006B Y:00006B                   DC      END_SHIFT_RESET_ODD_ROW-SHIFT_RESET_ODD_ROW-1
1996      Y:00006C Y:00006C                   DC      CLK3+DELAY+L_PIXEL
1997      Y:00006D Y:00006D                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+H_RESET
1998      Y:00006E Y:00006E                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
1999      Y:00006F Y:00006F                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
2000      Y:000070 Y:000070                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+L_RESET
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  HAWAII.waveforms  Page 37



2001      Y:000071 Y:000071                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
2002                                END_SHIFT_RESET_ODD_ROW
2003   
2004                                SHIFT_RESET_EVEN_ROW
2005      Y:000072 Y:000072                   DC      END_SHIFT_RESET_EVEN_ROW-SHIFT_RESET_EVEN_ROW-1
2006      Y:000073 Y:000073                   DC      CLK3+DELAY+L_PIXEL
2007      Y:000074 Y:000074                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+H_RESET
2008      Y:000075 Y:000075                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
2009      Y:000076 Y:000076                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
2010      Y:000077 Y:000077                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+L_RESET
2011      Y:000078 Y:000078                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
2012                                END_SHIFT_RESET_EVEN_ROW
2013   
2014                                SHIFT_EVEN_ROW
2015      Y:000079 Y:000079                   DC      END_SHIFT_EVEN_ROW-SHIFT_EVEN_ROW-1
2016      Y:00007A Y:00007A                   DC      CLK3+DELAY+L_PIXEL
2017      Y:00007B Y:00007B                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+H_RESET
2018      Y:00007C Y:00007C                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+H_LINE+H_READ+H_RESET
2019      Y:00007D Y:00007D                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
2020      Y:00007E Y:00007E                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
2021                                END_SHIFT_EVEN_ROW
2022   
2023                                SHIFT_ODD_ROW
2024      Y:00007F Y:00007F                   DC      END_SHIFT_ODD_ROW-SHIFT_ODD_ROW-1
2025      Y:000080 Y:000080                   DC      CLK3+DELAY+L_PIXEL
2026      Y:000081 Y:000081                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+H_RESET
2027      Y:000082 Y:000082                   DC      CLK2+DELAY+H_FSYNC+L_LSYNC+L_LINE+H_READ+H_RESET
2028      Y:000083 Y:000083                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+L_LINE+H_READ+H_RESET
2029      Y:000084 Y:000084                   DC      CLK2+DELAY+H_FSYNC+H_LSYNC+H_LINE+H_READ+H_RESET
2030                                END_SHIFT_ODD_ROW
2031   
2032                                SHIFT_READ_PIXELS
2033      Y:000085 Y:000085                   DC      END_SHIFT_READ_PIXELS-SHIFT_READ_PIXELS-1
2034      Y:000086 Y:000086                   DC      CLK3+DELAY+H_PIXEL
2035      Y:000087 Y:000087                   DC      $400000                           ; A/D sample
2036      Y:000088 Y:000088                   DC      $010033                           ; Start A/D conversion
2037      Y:000089 Y:000089         SXMIT0    DC      SXMIT                             ; Series transmit four pixels' data
2038      Y:00008A Y:00008A                   DC      0                                 ; Return SXMIT to zero
2039      Y:00008B Y:00008B                   DC      CLK3+DELAY+L_PIXEL
2040      Y:00008C Y:00008C                   DC      $400000                           ; A/D sample
2041      Y:00008D Y:00008D                   DC      $010033                           ; Start A/D conversion
2042      Y:00008E Y:00008E         SXMIT1    DC      SXMIT                             ; Series transmit four pixels' data
2043      Y:00008F Y:00008F                   DC      0                                 ; Return SXMIT to zero
2044                                END_SHIFT_READ_PIXELS
2045   
2046                                ; Advance the row shift register as quickly as possible, 240 nsec/pixel
2047                                SHIFT_PIXELS
2048      Y:000090 Y:000090                   DC      END_SHIFT_PIXELS-SHIFT_PIXELS-1
2049      Y:000091 Y:000091                   DC      CLK3+DELAY+H_PIXEL
2050      Y:000092 Y:000092                   DC      CLK3+DELAY+L_PIXEL
2051                                END_SHIFT_PIXELS
2052   
2053                                READ_PIXEL
2054      Y:000093 Y:000093                   DC      END_READ_PIXEL-READ_PIXEL-1
2055      Y:000094 Y:000094                   DC      $140000                           ; A/D sample
2056      Y:000095 Y:000095                   DC      $010033                           ; Start A/D conversion
2057      Y:000096 Y:000096         SXMIT00   DC      SXMIT                             ; Series transmit four pixels' data
2058      Y:000097 Y:000097                   DC      0                                 ; Return SXMIT to zero
2059                                END_READ_PIXEL
2060   
2061                                SXMIT_EIGHT_PIXELS
2062      Y:000098 Y:000098                   DC      END_SXMIT_EIGHT_PIXELS-SXMIT_EIGHT_PIXELS-1
Motorola DSP56300 Assembler  Version 6.3.22   07-07-19  17:33:34  HAWAII.waveforms  Page 38



2063      Y:000099 Y:000099                   DC      DELAY+$000033
2064      Y:00009A Y:00009A                   DC      VP_DLY                            ; A/D sample
2065      Y:00009B Y:00009B                   DC      $000033                           ; Start A/D conversion
2066      Y:00009C Y:00009C         SXMIT2    DC      SXMIT                             ; Series transmit four pixels' data
2067      Y:00009D Y:00009D                   DC      DELAY+$000033
2068      Y:00009E Y:00009E                   DC      VP_DLY                            ; A/D sample
2069      Y:00009F Y:00009F                   DC      $000033                           ; Start A/D conversion
2070      Y:0000A0 Y:0000A0         SXMIT3    DC      SXMIT                             ; Series transmit four pixels' data
2071      Y:0000A1 Y:0000A1                   DC      0                                 ; Return SXMIT to zero
2072                                END_SXMIT_EIGHT_PIXELS
2073   
2074                                 END_APPLICATON_Y_MEMORY
2075      0000A2                              EQU     @LCV(L)
2076   
2077                                ; End of program
2078                                          END

0    Errors
0    Warnings


