#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <string.h>
#include <unistd.h>
#include <signal.h>

#include <NIDAQmx.h>
#define DAQmxErrChk(functionCall) { if( DAQmxFailed(error=(functionCall)) ) { goto Error; } }

#define PORT            61000
#define MESS_SIZE       81
#define MICRONS2VOLTS	10./80.

int		sockfd;
TaskHandle	taskHandle = 0;
void sigint();
 
int main(int argc, char *argv[])
{
//        char     message[MESS_SIZE];
        float    offset;
	int 	 ret;
	struct   sockaddr_in my_addr;;
	struct   sockaddr_in their_addr;;
	socklen_t	addrlen;

	/* DAQ vars*/
	int32       error = 0;
	char        errBuff[2048]={'\0'};
	
	// cHANNel parameters
	char        chan[] = "Dev1/ao0";
	float64     minVolt = 0.0;
	float64     maxVolt = 10.0;
	
	// Timing parameters
	uInt64      samplesPerChan = 1;
	
	// Data write parameters
	float64     data;
	int32       pointsWritten;
	float64     timeout = 10.0;

	/* get an internet domain socket */
	printf("Opening socket... ");
	if ((sockfd = socket(AF_INET, SOCK_DGRAM, 0)) == -1) {
		printf("ERROR\n");
		return(1);
	} else {
		printf("DONE\n");
	}

	/* complete the socket structure */
	my_addr.sin_family = AF_INET;         // host byte order
	my_addr.sin_port = htons(PORT);     // short, network byte order
	my_addr.sin_addr.s_addr = INADDR_ANY; // automatically fill with my IP
	memset(my_addr.sin_zero, '\0', sizeof(my_addr.sin_zero));

	/* bind the socket to the port number */
	printf("Binding the socket to port %i... ",PORT);
	if (bind(sockfd, (struct sockaddr *) &my_addr,sizeof(my_addr))==-1) {
		printf("ERROR\n");
		return(1);
	} else {
		printf("DONE\n");
	}


	/* now for the DAQ */

	printf("Resetting the DAQ... ");
	DAQmxErrChk ( DAQmxResetDevice ("Dev1"));
	printf("DONE\n");


	printf("Init DAQ... ");
 	DAQmxErrChk (DAQmxCreateTask("",&taskHandle));
    	DAQmxErrChk(DAQmxCreateAOVoltageChan(taskHandle,chan,"",minVolt,maxVolt,
		DAQmx_Val_Volts,NULL));
    	DAQmxErrChk (DAQmxStartTask(taskHandle));
	printf("DONE\n");

	/* initialize the DAQ output*/
	data=0;
	DAQmxErrChk (DAQmxWriteAnalogF64(taskHandle,
		samplesPerChan,0, timeout,
		DAQmx_Val_GroupByChannel,
		&data,&pointsWritten,NULL));

	/* start serving */
	signal(SIGINT,sigint);
	printf("Ready to rumble\n");
	while (1){

		/* get a message from the client (BLOCKING) */
		if ((ret=recvfrom(sockfd, &offset, sizeof(offset),0,
			(struct sockaddr *)&their_addr, &addrlen)) == -1) {
			perror("recv");
			return(1);
		}

		//printf("%i bytes received from %s: %f\n",
		//	ret, inet_ntoa(their_addr.sin_addr),offset);

		/* do something with the message */
		data = offset * MICRONS2VOLTS;

		if ((data >= minVolt) && (data <= maxVolt)){
			DAQmxErrChk (DAQmxWriteAnalogF64(taskHandle,
				samplesPerChan,0, timeout,
				DAQmx_Val_GroupByChannel,
				&data,&pointsWritten,NULL));
		} else {
			printf("Data out of range (min=%f, max=%f Volts)\n",
				minVolt,maxVolt);
		}

	} /*end while*/

Error:
    if( DAQmxFailed(error) )
        DAQmxGetExtendedErrorInfo(errBuff,2048);
    if( taskHandle!=0 ) {
        DAQmxStopTask(taskHandle);
        DAQmxClearTask(taskHandle);
    }
    if( DAQmxFailed(error) )
        printf("DAQmx Error: %s\n",errBuff);
    return 0;
}

void sigint()
{  
   signal(SIGINT,sigint); /* reset signal */
   printf("Quitting.....");
   close(sockfd);
   DAQmxStopTask(taskHandle);
   DAQmxClearTask(taskHandle);
   sleep(1);
   printf("goodbye.\n");
   exit(0);
}
