/*************************************************
 *        Define ASCII Commands
 *************************************************/
#define EN	0x4E45	/* End program		        */
#define IO	0x4F49	/* Pass	command to ioctl	*/
#define RD	0x4452	/* Send coadd frame		*/
#define CC      0x4343  /* Send coadd COUNT             */
#define AQ	0x5141	/* Config data acquisition	*/
#define RC      0x4352  /* Receive Config for IRCam     */
#define OK	0x4B4F	/* Message acknowledged 	*/
#define KO	0x4F4B	/* Message not acknowledged	*/
#define PS      0x5350  /* Send coadded PowSpec frame   */
#define SX	0x5853  /* Start Exposure               */
#define SB	0x4253  /* Set Picnic Bias              */
#define SC      0x4353  /* Set Controller               */
#define TB      0x4254  /* Take background frame        */
#define RB      0x4252  /* Reset Background frame       */
#define UB      0x4255  /* Use Background frame         */
#define OP      0x504F  /* send offsets to OPLE server  */
#define OF      0x464F  /* get offsets for OPLE server  */
#define FI      0x4946  /* send fringe info             */
#define GI      0x4947  /* receive gdt info from python */
#define AB      0x4241  /* abort exposure               */
#define XX      0x5858  /* stop exposure 		*/
#define CN      0x4E43  /* Change Name	                */
#define SD      0x4453  /* Toggle save data flag        */
#define FX      0x5846  /* Request FluxSeries           */
#define AM      0x4D41  /* Request Amplitude, OPD, parabola parameters */
#define SP      0x5053  /* Send python config structure */
#define RP      0x5052  /* Receive py-config from socket*/
#define FP      0x5046  /* Pass Fiber Positions to RT   */
/* CHAMP GUI exchange */
#define HF      0x4648 /* Flux history */ 
#define HP      0x5048 /* Phase history */
#define HD      0x4448 /* Delay history */
/* CHAMP */
#define FT      0x5446  /* receive FT structure		*/
#define CS      0x5343  /* send out Champ Status        */
#define SS      0x5353  /* Set Search parameters        */
#define AT      0x5441  /* Amplitude Threshold          */
#define CT      0x5443  /* Calc Thresholds              */
#define CP      0x5043  /* Champ Servo Params           */
#define IR      0x5249  /* Init Reference Offsets       */
#define CO      0x4F43  /*  champ COMMAND               */
#define SR      0x5253  /* Set Ref Offsets              */
#define DO      0x4F44  /* Delay Offsets (beam order)   */
#define PA      0x4150  /* BC   Paddle Offsets          */
#define PT      0x5450  /* Phase vs time */
#define PR      0x5250  /* Phase rms vs time */

#define NUM_SKIP_READS 2
#define OPLE "ople.chara-array.org"
#define MAXIMAGE 1048576	// 1024x1024   JDM: shouldn't this be in bytes?
//#define MAXIMAGE 262144
#define MAXCHANDATA 12000 // 12 channels # 1000 numberOfFrames
#define MAXREADS 10
#define MAXFRAMES 65536
#define STACK_SIZE 8192
//#define STACK_SIZE 120000 // JDM attempt to fix weird problem
#define STD_PRIORITY 1
#define HIGH_PRIORITY 99
#define MID_PRIORITY 50
#define TASK_MODE_0 T_FPU|T_CPU(0) /* Uses FPU, bound to CPU #0 */
#define TASK_MODE_1 T_FPU|T_CPU(1) /* Uses FPU, bound to CPU #1 */
#define PIPE_MINOR 0
#define BITS_PER_PIXEL 16
#define BUFFER_SIZE 134217728 * 8
#define MINOPDS 3
#define NUMDLS 6
#define NUMMEDIAN 3  //must be odd number
#define MAXCOMBOS 12
#define FTMEMORY 200
#define GDTMEMORY 600
#define GDT_SNR_THRESHOLD 4.0
#define STATLOOP 30 // must be less than FTMEMORY
#define NUM_DELAY_LINES 6  // from /libs/charalib/chara.h (needed for vme control)
#define SOCKET_BUFFER 65536 // from /libs/charaui/src/charaui.h (needed for vme socket)
#define c_re(c) ((c)[0])
#define c_im(c) ((c)[1])

#define MAX_BOARD_ID 16
#define DAC_COUNT 6
#define DAC_OFFSET 2
#define DAC2 0 + DAC_OFFSET
#define DAC3 1 + DAC_OFFSET
#define DAC4 2 + DAC_OFFSET
#define DAC5 3 + DAC_OFFSET
#define DAC6 4 + DAC_OFFSET
#define DAC7 5 + DAC_OFFSET
#define LABEL_PREFIX "ARC42 DC Bias"
#define BOARD_ID "ARC42"
#define VOLTS2WORD 4095.0/5.0
#define PIXELMASK "/usr/local/etc/pixelmap16.1x1"

#define TIMEOUT 10000000000 /* 10 second timeout used as idle execution for FSM */
/* 1 second gave us trouble in fiber explorer mode */
#define FSM_NUM_ROWS 4
#define FSM_NUM_COLS 4

#define GETCLOCK()  (long)   (  (double) (rt_timer_read()>>18) /3.814697265625 ) //returns time in ms.
#define MAX_ERROR_STRING	256

#define BASEPORT 0x378

//from NIDAQ
//#define PI 3.1415927
#define NIDAQ_BUFFERSIZE      4096
#define NIDAQ_NUMCHANNELS     4
#define NIDAQ_NUMAOCHANNELS   3
#define DAQmxErrChk(functionCall) { if( DAQmxFailed(error=(functionCall)) ) { goto Error; } }

char error_string[MAX_ERROR_STRING];

/** Possible states for the detector, as seen by the other tasks */
enum KEYSTATE
{
	S_IDLE, /* Do Nothing            */
	S_INIT, /* Init vars mem alloch  */
	S_RUN, /* Run GDT               */
	S_BKGND
/* Take Background frame */
};
typedef enum KEYSTATE KEY_STATE;

enum BCFTSTATES
{
	BC_FT_OFF, /* beam combiner off */
	BC_FT_SEARCH, /* Search mode */
	BC_FT_SEMILOCK, /* semilock state*/
	BC_FT_LOCK /* fringe tracker locked! */
};
typedef enum BCFTSTATES BC_FT_STATES;

enum BCSEARCHMODES
{
	BC_PADDLE, BC_LINEAR, BC_SPIRAL
};
typedef enum BCSEARCHMODES BC_SEARCH_MODES;

enum COMMAND
{
	C_IDLE, /* Switch to idle             */
	C_INIT, /* switch to Init vars        */
	C_RUN, /* Switch to GDT              */
	C_INITRUN
/* Do init, followed by run */
};
typedef enum COMMAND CMD;

KEY_STATE FSM[FSM_NUM_ROWS][FSM_NUM_COLS] =
{
/*  C_IDLE     C_INIT     C_RUN     C_INITRUN             */
{ S_IDLE, S_INIT, S_RUN, S_INIT } /* S_IDLE  */
,
{ S_IDLE, S_IDLE, S_RUN, S_RUN } /* S_INIT  */
,
{ S_IDLE, S_INIT, S_RUN, S_RUN } /* S_RUN   */
,
{ S_IDLE, S_INIT, S_RUN, S_RUN } /* S_BKGND */
};

struct daqOut
{
	float coadd[MAXIMAGE]; //1024x1024 max image
	int coaddCount; // Counter for use by external programs
	float bkgnd[MAXIMAGE];//1024x1024 background frame
	float pSpec2D[MAXIMAGE];//1024x1024 max pspec
	float opds[15]; //15  baselines
	float offs[6];
	float fluxSeries[MAXFRAMES];
};

typedef struct daqOut daqOut_struct;

enum REFERENCE_TELESCOPE
{
	S1, S2, E1, E2, W1, W2
};
typedef enum REFERENCE_TELESCOPE REF_TEL;

/* This structure is used for inter-task communication */
struct exchange
{
	unsigned int pixelCount;
	unsigned int byte_count_short;
	float byte_count_float;
	boolean daqRunning;
	boolean endProg;
	boolean resetBkgnd;
	boolean takeBkgnd;
	boolean useBkgnd;
	CMD cmd;
	unsigned char bkgndNoiseCol;
	unsigned char cpeak[BASELINES];
	unsigned char cpeak0[BASELINES];
	unsigned char cpeak1[BASELINES];
	float gdtWeight[BASELINES];
	float gdtThreshold[BASELINES];
	float gdtOpd[BASELINES];
	float gdtOptOpd[MINOPDS];
	int OPDSigns[BASELINES];
	int BeamOrder[NUMTELS];
	int WrapBeam; //wherei s wraparond mirror 3,4,5,6
	double DLOffset[NUMDLS];
	boolean OffsetsReady;
	boolean manOffsetsReady;
	/*   int RefTel; */
	REF_TEL RefTel;
	float lambda;
	float bandwidth;
	unsigned long framesPerBuffer;
	boolean abort;
	boolean continuousReadout;
	char image_filename[20];
	unsigned char rtpDev[32];
	boolean endTarget;
};
typedef struct exchange exchange_struct;

struct theDaq
{
	unsigned short rows;
	unsigned short cols;
	unsigned short rowOffset;
	unsigned short colOffset;
	unsigned short nreads;
	unsigned short numberOfCoadds;
	unsigned short framesPerReset;
	unsigned short exptime;
	unsigned long numberOfFrames;
	unsigned char byteSwapping;
	unsigned char do_reset;
	unsigned char do_deinterlace;
	unsigned char do_image_save;
	unsigned char daqRunning;
	unsigned char readToggle;
	float voffset;
	float vreset;
	float vd;
	float ictl;
	char image_directory[30];
	char image_filename[20];
	unsigned char continuousReadout;
	unsigned short savenum;
	unsigned short savesPerFile;
	unsigned short numBkgnd;
	unsigned short numberCoherent;
};

/* This structure is used to communicate data to the python interface and with the spooler */
typedef struct theDaq daq_struct;

// typedef uint32_t OPLE_TIME; // also defined in dlTypes.h

void bubbleSort(float *a, unsigned int n);
void set_manual_target(int server, int dl, double pos);
void set_manual_offsets(int server, double *pos);
void sendTarget_task(void *cookie);
int nFramesPerBuffer(unsigned short *mem_fd, int bufferSize, int rows, int cols, int bits_per_pixel);
int nFramesPerBuffer2(long iBuffSize, long lRows, long lCols);

unsigned short *create_memory(int pci_fd, unsigned int bufferSize);
float add(unsigned short *src_fd, float *dest_fd, int n, int m);
void linearFit(float *src_fd, float *dest_fd, unsigned short r, unsigned short c, unsigned short nr, unsigned short nsr, unsigned short nca,
		unsigned int cac, int m);
void fluxQuad(float *src_fd, float flux, unsigned short r, unsigned short c, unsigned short nr, int quad);
void incrementFilename(char *filename);
int deinterlace(int cols, int rows, unsigned short *image_fd);
void swap_memory(unsigned short *mem_fd, int size);
void sem_task(void *cookie);
void clean_exit(int dummy);
void error(char *msg);

int ReadPixelMapFile(int rows, int cols, int *pixelMap);
int correlation(float *x, float *y, long num, float *corr);

/* Routines borrowed from chara library */
void reverse_byte_order(void *p, int nbytes); // from rwfits.h
int open_connect_socket(char *machine, int port);
int char_waiting(int fd);

int modtrig(int command, float dither_freq, float dither_amplitude, float dither_smoothfrac, float dither_delay);
//NIDAQ
int NIDAQ_modtrig(int command, float dither_freq, float dither_amplitude, float dither_smoothfrac, float dither_delay);
int NIDAQ_TriangleWave(int number, float amplitude, float phase_offset, double *data);
int NIDAQ_SawToothWave(int number, float amplitude, float phase_offset, double *data);
int NIDAQ_Trigger(int number, int width, unsigned char *data);
int NIDAQ_BoxcarSmooth(int number, double *data, int width, double *data_sm);
void send_champ2vme(int *BeamOrder, int RefTel, int nbeams, double *BC_Ref_Offset, double *BC_FT_Offset);

void IdealFringe(float amplitude, float lambda, float frac_bandwidth, float visibility, float phase_offset, float group_delay, int num, float *fringe, float* opds);
int FitIdealFringe(float amplitude, float amplitude_range, float amplitude_step_size,
                   float lambda, float frac_bandwidth,
                   float visibility, float visibility_range, float vis_step_size,
                   float phase_offset, float phase_offset_range, float phase_offset_step_size,
		   float group_delay, float group_delay_range, float group_delay_step_size,
                   int num, float *fringes, float *opds, float *fitparams);

